@@ -1050,67 +1050,6 @@ UPDATE '.IMAGES_TABLE.'
   }
 }
 
-/**
- * update images.average_rate field
- * param int $element_id optional, otherwise applies to all
- * @return void
- */
-function update_average_rate( $element_id=-1 )
-{
-  $query = '
-SELECT element_id,
-       ROUND(AVG(rate),2) AS average_rate
-  FROM '.RATE_TABLE;
-  if ( $element_id != -1 )
-  {
-    $query .= ' WHERE element_id=' . $element_id;
-  }
-  $query .= ' GROUP BY element_id;';
-
-  $result = pwg_query($query);
-
-  $datas = array();
-
-  while ($row = pwg_db_fetch_assoc($result))
-  {
-    array_push(
-      $datas,
-      array(
-        'id' => $row['element_id'],
-        'average_rate' => $row['average_rate']
-        )
-      );
-  }
-
-  mass_updates(
-    IMAGES_TABLE,
-    array(
-      'primary' => array('id'),
-      'update' => array('average_rate')
-      ),
-    $datas
-    );
-
-  $query='
-SELECT id FROM '.IMAGES_TABLE .'
-  LEFT JOIN '.RATE_TABLE.' ON id=element_id
-  WHERE element_id IS NULL AND average_rate IS NOT NULL';
-  if ( $element_id != -1 )
-  {
-    $query .= ' AND id=' . $element_id;
-  }
-  $to_update = array_from_query( $query, 'id');
-
-  if ( !empty($to_update) )
-  {
-    $query='
-UPDATE '.IMAGES_TABLE .'
-  SET average_rate=NULL
-  WHERE id IN (' . implode(',',$to_update) . ')';
-    pwg_query($query);
-  }
-}
-
 /**
  * change the parent category of the given categories. The categories are
  * supposed virtual.
@@ -1272,7 +1211,7 @@ DELETE FROM '.$table.'
  */
 function create_virtual_category($category_name, $parent_id=null)
 {
-  global $conf;
+  global $conf, $user;
 
   // is the given category name only containing blank spaces ?
   if (preg_match('/^\s*$/', $category_name))
@@ -1361,6 +1300,11 @@ UPDATE
 ;';
   pwg_query($query);
 
+  if ('private' == $insert['status'])
+  {
+    add_permission_on_category($inserted_id, array_unique(array_merge(get_admins(), array($user['id']))));
+  }
+
   return array(
     'info' => l10n('Virtual album added'),
     'id'   => $inserted_id,
@@ -1450,6 +1394,36 @@ DELETE
     );
 }
 
+/**
+ *
+ */
+function delete_tags($tag_ids)
+{
+  if (is_numeric($tag_ids))
+  {
+    $tag_ids = array($tag_ids);
+  }
+
+  if (!is_array($tag_ids))
+  {
+    return false;
+  }
+  
+  $query = '
+DELETE
+  FROM '.IMAGE_TAG_TABLE.'
+  WHERE tag_id IN ('.implode(',', $tag_ids).')
+;';
+  pwg_query($query);
+  
+  $query = '
+DELETE
+  FROM '.TAGS_TABLE.'
+  WHERE id IN ('.implode(',', $tag_ids).')
+;';
+  pwg_query($query);
+}
+
 function tag_id_from_tag_name($tag_name)
 {
   global $page;
@@ -1476,7 +1450,7 @@ SELECT id
       array(
         array(
           'name' => $tag_name,
-          'url_name' => str2url($tag_name),
+          'url_name' => trigger_event('render_tag_url', $tag_name),
           )
         )
       );
@@ -1751,7 +1725,7 @@ SELECT id
       array(
         array(
           'name' => $tag_name,
-          'url_name' => str2url($tag_name),
+          'url_name' => trigger_event('render_tag_url', $tag_name),
           )
         )
       );
@@ -2072,9 +2046,7 @@ function get_active_menu($menu_page)
     case 'notification_by_mail':
       return 2;
 
-    case 'plugins_list':
-    case 'plugins_update':
-    case 'plugins_new':
+    case 'plugins':
     case 'plugin':
       return 3;
 
@@ -2085,44 +2057,62 @@ function get_active_menu($menu_page)
     case 'maintenance':
     case 'thumbnail':
     case 'comments':
+    case 'updates':
       return 4;
 
     case 'configuration':
     case 'extend_for_templates':
     case 'menubar':
-    case 'themes_new':
-    case 'themes_installed':
+    case 'themes':
     case 'theme':
-    case 'languages_installed':
-    case 'languages_new':
+    case 'languages':
       return 5;
   }
   return 0;
 }
 
-function get_taglist($query)
+function get_taglist($query, $only_user_language=true)
 {
   $result = pwg_query($query);
   
   $taglist = array();
   while ($row = pwg_db_fetch_assoc($result))
   {
-    array_push(
-      $taglist,
-      array(
-        'name' => $row['tag_name'],
-        'id' => '~~'.$row['tag_id'].'~~',
-        )
-      );
+    if (!$only_user_language and preg_match_all('#\[lang=(.*?)\](.*?)\[/lang\]#is', $row['name'], $matches))
+    {
+      foreach ($matches[2] as $tag_name)
+      {
+        array_push(
+          $taglist,
+          array(
+            'name' => trigger_event('render_tag_name', $tag_name),
+            'id' => '~~'.$row['id'].'~~',
+            )
+          );
+      }
+
+      $row['name'] = preg_replace('#\[lang=(.*?)\](.*?)\[/lang\]#is', null, $row['name']);
+    }
+    
+    if (strlen($row['name']) > 0)
+    {
+      array_push(
+        $taglist,
+        array(
+          'name' => trigger_event('render_tag_name', $row['name']),
+          'id' => '~~'.$row['id'].'~~',
+          )
+        );
+    }
   }
   
   $cmp = create_function('$a,$b', 'return strcasecmp($a["name"], $b["name"]);');
   usort($taglist, $cmp);
-  
+
   return $taglist;
 }
 
-function get_tag_ids($raw_tags)
+function get_tag_ids($raw_tags, $allow_create=true)
 {
   // In $raw_tags we receive something like array('~~6~~', '~~59~~', 'New
   // tag', 'Another new tag') The ~~34~~ means that it is an existing
@@ -2138,13 +2128,10 @@ function get_tag_ids($raw_tags)
     {
       array_push($tag_ids, $matches[1]);
     }
-    else
+    elseif ($allow_create)
     {
       // we have to create a new tag
-      array_push(
-        $tag_ids,
-        tag_id_from_tag_name($raw_tag)
-        );
+      $tag_ids[] = tag_id_from_tag_name($raw_tag);
     }
   }
 
@@ -2167,4 +2154,103 @@ function order_by_name($element_ids,$name)
   return $ordered_element_ids;
 }
 
+function add_permission_on_category($category_ids, $user_ids)
+{
+  // array-ify categories and users
+  if (!is_array($category_ids))
+  {
+    $category_ids = array($category_ids);
+  }
+
+  if (!is_array($user_ids))
+  {
+    $user_ids = array($user_ids);
+  }
+
+  // check for emptiness
+  if (count($category_ids) == 0 or count($user_ids) == 0)
+  {
+    return;
+  }
+  
+  // make sure categories are private and select uppercats or subcats
+  $cat_ids = (isset($_POST['apply_on_sub'])) ? implode(',', get_subcat_ids($category_ids)).",".implode(',', get_uppercat_ids($category_ids)) : implode(',', get_uppercat_ids($category_ids));
+  $query = '
+SELECT
+    id
+  FROM '.CATEGORIES_TABLE.'
+  WHERE id IN ('.$cat_ids.')
+    AND status = \'private\'
+;';
+  $private_cats = array_from_query($query, 'id');
+
+  if (count($private_cats) == 0)
+  {
+    return;
+  }
+  
+  // We must not reinsert already existing lines in user_access table
+  $granteds = array();
+  foreach ($private_cats as $cat_id)
+  {
+    $granteds[$cat_id] = array();
+  }
+  
+  $query = '
+SELECT
+    user_id,
+    cat_id
+  FROM '.USER_ACCESS_TABLE.'
+  WHERE cat_id IN ('.implode(',', $private_cats).')
+    AND user_id IN ('.implode(',', $user_ids).')
+;';
+  $result = pwg_query($query);
+  while ($row = pwg_db_fetch_assoc($result))
+  {
+    array_push($granteds[$row['cat_id']], $row['user_id']);
+  }
+
+  $inserts = array();
+  
+  foreach ($private_cats as $cat_id)
+  {
+    $grant_to_users = array_diff($user_ids, $granteds[$cat_id]);
+    
+    foreach ($grant_to_users as $user_id)
+    {
+      array_push(
+        $inserts,
+        array(
+          'user_id' => $user_id,
+          'cat_id' => $cat_id
+          )
+        );
+    }
+  }
+
+  if (count($inserts) > 0)
+  {
+    mass_inserts(USER_ACCESS_TABLE, array_keys($inserts[0]), $inserts);
+  }
+}
+
+
+function get_admins($include_webmaster=true)
+{
+  $status_list = array('admin');
+
+  if ($include_webmaster)
+  {
+    $status_list[] = 'webmaster';
+  }
+  
+  $query = '
+SELECT
+    user_id
+  FROM '.USER_INFOS_TABLE.'
+  WHERE status in (\''.implode("','", $status_list).'\')
+;';
+
+  return array_from_query($query, 'user_id');
+}
 ?>
\ No newline at end of file
