@@ -70,7 +70,7 @@ $lang['Deactivate'] = 'Deaktivieren';
 $lang['Delete Representant'] = 'Lösche Vorschaubild';
 $lang['Delete selected tags'] = 'Lösche markierte Stichworte';
 $lang['Delete selected users'] = 'Lösche markierte Benutzer';
-$lang['Deletions'] = 'Entfernen';
+$lang['Deletions'] = 'Löschung';
 $lang['Deny selected groups'] = 'Ausgewählte Gruppen ablehnen';
 $lang['Deny selected users'] = 'Ausgewählte Benutzer ablehnen';
 $lang['Description'] = 'Beschreibung';
@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'sende eine Email an den
 $lang['Email admins when a comment requires validation'] = 'sende eine Email an den(die) Adminstrator(en) wenn ein Kommentar die Freischaltung durch den Admin erfordert';
 $lang['Environment'] = 'Server-Daten';
 $lang['Form'] = 'Formular';
-$lang['Gallery URL'] = 'genaue URL zur Gallerie';
 $lang['Gallery title'] = 'Galerietitel';
 $lang['Grant selected groups'] = 'Ausgewählte Gruppen zulassen';
 $lang['Grant selected users'] = 'Ausgewählte Benutzer zulassen';
@@ -99,9 +98,9 @@ $lang['Link all album photos to some existing albums'] = 'Verbinde alle Album El
 $lang['Linked albums'] = 'Verlinktes Album';
 $lang['Lock gallery'] = 'Blockiere den Zugriff auf die Datenbank';
 $lang['Maintenance'] = 'Wartung';
-$lang['Edit album permissions'] = 'Befugnisse für ein Album verwalten';
-$lang['Manage permissions for group "%s"'] = 'Verwalte die Zugriffsrechte für die Gruppe "%s"';
-$lang['Manage permissions for user "%s"'] = 'Verwalte die Zugriffsrechte für den Benutzer "%s"';
+$lang['Edit album permissions'] = 'Zugriffsrechte für ein privates Album verwalten';
+$lang['Manage permissions for group "%s"'] = 'Verwalte die Zugriffsrechte auf private Alben für die Gruppe "%s"';
+$lang['Manage permissions for user "%s"'] = 'Verwalte die Zugriffsrechte auf private Alben für den Benutzer "%s"';
 $lang['Manage tags'] = 'Verwalte Stichworte';
 $lang['Members'] = 'Mitglieder';
 $lang['Metadata synchronized from file'] = 'Metadaten synchronisiert von Datei';
@@ -114,7 +113,7 @@ $lang['New tag'] = 'Neues Stichwort';
 $lang['Number of comments per page'] = 'Anzahl von Kommentaren pro Seite';
 $lang['Number of rates'] = 'Anzahl von Bewertungen';
 $lang['Number of thumbnails to create'] = 'Anzahl von zu erstellenden Vorschaubildern';
-$lang['Only private albums are listed'] = 'Nur als privat markierte Alben werden aufgelistet';
+$lang['Only private albums are listed'] = 'Nur als "privat" markierte Alben werden aufgelistet.';
 $lang['Operating system'] = 'Betriebssystem';
 $lang['Options'] = 'Optionen';
 $lang['Other private albums'] = 'Weitere private Alben';
@@ -127,8 +126,8 @@ $lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It
 $lang['Permalink %s is already used by album %s'] = 'Permalink %s wird zurzeit vom Album %s benutzt';
 $lang['Permalink history'] = 'Permalink-Historie';
 $lang['Permalinks'] = 'Permalinks';
-$lang['Permission denied'] = 'Zugriff verweigern';
-$lang['Permission granted thanks to a group'] = 'Benutzern durch Zugehörigkeit in einer Gruppe Zugriff erlaubt';
+$lang['Permission denied'] = 'Zugriff verweigert';
+$lang['Permission granted thanks to a group'] = 'Benutzern durch Zugehörigkeit in einer Gruppe ist der Zugriff erlaubt';
 $lang['Permission granted'] = 'Zugriff erlaubt';
 $lang['Photo informations updated'] = 'Fotoinformationen aktualisiert';
 $lang['Plugins'] = 'Plugins';
@@ -177,16 +176,16 @@ $lang['You need to confirm deletion'] = 'Löschen bitte bestätigen';
 $lang['add tags'] = 'Stichworte hinzufügen';
 $lang['Associate to album'] = 'Mit einem Album verbinden';
 $lang['associate to group'] = 'Mit Gruppe verbinden';
-$lang['Authorized'] = 'Freigegebene Kategorien';
+$lang['Authorized'] = 'Zugriff erlaubt';
 $lang['Add a virtual album'] = 'Virtuelles Album hinzufügen';
 $lang['Authorize users to add comments on selected albums'] = 'Benutzern erlauben, in ausgewählten Alben Kommentare zu schreiben';
 $lang['The name of an album must not be empty'] = 'Der Name eines Albums darf nicht leer sein.';
-$lang['Lock albums'] = 'Album schließen';
-$lang['Private'] = 'Privates Album';
-$lang['Public'] = 'Öffentliches Album';
+$lang['Lock albums'] = 'Alben sperren';
+$lang['Private'] = 'Privat';
+$lang['Public'] = 'Öffentlich';
 $lang['Find a new representant by random'] = 'Bestimme ein neues zufälliges Vorschaubild';
 $lang['Public / Private'] = 'Öffentlich / Privat';
-$lang['Manage authorizations for selected albums'] = 'Berechtigungen für ausgewählte Alben verwalten';
+$lang['Manage authorizations for selected albums'] = 'Zugriffsrechte durch private Alben verwalten';
 $lang['Virtual album added'] = 'Virtuelles Album hinzugefügt';
 $lang['Virtual album deleted'] = 'Virtuelles Album entfernt';
 $lang['Access type'] = 'Zugangsart';
@@ -202,14 +201,14 @@ $lang['Date'] = 'Datum';
 $lang['delete album'] = 'Album löschen';
 $lang['Dissociate from album'] = 'Von Album abtrennen';
 $lang['dissociate from group'] = 'Von Gruppe abtrennen';
-$lang['edit album permissions'] = 'Albumberechtigungen bearbeiten';
+$lang['edit album permissions'] = 'Zugriffsrechte auf das Album bearbeiten';
 $lang['Album updated successfully'] = 'Informationen des Albums wurden erfolgreich aktualisiert.';
 $lang['photos per page'] = 'Fotos je Seite';
 $lang['High definition enabled'] = 'High definition eingeschaltet';
 $lang['File'] = 'Datei';
 $lang['Filesize'] = 'Dateigröße';
 $lang['first photo added on %s'] = 'erstes Foto am %s hinzugefügt';
-$lang['Forbidden'] = 'Gesperrte Kategorien';
+$lang['Forbidden'] = 'Zugriff verweigert';
 $lang['global mode'] = 'Globaler Modus';
 $lang['group "%s" added'] = 'Gruppe "%s" hinzugefügt';
 $lang['group "%s" deleted'] = 'Gruppe "%s" gelöscht';
@@ -221,8 +220,8 @@ $lang['High definition'] = 'High definition';
 $lang['jump to album'] = 'gehe zum Album';
 $lang['jump to photo'] = 'springe zu Foto';
 $lang['leave'] = 'Beibehalten';
-$lang['Lock'] = 'Schließen';
-$lang['Locked'] = 'Geschlossen';
+$lang['Lock'] = 'Sperren';
+$lang['Locked'] = 'Gesperrt';
 $lang['manage album photos'] = 'verwalte Fotos im Album';
 $lang['manage sub-albums'] = 'Verwalten Sie die Sub-Alben';
 $lang['Manage'] = 'Verwalten';
@@ -243,7 +242,7 @@ $lang['New photos were added'] = 'Neue Fotos wurden hinzugefügt';
 $lang['on'] = ' am ';
 $lang['between'] = 'zwischen dem';
 $lang['and'] = ' und dem ';
-$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Der Webmaster hat dich für die E-Mailbenachrichtigung eingetragen. Das bedeutet nicht, das du "zugemüllt" wirst, sondern gelegentlich eine E-Mail über aktualisierte Bilder/Kategorien in der Bildergalerie erhalten wirst. Die E-Mail wird nicht vom System, sondern vom Webmaster selbst ausgelöst. Falls du das als Belästigung empfindest, klicke unten einfach auf den Link "Austragen".';
+$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Der Webmaster hat dich für die E-Mailbenachrichtigung eingetragen. Das bedeutet nicht, das du "zugemüllt" wirst, sondern gelegentlich eine E-Mail über aktualisierte Bilder/Kategorien in der Bildergalerie. Die E-Mail wird nicht vom System, sondern vom Webmaster selbst ausgelöst. Falls du das als Belästigung empfindest, klicke unten einfach auf den Link "Austragen".';
 $lang['You have subscribed to receiving notifications by mail.'] = 'Sie sind eingetragen für die Benachrichtigung per E-Mail';
 $lang['To subscribe'] = 'Zum wieder anmelden';
 $lang['If you encounter problems or have any question, please send a message to'] = 'Bei Problemen oder Fragen sende eine E-Mail an ';
@@ -298,7 +297,7 @@ $lang['Send mail on HTML format'] = 'Sende E-Mail im HTML-Format';
 $lang['Include display of recent photos grouped by dates'] = 'Binde die neuesten Bilder, gruppiert nach Datum, in die Email ein';
 $lang['Available only with HTML format'] = 'Nur verfügbar, wenn die Benachrichtigungen im HTML-Format verschickt werden';
 $lang['no write access'] = 'kein Schreibzugriff';
-$lang['Permissions'] = 'Berechtigungen';
+$lang['Permissions'] = 'Zugriffsrechte';
 $lang['private'] = 'private';
 $lang['public'] = 'öffentlich';
 $lang['Purge never used notification feeds'] = 'Lösche alle noch nicht verschickten Benachrichtigungen';
@@ -317,7 +316,7 @@ $lang['test this remote site'] = 'testen Remote-Site';
 $lang['remove tags'] = 'Stichworte entfernen';
 $lang['Repair and optimize database'] = 'Reparieren und Optimierung der Datenbank';
 $lang['selection'] = 'Auswahl';
-$lang['set to'] = 'Setzte auf';
+$lang['set to'] = 'Setze auf';
 $lang['singly represented'] = 'festgelegtes Vorschaubild';
 $lang['This site already exists'] = 'Diese Seite gibt es bereits';
 $lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Erstellen Sie eine neue Remote-Seite: (genaue URL zur create_listing_file.php der Remote-Seite)';
@@ -333,14 +332,14 @@ $lang['status'] = 'Status';
 $lang['Directory'] = 'Verzeichnis';
 $lang['sub-albums'] = 'Sub-Album';
 $lang['synchronize metadata'] = 'Synchronisieren von Meta-Daten';
-$lang['target'] = 'Ziel';
+$lang['target'] = 'Ziel:';
 $lang['Thumbnail'] = 'Vorschaubild';
 $lang['title'] = 'Titel';
 $lang['Album list management'] = 'Albumverwaltung';
 $lang['Piwigo configuration'] = 'Konfiguration der Piwigo';
 $lang['Edit album'] = 'Einen Album bearbeiten';
-$lang['Group management'] = 'Verwalten von Gruppen';
-$lang['User list'] = 'Liste der Benutzer';
+$lang['Group management'] = 'Gruppenliste und -verwaltung';
+$lang['User list'] = 'Benutzerliste und -verwaltung';
 $lang['Edit photo information'] = 'Bearbeite Fotoinformation';
 $lang['Thumbnail creation'] = 'Erstellung von Vorschaubildern';
 $lang['Database synchronization with files'] = 'Synchronisierung der Datenbank';
@@ -409,14 +408,14 @@ $lang['Upload'] = 'Upload';
 $lang['user "%s" added'] = 'Benutzer "%s" hinzugefügt';
 $lang['User status'] = 'Status des Benutzers';
 $lang['user_status_admin'] = 'Administrator';
-$lang['user_status_generic'] = 'Allgemein';
+$lang['user_status_generic'] = 'Generischer Status';
 $lang['user_status_guest'] = 'Gast';
-$lang['user_status_normal'] = 'Besucher';
+$lang['user_status_normal'] = 'Benutzer';
 $lang['user_status_webmaster'] = 'Webmaster';
 $lang['Virtual album'] = 'Virteller Album';
 $lang['Waiting'] = 'Wartend auf Freigabe';
 $lang['default'] = 'Standard';
-$lang['Toggle \'default group\' property'] = 'Setzt die Gruppe als Standartgruppe. (Neu registrierte Benutzer gehören automatisch dieser Gruppe an!)';
+$lang['Toggle \'default group\' property'] = 'Setzt die Gruppe als Standardgruppe. (Neu registrierte Benutzer gehören automatisch dieser Gruppe an!)';
 $lang['Advanced features'] = 'Erweiterte Einstellungen';
 $lang['Specials'] = 'Erweiterte Auswahl';
 $lang['Overall'] = 'Gesamt';
@@ -490,8 +489,8 @@ $lang['No display'] = 'Keine Anzeige';
 $lang['Classic display'] = 'Klassische Ansicht';
 $lang['Hoverbox display'] = 'Anzeige beim überflug';
 $lang['Mail address is obligatory for all users'] = 'Die Angabe einer gültigen E-Mail-Adresse ist für alle Benutzer verpflichtend';
-$lang['Minimum privacy level'] = 'minimale Privatsphärenebene';
-$lang['Privacy level'] = 'Privatsphärenebene';
+$lang['Minimum privacy level'] = 'Minimale Datenschutzstufe';
+$lang['Privacy level'] = 'Datenschutzstufe';
 $lang['Level 0'] = '---';
 $lang['Level 1'] = 'Kontakt';
 $lang['Level 2'] = 'Freunde';
@@ -524,7 +523,7 @@ $lang['Can\'t create temporary file.'] = 'Temporäre Datei kann nicht erstellt .
 $lang['Can\'t download archive.'] = 'Kann Archiv nicht downloaden.';
 $lang['Can\'t read or extract archive.'] = 'Kann das Archiv nicht lesen oder entpacken.';
 $lang['An error occured during extraction (%s).'] = 'Fehler beim entpacken des Archives(%s).';
-$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'überprüfen Sie die Berechtigungen des Ordners "Plugins" und dessen Unterordner (CHMOD).';
+$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Überprüfen Sie die Berechtigungen des Ordners "Plugins" und dessen Unterordner (CHMOD).';
 $lang['Can\'t connect to server.'] = 'Es konnte keine Verbindung zum Server hergestellt werden.';
 $lang['Purge compiled templates'] = 'Löschen der kompilierten Templates';
 $lang['ACCESS_0'] = 'Frei';
@@ -600,7 +599,7 @@ $lang['Instructions to use Piwigo'] = 'Instruktionen um die Piwigo zu benutzen';
 $lang['Installed Themes'] = 'Installierte Themen';
 $lang['Add New Theme'] = 'Füge ein neues Thema hinzu';
 $lang['Forbid this theme to users'] = 'Verbieten Sie dieses Thema den Benutzern';
-$lang['Set as default theme for unregistered and new users'] = 'Setzte als Standardthema für unregistrierte und neue Benutzer';
+$lang['Set as default theme for unregistered and new users'] = 'Setze als Standardthema für unregistrierte und neue Benutzer';
 $lang['unknown'] = 'unbekannt';
 $lang['Upload Photos'] = 'Lade Fotos hoch';
 $lang['Drop into album'] = 'In das Album hochladen';
@@ -613,16 +612,13 @@ $lang['Album name'] = 'Albumname';
 $lang['Album "%s" has been added'] = 'Album "%s" wurde hinzugefügt';
 $lang['Uploaded Photos'] = 'Lade Fotos hoch';
 $lang['%d photos uploaded'] = '%d Fotos hochgeladen';
-$lang['Privacy level set to "%s"'] = 'Privatsphärenebene gesetzt auf "%s"';
+$lang['Privacy level set to "%s"'] = 'Datenschutzstufe auf "%s" gesetzt';
 $lang['Album "%s" now contains %d photos'] = 'Das Album "%s" enthält nun %d Fotos';
 $lang['Manage this set of %d photos'] = 'Verwalte dieses Set von %d Fotos';
 $lang['Select files'] = 'Wähle Dateien aus';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG Dateien oder ZIP Archive, die JPEG Dateien enthalten bitte.';
 $lang['Everybody'] = 'Jedermann';
 $lang['Who can see these photos?'] = 'Wer soll die Fotos sehen können?';
 $lang['Who can see this photo?'] = 'Wer soll dieses Foto sehen können?';
-$lang['... or switch to the old style form'] = '... oder schalte um auf das alte Formular';
-$lang['... or switch to the multiple files form'] = '... oder schalte um auf Mehrfachauswahl';
 $lang['The websize maximum width must be a number between %d and %d'] = 'Die maximale Breite muss eine Zahl zwischen %d und %d sein';
 $lang['The websize maximum height must be a number between %d and %d'] = 'Die maximale Höhe muss eine Zahl zwischen %d und %d sein';
 $lang['The websize image quality must be a number between %d and %d'] = 'Die Bildqualität muss eine Zahl zwischen %d und %d sein';
@@ -701,8 +697,8 @@ $lang['Impossible to deactivate this language, you need at least one language.']
 $lang['Inactive Languages'] = 'Deaktivierte Sprachen';
 $lang['Make this language available to users'] = 'Aktiviere diese Sprache für Benutzer';
 $lang['Set as default language for unregistered and new users'] = 'Als Standardsprache für neue und unregistrierte User festlegen';
-$lang['delete'] = 'lösche';
-$lang['Add Photos'] = 'Füge Fotos hinzu';
+$lang['delete'] = 'Löschen:';
+$lang['Add Photos'] = 'Fotos hinzufügen';
 $lang['The following tag was deleted'] = 'Folgendes Stichwort wurde gelöscht';
 $lang['There is no other language available.'] = 'Es ist keine weitere Sprache verfügbar.';
 $lang['There is no other plugin available.'] = 'Es ist kein weiteres Plugin verfügbar.';
@@ -786,5 +782,86 @@ $lang['WARNING! This plugin does not seem to be compatible with this version of
 $lang['Do you want to activate anyway?'] = 'Wollen Sie es wirklich wieder aktivieren?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'DIESES PLUGIN IST JETZT IN DEN KERN DER PIWIGO INTEGRIERT! BITTE UNBEDINGT DEINSTALLIEREN!';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERROR: DIESES PLUGIN FEHLT OBWOHL ES INSTALLIERT IST! BITTE UNBEDINGT DEINSTALLIEREN! ';
-
+$lang['Regenerate Thumbnails'] = 'Vorschaubilder neu erstellen';
+$lang['Thumbnails generation in progress...'] = 'Vorschaubilder werden neu erstellt...';
+$lang['%s thumbnails have been regenerated'] = '%s Vorschaubilder wurden neu erstellt';
+$lang['%s thumbnails can not be regenerated'] = '%s Vorschaubilder konnten nicht neu erstellt werden';
+$lang['Regenerate Websize Photos'] = 'Neuerstellung web-optimierter Fotos';
+$lang['Photos generation in progress...'] = 'Fotos werden neu erstellt...';
+$lang['%s photos have been regenerated'] = '%s Fotos wurden neu erstellt';
+$lang['%s photos can not be regenerated'] = '%s Fotos konnten nicht neu erstellt werden';
+$lang['new'] = 'neu';
+$lang['No results'] = 'Keine Ergebnisse';
+$lang['Searching...'] = 'Suche...';
+$lang['Type in a search term'] = 'Geben Sie bitte einen Suchbegriff ein';
+$lang['Activate icon "new" next to albums and pictures'] = ' Aktivieren Sie das Icon "Neu" neben Alben und Fotos ';
+$lang['Deactivate all'] = 'Deaktiviere alle';
+$lang['Default photos order'] = 'Voreingestellte Fotoanordnung';
+$lang['Restore'] = 'Zurücksetzen';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Zurücksetzen auf Standardkonfiguration. Alle Einstellungen in diesem Plugin gehen verloren!';
+$lang['Show menubar'] = 'Zeige die Menübar';
+$lang['Updates'] = 'Aktualisierungen';
+$lang['Update in progress... Please wait.'] = 'Aktualisierung in Arbeit…Bitte warten.';
+$lang['Ignore this update'] = 'Ignoriere diese Aktualisierung';
+$lang['Reset ignored updates'] = 'Zurücksetzen der ignorierten Aktualisierungen';
+$lang['Update All'] = 'Aktualisiere alles';
+$lang['ERROR'] = 'FEHLER';
+$lang['Update Complete'] = 'Aktualisierung komplett';
+$lang['Piwigo Update'] = 'Piwigo Aktualisierung';
+$lang['Extensions Update'] = 'Aktualisierung der Erweiterungen';
+$lang['All extensions are up to date.'] = 'Alle Erweiterungen sind aktuell.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Folgende Erweiterungen sind möglicherweise nicht kompatibel mit der neuen Version der Piwigo:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = ' Folgende Themen sind möglicherweise nicht kompatibel mit der neuen Version der Piwigo:';
+$lang['I decide to update anyway'] = 'Ich möchte trotzdem aktualisieren';
+$lang['Update to Piwigo %s'] = 'Aktualisierung auf Piwigo %s';
+$lang['Two updates are available'] = 'Zwei Aktualisierungen sind verfügbar';
+$lang['This is a minor update, with only bug corrections.'] = 'Dies ist eine kleine Aktualisierung nur zur Fehlerbeseitigung.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Dies ist eine größere Aktualisierung  mit <a href="%s">neuen Funktionen </a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'Einigen Themen und Erweiterungen sind nun leider nicht mehr verfügbar.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Sie können direkt auf Piwigo %s aktualisieren ohne vorher auf Piwigo %s zu aktualisieren (empfohlen).';
+$lang['Save Template Directory'] = 'Sichere den Template-Ordner';
+$lang['Dump Database'] = 'Sichere die Datenbank';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Sichere auch die Daten der History (Warnung: kann das Speicherlimit des Servers überschreiten)';
+$lang['Unable to write new local directory.'] = 'Es ist nicht möglich einen neuen lokalen Ordner zu erstellen.';
+$lang['Unable to send template directory.'] = 'Es ist nicht möglich den Templateordner zu senden.';
+$lang['Unable to dump database.'] = 'Es ist nicht möglich die Datenbank zu sichern.';
+$lang['Some upgrades are available for extensions.'] = 'Einige Aktualisierungen für Erweiterungen sind verfügbar.';
+$lang['Ignore All'] = 'Ignoriere alle';
+$lang['Crop'] = 'Zuschneiden';
+$lang['Width'] = 'Breite';
+$lang['Height'] = 'Höhe';
+$lang['Follow Orientation'] = 'Folgen Sie der Orientierung';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Wenn Sie die Vorschaubilder erneuern möchten gehen Sie bitte zum <a href="%s"> Stapelverarbeitungsmanager</a>.';
+$lang['Graphics Library'] = ' Grafikbibliothek';
+$lang['Add a criteria'] = 'Ein Kriterium hinzufügen'; 
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = ' Sie können keine Standardsortierung festlegen da Sie eine benutzerdefinierte Einstellung in Ihrer lokalen Konfiguration festgelegt haben.';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Sie haben <i>$conf[\'order_by\']</i> in ihrer lokalen Konfigurationsdatei festgelegt, dieser Parameter wird abgelehnt, bitte entfernen sie ihn oder benennen sie ihn um in <i>$conf[\'order_by_custom\']</i> !';
+$lang['Average rate'] = 'Durchschnittliche Bewertung';
+$lang['Rate'] = 'Bewertung';
+$lang['Learn more'] = 'Mehr Informationen';
+$lang['An error has occured during upgrade.'] = 'Ein Fehler trat während des Aktualisierens auf.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Ein Fehler trat während des Entpackens auf. Bitte prüfen Sie die Schreibrechte ihrer Piwigo Installation.<br><a href="%s">Klicken Sie hier für das Fehlerprotokoll</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo kann die Aktualisierungsdatei nicht vom Server laden';
+$lang['(this tag will be deleted)'] = '(dieser Tag wird gelöscht!)';
+$lang['... or '] = '... oder';
+$lang['Allowed file types: %s.'] = 'Erlaubte Dateitypen: %s.';
+$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Standardmäßig erstellt Piwigo eine für Web optimierete Ansicht der HD-Version (hochaufgelösten Version) deines Fotos';
+$lang['Confirm merge'] = 'Zusammenführen bestätigen';
+$lang['Create'] = 'Erstellen';
+$lang['hide details'] = 'Details verbergen';
+$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Wenn das Bild nicht HD (hochaufgelöst) ist und das Bild kleiner ist als die für Web optimierte Größe, verwendet Piwigo dieses als HD und erstellt eine verkleinerte Web optimierten Version';
+$lang['Manage Permissions'] = 'Zugriff verwalten';
+$lang['Maximum file size: %sB.'] = 'Max. Dateigröße: %sB.';
+$lang['Merge selected tags'] = 'Gewählte Tags zusammenführen';
+$lang['Merge tags'] = 'Tags zusammenführen';
+$lang['No destination tag selected'] = 'Keinen Ziel-Tag gewählt';
+$lang['Photo %s of %s'] = 'Bild %s of %s';
+$lang['Select an album'] = 'Wähle ein Album';
+$lang['Select at least two tags for merging'] = 'Wahle 2 Tags zum Zusammenführen';
+$lang['Select the destination tag'] = 'Wähle Ziel-Tag';
+$lang['show details'] = 'Details zeigen';
+$lang['Start Upload'] = 'Upload starten';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Tags <em>%s</em> in <em>%s</em> zusammengeführt';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Du benutzt den einfachen Uploader. Benutze den <a href="%s">Flash uploader</a> stattdessen.';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Probleme mit dem Flash Uploader. Benutze den <a href="%s">Browser uploader</a>';
 ?>
\ No newline at end of file
