@@ -79,8 +79,6 @@ $lang['%s must be to set to false in your local/config/config.inc.php file'] = "
 $lang['%s value is not correct file because exif are not supported'] = "%s value is incorrect because exif are not supported";
 $lang['+ Add an upload box'] = '+ Add an upload box';
 $lang[', click on'] = ", click on";
-$lang['... or switch to the multiple files form'] = '... or switch to the multiple files form';
-$lang['... or switch to the old style form'] = '... or switch to the old style form';
 $lang['A local listing.xml file has been found for'] = "A local listing.xml file has been found for";
 $lang['A new version of Piwigo is available.'] = "A new version of Piwigo is available.";
 $lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = "a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory \"thumbnail\" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :";
@@ -98,9 +96,11 @@ $lang['Activate icon "%s"'] = 'Activate icon "%s"';
 $lang['Activate Navigation Bar'] = 'Activate navigation bar';
 $lang['Activate Navigation Thumbnails'] = 'Activate navigation thumbnails';
 $lang['Activate'] = "Activate";
+$lang['Activate icon "new" next to albums and pictures'] = 'Activate icon "new" next to albums and pictures';
 $lang['Active Languages'] = 'Active Languages';
 $lang['Active Plugins'] = 'Active Plugins';
 $lang['Active Themes'] = 'Active Themes';
+$lang['Add a criteria'] = 'Add a criteria';
 $lang['Add a filter'] = 'Add a filter';
 $lang['Add a tag'] = "Add a tag";
 $lang['Add a user'] = "Add a user";
@@ -158,6 +158,7 @@ $lang['Authorized'] = "Authorized";
 $lang['Automatic correction'] = "Automatic correction";
 $lang['automatic order'] = 'automatic order';
 $lang['Available only with HTML format'] = "Available only with HTML format";
+$lang['Average rate'] = "Average rate";
 $lang['average time'] = "average time";
 $lang['Batch management'] = "Batch management";
 $lang['Batch Manager'] = 'Batch Manager';
@@ -205,7 +206,9 @@ $lang['Database'] = "Database";
 $lang['Date'] = "Date";
 $lang['Day'] = "Day";
 $lang['Deactivate'] = "Deactivate";
+$lang['Deactivate all'] = "Deactivate all";
 $lang['Default display'] = "Default display";
+$lang['Default photos order'] = "Default photos order";
 $lang['Default user cannot be deleted'] = "Default user cannot be deleted";
 $lang['Default user does not exist'] = "The default user does not exist";
 $lang['default values'] = "default values";
@@ -213,7 +216,7 @@ $lang['default'] = "default";
 $lang['delete album'] = "delete album";
 $lang['Delete orphan tags'] = 'Delete orphan tags';
 $lang['delete photo'] = 'delete photo';
-$lang['Delete Representant'] = "Delete Representant";
+$lang['Delete Representant'] = "Delete album thumbnail";
 $lang['Delete selected photos'] = "Delete selected photos";
 $lang['Delete selected tags'] = "Delete selected tags";
 $lang['Delete selected users'] = "Delete selected users";
@@ -239,12 +242,12 @@ $lang['Dissociate from album'] = "Dissociate from album";
 $lang['dissociate from group'] = "dissociate from group";
 $lang['Dissociated'] = "Dissociated";
 $lang['Documentation'] = "Documentation";
-$lang['Does not represent'] = "Does not represent";
+$lang['Does not represent'] = "Is not thumbnail for";
 $lang['Download'] = 'Download';
 $lang['Download,'] = 'Download,';
 $lang['Downloads'] = "Downloads";
 $lang['Drag to re-order'] = "Click-and-drag to re-order";
-$lang['Drop into album'] = 'Drop into album';
+$lang['Drop into album'] = 'Select an album';
 $lang['duplicates'] = 'duplicates';
 $lang['Edit album permissions'] = "Edit album permissions";
 $lang['edit album permissions'] = "edit album permissions";
@@ -282,7 +285,7 @@ $lang['File upload stopped by extension'] = 'File upload stopped by extension';
 $lang['File'] = "File";
 $lang['File/directory read error'] = "File/directory read error";
 $lang['Filesize'] = "Filesize";
-$lang['Find a new representant by random'] = "Find a new random representant";
+$lang['Find a new representant by random'] = "Find a new random album thumbnail";
 $lang['first photo added on %s'] = "first photo added on %s";
 $lang['for the file format'] = "for the file format";
 $lang['for this file format'] = "for this file format";
@@ -292,7 +295,6 @@ $lang['Forbidden'] = "Forbidden";
 $lang['Form'] = "Form";
 $lang['FTP + Synchronization'] = 'FTP + Synchronization';
 $lang['Gallery title'] = "Gallery title";
-$lang['Gallery URL'] = "Gallery URL";
 $lang['GD library is missing'] = "GD library is missing";
 $lang['GD version'] = "GD version";
 $lang['General statistics'] = "General statistics";
@@ -349,7 +351,7 @@ $lang['Inactive Themes'] = 'Inactive themes';
 $lang['include child albums'] = 'include child albums';
 $lang['Include display of recent photos grouped by dates'] = "Include display of recent photos grouped by dates";
 $lang['Information data registered in database'] = "Information data registered in database";
-$lang['Informations'] = "Informations";
+$lang['Informations'] = "Information";
 $lang['Install on your computer,'] = 'Install on your computer,';
 $lang['Install'] = "Install";
 $lang['Installed Languages'] = 'Installed Languages';
@@ -357,7 +359,6 @@ $lang['Installed Themes'] = "Installed Themes";
 $lang['Instructions to use Piwigo'] = "Instructions to use Piwigo";
 $lang['Invert'] = 'Invert';
 $lang['IP'] = "IP";
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG files or ZIP archives with JPEG files inside please.';
 $lang['jump to album'] = "jump to album";
 $lang['jump to photo'] = "jump to photo";
 $lang['Keep high definition'] = 'Keep high definition';
@@ -514,7 +515,6 @@ $lang['Piwigo version differs on the remote site'] = "Piwigo version differs on
 $lang['Piwigo version'] = "Piwigo version";
 $lang['pixels'] = 'pixels';
 $lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = "Please check \"plugins\" folder and sub-folders permissions (CHMOD).";
-$lang['Please wait...'] = 'Please wait...';
 $lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.';
 $lang['Plugin has been successfully copied'] = "The plugin has been successfully copied";
 $lang['Plugin list'] = "Plugins list";
@@ -540,9 +540,10 @@ $lang['Purge search history'] = "Purge search history";
 $lang['Purge sessions'] = "Purge sessions";
 $lang['Quick Local Synchronization'] = "Quick Local Synchronization";
 $lang['Random photo'] = "Random photo";
-$lang['randomly represented'] = "random representative";
+$lang['randomly represented'] = "random album thumbnail";
 $lang['ranks'] = "ranks";
-$lang['Rate date'] = "Rating date";
+$lang['Rate'] = "Rate";
+$lang['Rate date'] = "Rate date";
 $lang['Rating by guests'] = "Rating by guests";
 $lang['Rating'] = "Rating";
 $lang['read local listing.xml and update'] = "read local listing.xml and update";
@@ -566,11 +567,13 @@ $lang['remove title'] = 'remove title';
 $lang['Repair and optimize database'] = "Repair and optimize database";
 $lang['Replacement of original templates by customized templates from template-extension subfolder'] = "Replacement of original templates by customized templates from the template-extension subfolder";
 $lang['Replacers (customized templates)'] = "Substitutes (customized templates)";
-$lang['Representant'] = "Representant";
-$lang['Representation of albums'] = "Representation of albums";
-$lang['Representative'] = "Representative";
-$lang['Represents'] = "Represents";
+$lang['Representant'] = "Album Thumbnail";
+$lang['Representation of albums'] = "Album thumbnail";
+$lang['Representative'] = 'Album thumbnail';
+$lang['Represents'] = 'Is thumbnail for';
 $lang['Resize'] = 'Resize';
+$lang['Restore'] = "Restore";
+$lang['Restore default configuration. You will lose your plugin settings!'] = "Restore default configuration. You will lose your plugin settings!";
 $lang['Results of miniaturization'] = "Miniaturization process results";
 $lang['Save order'] = "Save order";
 $lang['Save page visits by administrators'] = "Record pages visited by administrators";
@@ -605,8 +608,9 @@ $lang['Set title'] = 'Set title';
 $lang['set to'] = "set to";
 $lang['Settings'] = 'Settings';
 $lang['Show info'] = "Show info";
+$lang['Show menubar'] = "Show menubar";
 $lang['Simulation'] = "Simulation";
-$lang['singly represented'] = "fixed representative";
+$lang['singly represented'] = 'fixed album thumbnail';
 $lang['Site manager'] = "Site manager";
 $lang['Specials'] = "Specials";
 $lang['Start pLoader and add your photos.'] = 'Start pLoader and add your photos.';
@@ -763,7 +767,9 @@ $lang['You are running on development sources, no check possible.'] = "You are r
 $lang['You are running the latest version of Piwigo.'] = "You are running Piwigo latest version.";
 $lang['You cannot delete your account'] = "You cannot delete your account";
 $lang['You cannot move an album in its own sub album'] = "You cannot move an album in its own sub album";
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'You can\'t define a default photo order because you have a custom setting in your local configuration.';
 $lang['You have %d orphan tags: %s.'] = 'You have %d orphan tags: %s.';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !';
 $lang['You have subscribed to receiving notifications by mail.'] = "You have subscribed to receive notifications by mail.";
 $lang['You have unsubscribed from receiving notifications by mail.'] = "You have unsubscribed from being notified by mail.";
 $lang['You might go to plugin list to install and activate it.'] = "Go to the plugins list to install and activate it.";
@@ -787,4 +793,75 @@ $lang['Do you want to activate anyway?'] = 'Do you want to activate anyway?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'THIS PLUGIN IS NOW PART OF PIWIGO CORE! UNINSTALL IT NOW!';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.';
 $lang['display'] = 'display';
-?>
\ No newline at end of file
+$lang['Regenerate Thumbnails'] = 'Regenerate Thumbnails';
+$lang['Regenerate Websize Photos'] = 'Regenerate Websize Photos';
+$lang['Thumbnails generation in progress...'] = 'Thumbnails generation in progress...';
+$lang['Photos generation in progress...'] = 'Photos generation in progress...';
+$lang['%s thumbnails have been regenerated'] = '%s thumbnails have been regenerated';
+$lang['%s thumbnails can not be regenerated'] = '%s thumbnails can not be regenerated';
+$lang['%s photos have been regenerated'] = '%s photos have been regenerated';
+$lang['%s photos can not be regenerated'] = '%s photos can not be regenerated';
+
+$lang['Updates'] = 'Updates';
+$lang['Update in progress... Please wait.'] = 'Update in progress... Please wait.';
+$lang['Ignore this update'] = 'Ignore this update';
+$lang['Reset ignored updates'] = 'Reset ignored updates';
+$lang['Update All'] = 'Update All';
+$lang['ERROR'] = 'ERROR';
+$lang['Update Complete'] = 'Update Complete';
+$lang['Piwigo Update'] = 'Piwigo Update';
+$lang['Extensions Update'] = 'Extensions Update';
+$lang['All extensions are up to date.'] = 'All extensions are up to date.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Following plugins may not be compatible with the new version of Piwigo:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Following themes may not be compatible with the new version of Piwigo:';
+$lang['I decide to update anyway'] = 'I decide to update anyway';
+$lang['Update to Piwigo %s'] = 'Update to Piwigo %s';
+$lang['Two updates are available'] = 'Two updates are available';
+$lang['This is a minor update, with only bug corrections.'] = 'This is a minor update, with only bug corrections.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'This is a major update, with <a href="%s">new exciting features</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'Some themes and plugins may be not available yet.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).';
+$lang['Save Template Directory'] = 'Save template directory';
+$lang['Dump Database'] = 'Dump Database';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Include history data (Warning: server memory limit may be exceeded)';
+$lang['Unable to write new local directory.'] = 'Unable to write new local directory.';
+$lang['Unable to send template directory.'] = 'Unable to send template directory.';
+$lang['Unable to dump database.'] = 'Unable to dump database.';
+$lang['Some upgrades are available for extensions.'] = 'Some upgrades are available for extensions.';
+$lang['Please wait...'] = 'Please wait...';
+$lang['Ignore All'] = 'Ignore All';
+$lang['Crop'] = 'Crop';
+$lang['Width'] = 'Width';
+$lang['Height'] = 'Height';
+$lang['Follow Orientation'] = 'Follow Orientation';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.';
+$lang['Graphics Library'] = 'Graphics Library';
+$lang['... or '] = '... or ';
+$lang['Create'] = 'Create';
+$lang['Start Upload'] = 'Start Upload';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.';
+$lang['Maximum file size: %sB.'] = 'Maximum file size: %sB.';
+$lang['Allowed file types: %s.'] = 'Allowed file types: %s.';
+$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).';
+$lang['Manage Permissions'] = 'Manage Permissions';
+$lang['Photo %s of %s'] = 'Photo %s of %s';
+$lang['show details'] = 'show details';
+$lang['hide details'] = 'hide details';
+$lang['Merge tags'] = 'Merge tags';
+$lang['Select the destination tag'] = 'Select the destination tag';
+$lang['(this tag will be deleted)'] = '(this tag will be deleted)';
+$lang['Confirm merge'] = 'Confirm merge';
+$lang['Merge selected tags'] = 'Merge selected tags';
+$lang['No destination tag selected'] = 'No destination tag selected';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Tags <em>%s</em> merged into tag <em>%s</em>';
+$lang['Select at least two tags for merging'] = 'Select at least two tags for merging';
+$lang['Learn more'] = 'Learn more';
+$lang['Select an album'] = 'Select an album';
+$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'By default, Piwigo will create a new websize from the HD (high definition) version of your photo.';
+$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.';
+
+$lang['An error has occured during upgrade.'] = 'An error has occured during upgrade.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo cannot retrieve upgrade file from server';
+?>
