@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Español [ES]
-Version: 2.2.0
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=169
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -35,20 +35,19 @@ $lang_info['direction'] = 'ltr';
 $lang_info['code'] = 'es';
 $lang_info['zero_plural'] = false;
 
-$lang['%.2f (rated %d times)'] = '%.2f (noté %d fois)';
 $lang['%d Kb'] = '%d Ko';
-$lang['%d album updated'] = '%d álbum actualizado';
-$lang['%d albums updated'] = '%d álbumes actualizados';
-$lang['%d comment to validate'] = '%d Comentario pendiente de validar';
-$lang['%d comments to validate'] = '%d comentarios pendientes de validar';
-$lang['%d new comment'] = '%d nuevo comentario';
-$lang['%d new comments'] = '%d nuevos comentarios';
-$lang['%d comment'] = '%d comentario';
-$lang['%d comments'] = '%d comentarios';
+$lang['%d album updated'] = '%d àlbum actualizado';
+$lang['%d albums updated'] = '%d àlbumes actualizados';
+$lang['%d comment to validate'] = '%d Comentario usuario que hay que validar';
+$lang['%d comments to validate'] = '%d comentarios de usuario que hay que validar';
+$lang['%d new comment'] = '%d Nuevo comentario usuario';
+$lang['%d new comments'] = '%d nuevos comentarios del usuario';
+$lang['%d comment'] = '%d Comentario';
+$lang['%d comments'] = '%d Comentarios';
 $lang['%d hit'] = '%d visitas';
 $lang['%d hits'] = '%d visitas';
-$lang['%d new photo'] = '%d nueva fotografía';
-$lang['%d new photos'] = '%d nuevas fotografías';
+$lang['%d new photo'] = '%d nueva fotos';
+$lang['%d new photos'] = '%d nuevas fotos';
 $lang['%d new user'] = '%d nuevo usuario';
 $lang['%d new users'] = '%d nuevos usuarios';
 $lang['About'] = 'Acerca de';
@@ -57,56 +56,51 @@ $lang['Any tag'] = 'Cualquier etiqueta';
 $lang['At least one listed rule must be satisfied.'] = 'Debe elegir al menos una de las reglas que se listan.';
 $lang['At least one tag must match'] = 'Debe coincidir al menos una de las etiquetas';
 $lang['Author'] = 'Autor';
-$lang['Average rate'] = 'Valoración promedio';
-$lang['Albums'] = 'Álbumes';
+$lang['Albums'] = 'Albums';
 $lang['Album'] = 'Álbum';
 $lang['Close this window'] = 'Cerrar la ventana';
-$lang['Complete RSS feed (photos, comments)'] = 'Flujo RSS completo (fotografías, comentarios)';
+$lang['Complete RSS feed (photos, comments)'] = 'Flujo RSS completo (fotos, comentarios)';
 $lang['Confirm Password'] = 'Confirmar la contraseña';
 $lang['Connection settings'] = 'Datos de conexión';
 $lang['Login'] = 'Identificarse';
-$lang['Contact webmaster'] = 'Contactar con el webmaster';
+$lang['Contact webmaster'] = 'Contactar el webmastre';
 $lang['Create a new account'] = 'Crear una nueva cuenta';
 $lang['Created on'] = 'Creada el';
 $lang['Creation date'] = 'Fecha de creación';
 $lang['Current password is wrong'] = 'La contraseña actual es incorrecta';
 $lang['Dimensions'] = 'Dimensiones';
-$lang['Display'] = 'Mostrar';
+$lang['Display'] = 'Monstrar';
 $lang['Each listed rule must be satisfied.'] = 'Debe cumplimentar cada una de las reglas';
-$lang['Email address is missing. Please specify an email address.'] = 'Por favor, cumplimente su dirección email.';
-$lang['Email address'] = 'Dirección email';
+$lang['Email address is missing. Please specify an email address.'] = 'Falta su dirección electrónica';
+$lang['Email address'] = 'Dirección electrónica';
 $lang['Enter your personnal informations'] = 'Cumplimente sus datos personales';
 $lang['Error sending email'] = 'Error de envío';
 $lang['File name'] = 'Nombre del archivo';
-$lang['File'] = 'Archivo';
+$lang['File'] = 'Fichero';
 $lang['Filesize'] = 'Tamaño';
 $lang['Filter and display'] = 'Filtrar y mostrar';
-$lang['Filter'] = 'Criterios de selección';
+$lang['Filter'] = 'Filtro';
 $lang['Forgot your password?'] = '¿Olvidó su contraseña?';
 $lang['Go through the gallery as a visitor'] = 'Recorrer la galería como visitante';
 $lang['Help'] = 'Ayuda';
 $lang['Identification'] = 'Identificación';
-$lang['Photos only RSS feed'] = 'Notificaciones RSS sólo para las fotografías';
-$lang['Keyword'] = 'Contraseña';
+$lang['Photos only RSS feed'] = 'Flujo RSS sólo las fotos';
+$lang['Keyword'] = 'Palabra clave';
 $lang['Links'] = 'Enlaces';
 $lang['N/A'] = 'no disponible';
 $lang['New on %s'] = 'Nuevo el %s';
 $lang['New password confirmation does not correspond'] = 'Los valores de la contraseña no coinciden';
-$lang['New password sent by email'] = 'Nueva contraseña enviada por correo electrónico';
-$lang['No email address'] = 'Falta la dirección email';
-$lang['No classic user matches this email address'] = 'La dirección email no corresponde a ningún usuario registrado';
-$lang['Notification'] = 'Notificación';
+$lang['Notification'] = 'Notificación RSS';
 $lang['Number of items'] = 'Número de artículos';
 $lang['Original dimensions'] = 'Dimensiones originales';
 $lang['Password forgotten'] = 'Contraseña olvidada';
 $lang['Password'] = 'Contraseña';
-$lang['Post date'] = 'Fecha de incorporación';
+$lang['Post date'] = 'Añadido el día';
 $lang['Posted on'] = 'Añadido el';
 $lang['Profile'] = 'Perfil';
 $lang['Quick connect'] = 'Conexión rápida';
-$lang['RSS feed'] = 'Notificaciones RSS';
-$lang['Rate'] = 'Calificación';
-$lang['Register'] = 'Registrarse';
+$lang['RSS feed'] = 'flujo RSS';
+$lang['Register'] = 'Regístrarse';
 $lang['Registration'] = 'Registro';
 $lang['Related tags'] = 'Etiquetas relacionadas';
 $lang['Reset'] = 'Cancelar';
@@ -115,37 +109,36 @@ $lang['Search rules'] = 'Criterios de búsqueda';
 $lang['Search tags'] = 'Buscar etiquetas';
 $lang['Search'] = 'Búsqueda';
 $lang['display available tags'] = 'Ver las etiquetas disponibles';
-$lang['Send new password'] = 'Enviar una nueva contraseña';
 $lang['Since'] = 'Desde';
-$lang['Sort by'] = 'Clasificar por';
-$lang['Sort order'] = 'Criterio de clasificación';
+$lang['Sort by'] = 'Clasificar según';
+$lang['Sort order'] = 'Orden de Clasificación';
 $lang['Tag'] = 'Etiqueta';
 $lang['Tags'] = 'Etiquetas';
-$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'Las notificaciones RSS informan de eventos relacionados con este sitio: nuevas fotografías, categorías actualizadas, nuevos comentarios. Debe utilizarse con un lector RSS.';
+$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'El flujo RSS notifica eventos de la galería:fotos nuevas, categorías actualizadas, nuevos comentarios de usuarios. Debe usarse con un lector de flujos RSS.';
 $lang['Unknown feed identifier'] = 'Identificador de RSS desconocido';
 $lang['User comments'] = 'Comentarios del usuario';
-$lang['Username'] = 'Nombre de usuario';
+$lang['Username'] = 'Nombre del usuario';
 $lang['Visits'] = 'Visitas';
-$lang['Webmaster'] = 'Administrador de sitio web';
+$lang['Webmaster'] = 'Webmastre';
 $lang['Week %d'] = 'Semana %d';
 $lang['About Piwigo'] = 'Acerca de Piwigo';
 $lang['You are not authorized to access the requested page'] = 'No dispone de autorización para ver la página solicitada';
 $lang['add to caddie'] = 'Agregar a la cesta';
-$lang['add this photo to your favorites'] = 'agregar esta fotografía a sus favoritos';
+$lang['add this photo to your favorites'] = 'agregar esta foto a sus favoritos';
 $lang['Administration'] = 'Administración';
 $lang['all'] = 'todo';
 $lang['ascending'] = 'ascendiente';
 $lang['author(s) : %s'] = 'autor(es) : %s';
-$lang['Expand all albums'] = 'Ver todos los álbumes';
+$lang['Expand all albums'] = 'Ver todos los àlbumes';
 $lang['posted after %s (%s)'] = 'disponible con posterioridad al %s (%s)';
 $lang['posted before %s (%s)'] = 'disponible antes del %s (%s)';
 $lang['posted between %s (%s) and %s (%s)'] = 'disponible entre él %s (%s) y el %s (%s)';
 $lang['posted on %s'] = 'disponible el %s';
 $lang['Best rated'] = 'Mejor valoracion';
-$lang['display best rated photos'] = 'mostrar las fotografías con mejor calificación';
+$lang['display best rated photos'] = 'mostrar las fotos con mejor calificación';
 $lang['caddie'] = 'Carrito';
 $lang['Calendar'] = 'Calendario';
-$lang['All'] = 'Todas';
+$lang['All'] = 'Todo';
 $lang['display each day with photos, month per month'] = 'Visualizacíon año por año,  mes por mes, día por dia,';
 $lang['View'] = 'Vista';
 $lang['chronology_monthly_calendar'] = 'Calendario mensual';
@@ -175,45 +168,45 @@ $lang['day'][4] = 'Jueves';
 $lang['day'][5] = 'Viernes';
 $lang['day'][6] = 'Sábado';
 $lang['Default'] = 'Por defecto';
-$lang['delete this photo from your favorites'] = 'eliminar esta fotografía de sus favoritos';
+$lang['delete this photo from your favorites'] = 'Borrar esta foto de sus favoritos';
 $lang['Delete'] = 'Suprimir';
 $lang['descending'] = 'descendente';
 $lang['download'] = 'descargar';
-$lang['download this file'] = 'descargar este archivo';
+$lang['download this file'] = 'descargar este fichero';
 $lang['edit'] = 'Editar';
 $lang['wrong date'] = 'Fecha errónea';
 $lang['excluded'] = 'Excluidos';
 $lang['Your favorites'] = 'Mis favoritos';
-$lang['display your favorites photos'] = 'mostrar mis fotografías favoritas';
+$lang['display your favorites photos'] = 'mostrar mis fotos favoritas';
 $lang['Favorites'] = 'Favoritas';
-$lang['First'] = 'Primera';
+$lang['First'] = 'Primera página';
 $lang['The gallery is locked for maintenance. Please, come back later.'] = 'Se están realizando operaciones de mantenimiento, regrese más tarde.';
 $lang['Page generated in'] = 'Página generada en';
 $lang['guest'] = 'Visitante';
 $lang['Hello'] = 'Hola';
 $lang['available for administrators only'] = 'disponible sólo para los administradores';
-$lang['display this album'] = 'muestra las fotografías en el directorio raíz de este álbum';
+$lang['display this album'] = 'muestra las fotos en el directorio raíz de este àlbum';
 $lang['display last user comments'] = 'Ver los últimos comentarios de los usuarios';
 $lang['customize the appareance of the gallery'] = 'personalizar el aspecto de la galería';
 $lang['search'] = 'Buscar';
 $lang['Home'] = 'Inicio';
-$lang['in this album'] = 'en este álbum';
-$lang['in %d sub-album'] = 'en este %d sub-álbum';
-$lang['in %d sub-albums'] = 'en estos %d sub-álbumes';
+$lang['in this album'] = 'en este àlbum';
+$lang['in %d sub-album'] = 'en este %d sub-àlbum';
+$lang['in %d sub-albums'] = 'en estos %d sub-àlbumes';
 $lang['included'] = 'incluidos';
 $lang['Invalid password!'] = 'Contraseña incorrecta !';
 $lang['Language'] = 'Idioma';
 $lang['last %d days'] = '%d últimos días';
-$lang['Last'] = 'Última';
+$lang['Last'] = 'Última página';
 $lang['Logout'] = 'Desconexión';
 $lang['E-mail address'] = $lang['Email address'];
 $lang['obligatory'] = 'obligatorio';
-$lang['Maximum photo height'] = 'Altura máxima de las fotografías';
-$lang['Maximum height must be a number superior to 50'] = 'La altura de las fotografías debe ser superior a 50px.';
-$lang['Maximum photo width'] = 'Anchura máxima de las fotografías';
-$lang['Maximum width must be a number superior to 50'] = 'La anchura de las fotografías debe ser superior a 50px.';
-$lang['display a calendar by creation date'] = 'mostrar las imágenes en un calendario por fecha de subida';
-$lang['display all photos in all sub-albums'] = 'Ver todas las fotografías de los álbumes y sub-álbumes';
+$lang['Maximum photo height'] = 'Altura máxima de las fotos';
+$lang['Maximum height must be a number superior to 50'] = 'La altura de las fotos debe ser superior a 50';
+$lang['Maximum photo width'] = 'Ancho máximo de las fotos';
+$lang['Maximum width must be a number superior to 50'] = 'El ancho de las fotos debe ser superior a 50';
+$lang['display a calendar by creation date'] = 'mostrar las imágenes en un calendario, por fecha de subida';
+$lang['display all photos in all sub-albums'] = 'Ver todas las fotos de los abumes y sub-albumes';
 $lang['return to normal view mode'] = 'Volver a la vista normal';
 $lang['display a calendar by posted date'] = 'Mostrar las imágenes en un calendario por fecha de agregación';
 $lang['month'][10] = 'Octubre';
@@ -229,33 +222,31 @@ $lang['month'][7] = 'Julio';
 $lang['month'][8] = 'Agosto';
 $lang['month'][9] = 'Septiembre';
 $lang['Most visited'] = 'Imágenes más vistas';
-$lang['display most visited photos'] = 'mostrar las fotografías más vistas';
-$lang['The number of photos per row must be a not null scalar'] = 'La cantidad de fotografías por línea debe ser un número entero superior a cero';
-$lang['Number of photos per row'] = 'Número de miniaturas por línea';
-$lang['The number of rows per page must be a not null scalar'] = 'El número de líneas por página debe ser un numero entero no nulo';
-$lang['Number of rows per page'] = 'Número de líneas por página';
+$lang['display most visited photos'] = 'mostrar las fotos más vistas';
+$lang['The number of photos per page must be a not null scalar'] = 'La cantidad de fotos por pagina debe ser un número entero superior a cero';
+$lang['Number of photos per page'] = 'Número de miniaturas por pagina';
 $lang['Unknown identifier'] = 'Identificador desconocido';
 $lang['New password'] = 'Nueva contraseña';
-$lang['Rate this photo'] = 'Puntuar esta fotografía';
-$lang['Next'] = 'Siguiente';
+$lang['Rate this photo'] = 'Votar esta foto';
+$lang['Next'] = 'Página siguiente';
 $lang['no rate'] = 'no valorada';
-$lang['Photos posted within the last %d day.'] = 'Sólo muestra los fotografías incorporadas desde el día %d .';
+$lang['Photos posted within the last %d day.'] = 'Sólo muestra los fotos incorporadas desde el %d día.';
 $lang['Photos posted within the last %d days.'] = 'Sólo muestra las imágenes incorporadas desde los últimos %d dias.';
 $lang['password updated'] = 'contraseña actualizada';
 $lang['Recent period must be a positive integer value'] = 'El período debe ser un número entero positivo';
-$lang['photo'] = 'Fotografía';
-$lang['Click on the photo to see it in high definition'] = 'Haga clic en la fotografía para verla en alta resolución';
-$lang['Show file metadata'] = 'Mostrar los meta-datos del archivo';
+$lang['photo'] = 'Foto';
+$lang['Click on the photo to see it in high definition'] = 'Haga clic en la foto para verla en alta resolución';
+$lang['Show file metadata'] = 'Mostrar los meta-datos del fichero';
 $lang['Powered by'] = 'Distribuido por';
 $lang['Preferences'] = 'Preferencias';
-$lang['Previous'] = 'Anterior';
-$lang['Random photos'] = 'Fotografías al azar';
-$lang['display a set of random photos'] = 'mostrar un conjunto aleatorio de fotografías';
+$lang['Previous'] = 'Página anterior';
+$lang['Random photos'] = 'foto al azar';
+$lang['display a set of random photos'] = 'mostrar un conjunto aleatorio de fotos';
 $lang['Recent albums'] = 'Álbumes recientes';
-$lang['display recently updated albums'] = 'Ver los álbumes creados o actualizados recientemente';
-$lang['Recent period'] = 'Días a considerar para incorporaciones recientes';
-$lang['Recent photos'] = 'Fotografías recientes';
-$lang['display most recent photos'] = 'mostrar las fotografías más recientes';
+$lang['display recently updated albums'] = 'Ver los àlbumes recien creados o actualizados';
+$lang['Recent period'] = 'Número de imágenes recientes';
+$lang['Recent photos'] = 'fotos recientes';
+$lang['display most recent photos'] = 'mostrar las fotos más recientes';
 $lang['Redirection...'] = 'Redirección...';
 $lang['Please, enter a login'] = 'Por favor, indique un nombre de usuario';
 $lang['login mustn\'t end with a space character'] = 'el nombre de usuario no debe terminar por un espacio';
@@ -264,10 +255,10 @@ $lang['this login is already used'] = 'Este nombre de usuario ya ha sido escogid
 $lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'El formato de la dirección e-mail debe ser xxx@yyy.eee (ejemplo: jack@altern.org)';
 $lang['please enter your password again'] = 'Por favor, escriba de nuevo su contraseña';
 $lang['Auto login'] = 'Conexión automática';
-$lang['remove this tag from the list'] = 'eliminar esta etiqueta de la lista';
-$lang['representative'] = 'Imagen de portada';
+$lang['remove this tag from the list'] = 'quitar este tag de la lista';
+$lang['representative'] = 'representante';
 $lang['Search for Author'] = 'Buscar por autor';
-$lang['Search in albums'] = 'Buscar en los álbumes';
+$lang['Search in albums'] = 'Buscar en los àlbumes';
 $lang['Search by Date'] = 'Buscar por fecha';
 $lang['Date'] = 'del dia';
 $lang['End-Date'] = 'Hasta el dia';
@@ -278,28 +269,28 @@ $lang['Search for any terms'] = 'Buscar una de las palabras';
 $lang['Empty query. No criteria has been entered.'] = 'Demanda vacía. Ningún criterio surtido..';
 $lang['Search Options'] = 'Opciones de búsqueda';
 $lang['Search results'] = 'Resultados de la búsqueda';
-$lang['Search in sub-albums'] = 'Buscar en los sub-álbumes';
+$lang['Search in sub-albums'] = 'Buscar en los sub-àlbumes';
 $lang['searched words : %s'] = 'Palabras de búsqueda : %s';
-$lang['Contact'] = 'Contacto:&nbsp;';
-$lang['set as album representative'] = 'Elegir como portada de este álbum';
+$lang['Contact'] = 'Contactar';
+$lang['set as album representative'] = 'Elegir como cabeza de este àlbum';
 $lang['Show number of comments'] = 'Mostrar el número de comentarios';
 $lang['Show number of hits'] = 'Mostrar el número de visualizaciones';
-$lang['slideshow'] = 'Presentación';
-$lang['stop the slideshow'] = 'Detener la presentación';
+$lang['slideshow'] = 'Diaporama';
+$lang['stop the slideshow'] = 'Detener el diaporama';
 $lang['Specials'] = 'Herramientas';
 $lang['SQL queries in'] = 'búsquedas SQL en';
-$lang['display only recently posted photos'] = 'Seleccionar sólo las fotografías incorporadas recientemente';
-$lang['return to the display of all photos'] = 'Volver a mostrar todas los fotografías';
-$lang['the beginning'] = 'ir al principio';
+$lang['display only recently posted photos'] = 'Seleccionar sólo los fotos incorporados recientemente';
+$lang['return to the display of all photos'] = 'Volver a mostrar todos los fotos';
+$lang['the beginning'] = 'el principio';
 $lang['Interface theme'] = 'Tema';
 $lang['Thumbnails'] = 'Miniaturas';
 $lang['Menu'] = 'Menú';
-$lang['A comment on your site'] = 'Comentarios';
+$lang['A comment on your site'] = 'Una opinión sobre esta pagina';
 $lang['today'] = 'hoy';
-$lang['Update your rating'] = 'Modificar la valoración';
+$lang['Update your rating'] = 'Actualizar la valoración';
 $lang['wrong filename'] = 'Nombre de directorio incorrecto';
 $lang['the username must be given'] = 'Indique el nombre de usuario';
-$lang['useful when password forgotten'] = 'Útil en caso de que olvide la contraseña';
+$lang['useful when password forgotten'] = 'Útil en caso de que olvideis la contraseña';
 $lang['Quick search'] = 'Búsqueda rápida';
 $lang['Connected user: %s'] = 'Usuario conectado: %s';
 $lang['IP: %s'] = 'IP: %s';
@@ -311,52 +302,76 @@ $lang['User: %s'] = 'Usuario: %s';
 $lang['Email: %s'] = 'Email: %s';
 $lang['Admin: %s'] = 'Administración: %s';
 $lang['Registration of %s'] = 'Registro de %s';
-$lang['Album: %s'] = 'Álbum: %s';
-$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'El estatus del usuario "guest" no es válido, se utilizará el estatus por defecto. Por favor, informe al administrador del sitio.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'El Administrador, el administrador del sitio y el usuario especial no pueden utilizar este método';
+$lang['Album: %s'] = 'Álbum : %s';
+$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'El estatus del usuario "guest" no es conforme, se utilizará el estatus por defecto. Por favor, informe al administrador del sitio.';
 $lang['this email address is already in use'] = 'Otro usuario ya utiliza esta dirección e-mail';
-$lang['Album results for'] = 'Resultado en los álbumes para';
+$lang['Album results for'] = 'Résultados de los  àlbumes por';
 $lang['Tag results for'] = 'Resultados de las etiquetas para';
 $lang['from %s to %s'] = 'de %s a %s';
-$lang['Play of slideshow'] = 'Comenzar';
-$lang['Pause of slideshow'] = 'Pausa';
-$lang['Repeat the slideshow'] = 'Repetir';
-$lang['Not repeat the slideshow'] = 'No repetir';
-$lang['Reduce diaporama speed'] = '+ Lento';
-$lang['Accelerate diaporama speed'] = '+ Rápido';
+$lang['Play of slideshow'] = 'Lectura del diaporama';
+$lang['Pause of slideshow'] = 'Pausa del diaporama';
+$lang['Repeat the slideshow'] = 'Repetir el diaporama';
+$lang['Not repeat the slideshow'] = 'No repetir el diaporama ';
+$lang['Reduce diaporama speed'] = 'Disminuir la velocidad del diaporama';
+$lang['Accelerate diaporama speed'] = 'Acelerar la velocidad del diaporama';
 $lang['Submit'] = 'Validar';
 $lang['Yes'] = 'Si';
 $lang['No'] = 'No';
-$lang['%d photo'] = '%d Fotografías';
-$lang['%d photos'] = '%d Fotografías';
-$lang['%d photo is also linked to current tags'] = '%d fotografía también está vinculada con las etiquetas actuales';
-$lang['%d photos are also linked to current tags'] = '%d fotografías también están vinculadas a estas etiquetas';
-$lang['display photos linked to this tag'] = 'Ver únicamente las fotografías vinculadas con esta etiqueta';
-$lang['photos posted during the last %d days'] = 'fotografías agregadas los últimos %d días';
+$lang['%d photo'] = '%d Foto';
+$lang['%d photos'] = '%d Fotos';
+$lang['%d photo is also linked to current tags'] = '%d foto también está relacionada con los tags actuales';
+$lang['%d photos are also linked to current tags'] = '%d fotos también están relacionada con los tags actuales';
+$lang['display photos linked to this tag'] = 'Ver únicamente las fotos relacionadas a ese tag';
+$lang['photos posted during the last %d days'] = 'fotos agregadas los últimos %d días';
 $lang['Piwigo Help'] = 'Ayuda de Piwigo';
 $lang['Rank'] = 'Fila';
 $lang['group by letters'] = 'Reagrupar por letras';
 $lang['letters'] = 'letras';
-$lang['show tag cloud'] = 'mostrar la nube de etiquetas';
+$lang['show tag cloud'] = 'mostrar la nube de tags';
 $lang['cloud'] = 'nube';
 $lang['Reset to default values'] = 'Restablecer los valores predeterminados';
 $lang['Sent by'] = 'Enviado por';
-$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Su navegador web no soporta cookies o están deshabilitadas. Habilite las cookies para poder conectarse.';
-$lang['delete all photos from your favorites'] = 'eliminar todas las fotografías de sus favoritos';
-$lang['Are you sure?'] = '¿Está seguro?';
-$lang['delete this comment'] = 'eliminar este comentario';
+$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'El cookies están bloqueados o sostenidos por su navegador Web. Usted debe acelerar el cookies para conectarse.';
+$lang['delete all photos from your favorites'] = 'borrar todas las fotos de tus favoritos';
+$lang['Are you sure?'] = '¿Seguro?';
+$lang['delete this comment'] = 'Borrar este comentario';
 $lang['edit this comment'] = 'editar este comentario';
 $lang['Edit a comment'] = 'Editar un comentario';
-$lang['(!) This comment requires validation'] = '(!) Este comentario requiere valida';
+$lang['(!) This comment requires validation'] = '(!) Este comentario debe ser validado';
 $lang['Welcome'] = 'Bienvenida';
-$lang['Welcome to your Piwigo photo gallery!'] = 'Bienvenidos a su galería fotográfica Piwigo!';
-$lang['... or browse your empty gallery'] = '... o navegue por su galería (sin contenido)';
-$lang['... or please deactivate this message, I will find my way by myself'] = '... o desactivar este mensaje, yo mismo lo solucionaré';
-$lang['Hello %s, your Piwigo photo gallery is empty!'] = '¡Hola %s, su galería fotográfica Piwigo está vacía!';
-$lang['I want to add photos'] = 'Quiero añadir fotografías';
-$lang['Manage this user comment: %s'] = 'Gestionar este comentario: %s';
+$lang['Welcome to your Piwigo photo gallery!'] = 'Bienvenidos a su galería foto Piwigo!';
+$lang['... or browse your empty gallery'] = '... o navegue por su galería vacía';
+$lang['... or please deactivate this message, I will find my way by myself'] = '... o desactive este mensaje, yo mismo me desenredaré';
+$lang['Hello %s, your Piwigo photo gallery is empty!'] = '¡Buenos días %s, su galería foto Piwigo está vacía!';
+$lang['I want to add photos'] = 'Quiero subir fotos';
+$lang['Manage this user comment: %s'] = 'Administrar este comentario: %s';
 $lang['This author modified following comment:'] = 'Este autor modificó el comentario siguiente:';
-$lang['This author removed the comment with id %d'] = 'Este autor eliminó el comentario con id. %d';
+$lang['This author removed the comment with id %d'] = 'Este autor suprimió el comentario sustentador al que él identificaba %d';
 $lang['validate this comment'] = 'Validar este comentario';
 $lang['html tags are not allowed in login'] = 'Etiquetas HTML no están permitidas en el area de conección';
+$lang['%d rates'] = '%d Notas';
+$lang['Rating score'] = 'Puntuación';
+$lang['Enter a username or email address'] = 'Introduzca su nombre de usuario o dirección de correo electrónico';
+$lang['Invalid username or email'] = 'Nombre de usuario o dirección de correo electrónico no válida';
+$lang['Password reset is not allowed for this user'] = 'La renovación de la contraseña no se permite para este usuario';
+$lang['User "%s" has no email address, password reset is not possible'] = 'El usuario "% s" \'s no tiene dirección de correo electrónico, la renovación de la contraseña no es posible';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Alguien ha solicitado la renovación de su contraseña para el siguiente usuario :';
+$lang['Username "%s" on gallery %s'] = 'El usuario "%s" en la galería %s';
+$lang['To reset your password, visit the following address:'] = 'Para renovar su contraseña, haga clic en el siguiente enlace :';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Si se trata de un error, ignorar este mensaje y la solicitud no será tomada en cuenta.';
+$lang['Password Reset'] = 'Renovar su contraseña';
+$lang['Check your email for the confirmation link'] = 'Revise su correo electrónico para encontrar el enlace de confirmación';
+$lang['Invalid key'] = 'clave no válida';
+$lang['The passwords do not match'] = 'Las contraseñas no coinciden';
+$lang['Your password has been reset'] = 'Su contraseña se ha restablecida';
+$lang['Return to home page'] = 'Volver a la página de inicio';
+$lang['Please enter your username or email address.'] = 'Gracias por introducir su nombre de usuario o dirección de correo electrónico.';
+$lang['You will receive a link to create a new password via email.'] = 'Recibira por email un enlace para renovar su contraseña.';
+$lang['Username or email'] = 'Nombre de usuario o dirección de correo electrónico';
+$lang['Change my password'] = 'Cambiar mi contraseña';
+$lang['Enter your new password below.'] = 'Ingrese su nueva contraseña abajo.';
+$lang['Reset Password'] = 'Restablecer la contraseña';
+$lang['EXIF Metadata'] = 'Datos EXIF';
+$lang['IPTC Metadata'] = 'Datos IPTC';
+
 ?>
\ No newline at end of file
