@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: فارسی [IR]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=419
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -34,8 +34,6 @@ $lang_info['direction'] = "rtl";
 $lang_info['code'] = "Fa";
 $lang_info['zero_plural'] = "1";
 
-
-$lang['%.2f (rated %d times)'] = "%.2f (%d بار امتیاز داده شده)";
 $lang['%d Kb'] = "%d Kb";
 $lang['%d album updated'] = "دسته %d بروز رسانی شد";
 $lang['%d albums updated'] = "دسته‌های %d بروزرسانی شدند";
@@ -57,7 +55,6 @@ $lang['Any tag'] = "هر برچسبی";
 $lang['At least one listed rule must be satisfied.'] = "حداقل یکی از معیارهای ذکر شده باید مطابقت داشته باشند";
 $lang['At least one tag must match'] = "حداقل یک برچسب باید مطابقت داشته باشد";
 $lang['Author'] = "نویسنده";
-$lang['Average rate'] = "Average rate";
 $lang['Albums'] = "دسته‌ها";
 $lang['Album'] = "دسته";
 $lang['Close this window'] = "بستن این پنجره";
@@ -91,9 +88,6 @@ $lang['Links'] = "لینک‌ها";
 $lang['N/A'] = "N/A";
 $lang['New on %s'] = "جدید در %s";
 $lang['New password confirmation does not correspond'] = "تایید گذرواژه با گذرواژه مطابقت ندارند!";
-$lang['New password sent by email'] = "گذرواژه جدید با ایمیل ارسال شد.";
-$lang['No email address'] = "آدرس ایمیل یافت نشد.";
-$lang['No classic user matches this email address'] = "هیچ کاربری یا این آدرس ایمیل مطابقت ندارد";
 $lang['Notification'] = "خبرنامه";
 $lang['Number of items'] = "تعداد آیتم‌ها";
 $lang['Original dimensions'] = "ابعاد اصلی";
@@ -104,7 +98,6 @@ $lang['Posted on'] = "ارسال شده در";
 $lang['Profile'] = "پروفایل";
 $lang['Quick connect'] = "اتصال سریع";
 $lang['RSS feed'] = "خوراک RSS";
-$lang['Rate'] = "امتیاز";
 $lang['Register'] = "ثبت نام";
 $lang['Registration'] = "ثبت نام کاربر جدید";
 $lang['Related tags'] = "برچسب‌های مربوطه";
@@ -114,7 +107,6 @@ $lang['Search rules'] = "قوانین جستجو";
 $lang['Search tags'] = "جستجوی برچسب‌ها";
 $lang['Search'] = "جستجو";
 $lang['display available tags'] = "نمایش برچسب‌های موجود";
-$lang['Send new password'] = "ارسال گذرواژه جدید";
 $lang['Since'] = "Since";
 $lang['Sort by'] = "مرتب سازی با";
 $lang['Sort order'] = "Sort order";
@@ -229,10 +221,6 @@ $lang['month'][8] = "آگوست";
 $lang['month'][9] = "سپتامبر";
 $lang['Most visited'] = "بیشترین بازدید";
 $lang['display most visited photos'] = "نمایش عکس‌هایی که بیشترین بازدید را داشته‌اند.";
-$lang['The number of photos per row must be a not null scalar'] = "تعداد عکس‌هایی که در هر سطر نمایش داده می‌شود که باید یک عدد غیر صفر باشد.";
-$lang['Number of photos per row'] = "تعداد عکس‌هایی که در هر سطر نمایش داده می‌شود";
-$lang['The number of rows per page must be a not null scalar'] = "تعداد عکس‌هایی که در هر صفحه نمایش داده می‌شود که باید یک عدد غیر صفر باشد.";
-$lang['Number of rows per page'] = "تعداد عکس‌هایی که در هر صفحه نمایش داده می‌شود";
 $lang['Unknown identifier'] = "ناشناخته!";
 $lang['New password'] = "گذرواژه جدید";
 $lang['Rate this photo'] = "امتیاز دادن به این تصویر";
@@ -312,7 +300,6 @@ $lang['Admin: %s'] = "Admin: %s";
 $lang['Registration of %s'] = "Registration of %s";
 $lang['Album: %s'] = "Category: %s";
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = "وضعیت بد برای کاربر \"میهمان\" ، وضعیت پیش‌فرض . لطفا این موضوع را با وبمستر(مدیر‌سایت) در میان بگذارید.";
-$lang['Administrator, webmaster and special user cannot use this method'] = "مدیر ، وب‌مستر و کاربر ویژه نمی‌توانند از این متد استفاده نمایند.";
 $lang['this email address is already in use'] = "یک کاربر دیگر این آدرس ایمیل را در سیستم ثبت کرده است.";
 $lang['Album results for'] = "نتایج دسته برای";
 $lang['Tag results for'] = "نتایج برچسب برای";
