@@ -86,7 +86,6 @@ $lang['Email admins when a valid comment is entered'] = "Notifier les administra
 $lang['Email admins when a comment requires validation'] = "Notifier les administrateurs quand un commentaire requiert leur validation";
 $lang['Environment'] = "Environnement";
 $lang['Form'] = "Formulaire";
-$lang['Gallery URL'] = "URL de la galerie";
 $lang['Gallery title'] = "Titre de la galerie";
 $lang['Grant selected groups'] = "Donner l'accès aux groupes sélectionnés";
 $lang['Grant selected users'] = "Donner l'accès aux utilisateurs sélectionnés";
@@ -626,12 +625,9 @@ $lang['Privacy level set to "%s"'] = 'Niveau de confidentialité "%s"';
 $lang['Album "%s" now contains %d photos'] = 'La catégorie "%s" contient désormais %d photos';
 $lang['Manage this set of %d photos'] = 'Gérer ce lot de %d photos';
 $lang['Select files'] = 'Choisir des fichiers';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'Fichiers JPEG ou archives ZIP contenant des fichiers JPEG s\'il vous plaît.';
 $lang['Everybody'] = 'Tout le monde';
 $lang['Who can see these photos?'] = 'Qui peut voir ces photos ?';
 $lang['Who can see this photo?'] = 'Qui peut voir cette photo ?';
-$lang['... or switch to the old style form'] = '... ou utiliser le formulaire "à l\'ancienne"';
-$lang['... or switch to the multiple files form'] = '... ou utiliser le formulaire multi-fichiers';
 $lang['The websize maximum width must be a number between %d and %d'] = 'La largeur maximum pour la photo taille web doit être un chiffre compris entre %d et %d';
 $lang['The websize maximum height must be a number between %d and %d'] = 'La hauteur maximum pour la photo taille web doit être un chiffre compris entre %d et %d';
 $lang['The websize image quality must be a number between %d and %d'] = 'La qualité d\'image pour la photo taille web doit être un chiffre compris entre %d et %d';
@@ -794,4 +790,88 @@ $lang['WARNING! This plugin does not seem to be compatible with this version of
 $lang['Do you want to activate anyway?'] = 'Voulez-vous l\'activer quand même?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'CE GREFFON FAIT DÉSORMAIS PARTIE DU CŒUR DE PIWIGO! SUPPRIMEZ-LE.';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERREUR: CE GREFFON EST MANQUANT MAIS TOUJOURS INSTALLÉ! DÉSINSTALLEZ-LE.';
+$lang['display'] = 'Afficher';
+$lang['Restore'] = "Restaurer";
+$lang['Restore default configuration. You will lose your plugin settings!'] = "Restaurer la configuration par défaut? Vous perdrez vos réglages personnels !";
+$lang['Show menubar'] = "Afficher le menu";
+$lang['Learn more'] = 'En savoir plus';
+$lang['Rate'] = 'Note';
+$lang['Average rate'] = 'Note moyenne';
+$lang['Activate icon "new" next to albums and pictures'] = 'Afficher l\'icône "nouveau" à côté des albums et des photos';
+$lang['Add a criteria'] = 'Ajouter un critère';
+$lang['Deactivate all'] = 'Désactiver tout';
+$lang['Default photos order'] = 'Ordre par défaut des photos';
+$lang['new'] = 'nouveau';
+$lang['No results'] = 'Pas de résultat';
+$lang['Searching...'] = 'Recherche...';
+$lang['Type in a search term'] = 'Entrez un terme de recherche';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Vous ne pouvez définir l\'ordre par défaut des photos car vous avez un paramètre personnalisé dans votre configuration locale.';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Vous avez spécifié <i>$conf[\'order_by\']</i> dans votre fichier de configuration, ce paramètre est obsolète, veuillez le supprimer ou le renommer en <i>$conf[\'order_by_custom\']</i> !';
+$lang['Regenerate Thumbnails'] = 'Régénérer les miniatures';
+$lang['Regenerate Websize Photos'] = 'Régénérer les photos taille web';
+$lang['Thumbnails generation in progress...'] = 'Génération des miniatures en cours...';
+$lang['Photos generation in progress...'] = 'Génération des photos en cours...';
+$lang['%s thumbnails have been regenerated'] = '%s miniatures ont été régénérées';
+$lang['%s thumbnails can not be regenerated'] = '%s miniatures ne peuvent pas être régénérées';
+$lang['%s photos have been regenerated'] = '%s photos ont été régénérées';
+$lang['%s photos can not be regenerated'] = '%s photos ne peuvent pas être régénérées';
+$lang['Updates'] = 'Mises à jour';
+$lang['Update in progress... Please wait.'] = 'Mise à jour en cours... Veuillez patienter.';
+$lang['Ignore this update'] = 'Ignorer cette mise à jour';
+$lang['Reset ignored updates'] = 'Réinitialiser les mises à jour ignorées';
+$lang['Update All'] = 'Tout mettre à jour';
+$lang['ERROR'] = 'ERREUR';
+$lang['Update Complete'] = 'Mise à jour effectuée';
+$lang['Piwigo Update'] = 'Mise à jour de Piwigo';
+$lang['Extensions Update'] = 'Mise à jour des extensions';
+$lang['All extensions are up to date.'] = 'Toutes les extensions sont à jour.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Les greffons suivants ne seront peut-être pas compatibles avec la nouvelle version de Piwigo:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Les thèmes suivants ne seront peut-être pas compatibles avec la nouvelle version de Piwigo:';
+$lang['I decide to update anyway'] = 'Je décide de migrer quand même';
+$lang['Update to Piwigo %s'] = 'Mettre à jour vers Piwigo %s';
+$lang['Two updates are available'] = 'Deux mises à jour sont disponibles';
+$lang['This is a minor update, with only bug corrections.'] = 'Ceci est une mise à jour mineure, avec uniquement des corrections de bugs.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Ceci est une mise à jour majeure, qui contient <a href="%s">un tas de nouveautés</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'Certains thèmes ou greffons ne sont peut-être pas encore disponibles.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Vous pouvez mettre à jour vers Piwigo %s directement, sans passer par Piwigo %s (recommandé).';
+$lang['Save Template Directory'] = 'Sauvegarder le dossier template';
+$lang['Dump Database'] = 'Sauvegarder la base de données';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Inclure les données de l\'historique (Attention: risque de dépassement de la limite mémoire du serveur)';
+$lang['Unable to write new local directory.'] = 'Impossible d\'écrire le nouveau dossier local.';
+$lang['Unable to send template directory.'] = 'Impossible d\'envoyer le dossier template.';
+$lang['Unable to dump database.'] = 'Impossible de sauvegarder la base de données.';
+$lang['Some upgrades are available for extensions.'] = 'Des mises à jour sont disponibles pour les extensions.';
+$lang['Ignore All'] = 'Tout ignorer';
+$lang['Crop'] = 'Retailler';
+$lang['Width'] = 'Largeur';
+$lang['Height'] = 'Hauteur';
+$lang['Follow Orientation'] = 'Respecter l\'orientation';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Si vous voulez régénérer des miniatures, merci de vous rendre dans la <a href="%s">Gestion par lot</a>.';
+$lang['Graphics Library'] = 'Bibliothèque graphique';
+$lang['... or '] = '... ou bien ';
+$lang['Create'] = 'Créer';
+$lang['Start Upload'] = 'Démarrer le transfert';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Vous utilisez le formulaire Flash. Des problèmes ? Essayez le <a href="%s">formulaire HTML</a> à la place.';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Vous utilisez le formulaire HTML. Essayez le <a href="%s">formulaire Flash</a> à la place.';
+$lang['Maximum file size: %sB.'] = 'Poids maximum des fichiers : %sB.';
+$lang['Allowed file types: %s.'] = 'Types de fichiers autorisés : %s.';
+$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Résolution maximum approximative : %dM pixels (soit %dx%d pixels).';
+$lang['Manage Permissions'] = 'Gérer les permissions';
+$lang['Photo %s of %s'] = 'Photo %s sur %s';
+$lang['show details'] = 'montrer les détails';
+$lang['hide details'] = 'cacher les détails';
+$lang['Merge tags'] = 'Fusionner les mots clés';
+$lang['Select the destination tag'] = 'Sélectionnez le mot clé de destination';
+$lang['(this tag will be deleted)'] = '(ce mot clé sera supprimé)';
+$lang['Confirm merge'] = 'Confirmez la fusion';
+$lang['Merge selected tags'] = 'Fusionner les mots clés sélectionnés';
+$lang['No destination tag selected'] = 'Vous n\'avez pas sélectionné de mot clé de destination';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Les mots clés <em>%s</em> ont été fusionnés dans le mot clé <em>%s</em>';
+$lang['Select at least two tags for merging'] = 'Sélectionnez au moins deux mots clés pour la fusion';
+$lang['Select an album'] = 'Selectionnez un album';
+$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Par défaut, Piwigo créera la nouvelle taille web à partir de la HD (haute définition).';
+$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Si la HD n\'est pas disponible et que la version actuelle de la taille web est plus grande que les dimensions ci-dessous, alors Piwigo la considérera comme HD et créera la nouvelle taille web à partir de celle-ci.';
+$lang['An error has occured during upgrade.'] = 'Une erreur est survenue pendant la mise à jour.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Impossible d\'extraire les fichiers. Veuillez vérifier les permissions des fichiers de votre installation.<br><a href="%s">Cliquez ici pour voir le rapport d\'erreur</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo ne peut pas récupérer le fichier de mise à jour depuis le serveur'; 
 ?>
\ No newline at end of file
