@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Français [FR]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=421
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -35,7 +35,6 @@ $lang_info['direction'] = 'ltr';
 $lang_info['code'] = 'fr';
 $lang_info['zero_plural'] = false;
 
-$lang['%.2f (rated %d times)'] = '%.2f (notée %d fois)';
 $lang['%d Kb'] = '%d Ko';
 $lang['%d album updated'] = '%d album mis à jour';
 $lang['%d albums updated'] = '%d albums mis à jour';
@@ -56,8 +55,6 @@ $lang['All tags'] = 'Tous les tags';
 $lang['Any tag'] = 'N\'importe quel tag';
 $lang['At least one listed rule must be satisfied.'] = 'Au moins un des critères doit être satisfait.';
 $lang['At least one tag must match'] = 'Au moins un tag doit correspondre';
-$lang['Author'] = 'Auteur';
-$lang['Average rate'] = 'Note moyenne';
 $lang['Albums'] = 'Albums';
 $lang['Album'] = 'Album';
 $lang['Close this window'] = 'Fermer cette fenêtre';
@@ -91,9 +88,6 @@ $lang['Links'] = 'Liens';
 $lang['N/A'] = 'non disponible';
 $lang['New on %s'] = 'Nouveau le %s';
 $lang['New password confirmation does not correspond'] = 'Erreur de confirmation de mot de passe';
-$lang['New password sent by email'] = 'Nouveau mot de passe envoyé par e-mail';
-$lang['No email address'] = 'Pas d\'adresse e-mail';
-$lang['No classic user matches this email address'] = 'Cette adresse e-mail ne correspond à aucun utilisateur classique';
 $lang['Notification'] = 'Notifications RSS';
 $lang['Number of items'] = 'Nombre d\'élément';
 $lang['Original dimensions'] = 'Dimensions d\'origine';
@@ -104,7 +98,6 @@ $lang['Posted on'] = 'Ajoutée le';
 $lang['Profile'] = 'Profil';
 $lang['Quick connect'] = 'Connexion rapide';
 $lang['RSS feed'] = 'flux RSS';
-$lang['Rate'] = 'Note';
 $lang['Register'] = 'S\'enregistrer';
 $lang['Registration'] = 'Enregistrement';
 $lang['Related tags'] = 'Tags liés';
@@ -114,7 +107,6 @@ $lang['Search rules'] = 'Critères de recherche';
 $lang['Search tags'] = 'Rechercher les tags';
 $lang['Search'] = 'Recherche';
 $lang['display available tags'] = 'Voir les tags disponibles';
-$lang['Send new password'] = 'Envoyer le nouveau mot de passe';
 $lang['Since'] = 'Depuis';
 $lang['Sort by'] = 'Trier selon';
 $lang['Sort order'] = 'Ordre de tri';
@@ -229,10 +221,8 @@ $lang['month'][8] = 'Août';
 $lang['month'][9] = 'Septembre';
 $lang['Most visited'] = 'Plus vues';
 $lang['display most visited photos'] = 'afficher les photos les plus vues';
-$lang['The number of photos per row must be a not null scalar'] = 'Le nombre de photos par ligne doit être un entier non nul';
-$lang['Number of photos per row'] = 'Nombre de miniatures par ligne';
-$lang['The number of rows per page must be a not null scalar'] = 'Le nombre de lignes par page doit être un entier non nul';
-$lang['Number of rows per page'] = 'Nombre de lignes par page';
+$lang['The number of photos per page must be a not null scalar'] = 'Le nombre de photos par page doit être un entier non nul';
+$lang['Number of photos per page'] = 'Nombre de miniatures par page';
 $lang['Unknown identifier'] = 'Identifiants inconnus';
 $lang['New password'] = 'Nouveau mot de passe';
 $lang['Rate this photo'] = 'Votez pour cette photo';
@@ -287,7 +277,7 @@ $lang['slideshow'] = 'diaporama';
 $lang['stop the slideshow'] = 'arrêter le diaporama';
 $lang['Specials'] = 'Spéciales';
 $lang['SQL queries in'] = 'requêtes SQL en';
-$lang['display only recently posted photos'] = 'n\'afficher que les photos publiés récemment';
+$lang['display only recently posted photos'] = 'n\'afficher que les photos publiées récemment';
 $lang['return to the display of all photos'] = 'retourner à l\'affichage de toutes les photos';
 $lang['the beginning'] = 'le début';
 $lang['Interface theme'] = 'Thème de l\'interface';
@@ -312,7 +302,6 @@ $lang['Admin: %s'] = 'Administration : %s';
 $lang['Registration of %s'] = 'Enregistrement de %s';
 $lang['Album: %s'] = 'Album : %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Statut de l\'utilisateur "guest" non conforme, utilisation du statut par défaut. Veuillez prévenir le webmestre.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Administrateur, webmestre et utilisateur spécial ne peuvent pas utiliser cette méthode';
 $lang['this email address is already in use'] = 'un autre utilisateur utilise déjà cette adresse e-mail';
 $lang['Album results for'] = 'Résultats des albums pour';
 $lang['Tag results for'] = 'Résultats des tags pour';
@@ -359,4 +348,30 @@ $lang['This author removed the comment with id %d'] = 'Cet auteur a supprimé le
 $lang['delete this comment'] = "supprimer ce commentaire";
 $lang['validate this comment'] = 'valider ce commentaire';
 $lang['html tags are not allowed in login'] = 'les balises html ne sont pas autorisées dans le login';
+$lang['Enter a username or email address'] = 'Entrez votre nom d\'utilisateur ou votre adresse email';
+$lang['Invalid username or email'] = 'Nom d\'utilisateur ou adresse email invalide';
+$lang['Password reset is not allowed for this user'] = 'Le renouvellement du mot de passe n\'est pas permise pour cet utilisateur';
+$lang['User "%s" has no email address, password reset is not possible'] = 'L\'utilisateur "%s" n\'a pas d\'adresse email, le renouvellement du mot de passe est impossible';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Quelqu\'un a demandé le renouvellement de votre mot de passe pour l\'utilisateur suivant :';
+$lang['Username "%s" on gallery %s'] = 'Utilisateur "%s" sur la galerie %s';
+$lang['To reset your password, visit the following address:'] = 'Pour renouveler votre mot de passe, cliquez sur le lien suivant :';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'S\'il s\'agit d\'une erreur, ignorez ce message et la demande ne sera pas prise en compte.';
+$lang['Password Reset'] = 'Renouvellement de votre mot de passe';
+$lang['Check your email for the confirmation link'] = 'Vérifiez vos emails pour trouver le lien de confirmation';
+$lang['Invalid key'] = 'Clef invalide';
+$lang['The passwords do not match'] = 'Les mots de passe ne correspondent pas';
+$lang['Your password has been reset'] = 'Votre mot de passe a été réinitialisé';
+$lang['Return to home page'] = 'Retourner sur la page d\'accueil';
+$lang['Please enter your username or email address.'] = 'Merci d\'entrer votre nom d\'utilisateur ou votre adresse email.';
+$lang['You will receive a link to create a new password via email.'] = 'Par email, vous recevrez un lien à cliquer pour renouveler votre mot de passe.';
+$lang['Username or email'] = 'Nom d\'utilisateur ou adresse email';
+$lang['Change my password'] = 'Changer mon mot de passe';
+$lang['Enter your new password below.'] = 'Entrez votre nouveau mot de passe ci-dessous.';
+$lang['Author'] = 'Auteur';
+$lang['%d rates'] = '%d notes';
+$lang['Rating score'] = 'Score';
+$lang['Reset Password'] = 'Réinitialiser le mot de passe';
+$lang['EXIF Metadata'] = 'Données EXIF';
+$lang['IPTC Metadata'] = 'Données IPTC';
+
 ?>
\ No newline at end of file
