@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'שלח מייל למנ
 $lang['Email admins when a comment requires validation'] = 'שלח מייל למנהל כאשר נדרש אימות לתגובה';
 $lang['Environment'] = 'סביבה';
 $lang['Form'] = 'טופס';
-$lang['Gallery URL'] = 'כתובת הגלריה';
 $lang['Gallery title'] = 'כותרת הגלריה';
 $lang['Grant selected groups'] = 'להעניק לקבוצות שנבחרו';
 $lang['Grant selected users'] = 'להענית למשתמשים שנבחרו';
@@ -615,12 +614,9 @@ $lang['Privacy level set to "%s"'] = 'רמת פרטיות מוגדרת ל "%s"';
 $lang['Album "%s" now contains %d photos'] = 'הקטגוריה "%s" מכילה כעט %d תמונות';
 $lang['Manage this set of %d photos'] = 'נהל את קבוצת התמונות הזאת (%d תמונות)';
 $lang['Select files'] = 'בחר קבצים';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'קבצי JPEG או בארכיון ZIP עם קבצי JPEG בתוך בבקשה.';
 $lang['Everybody'] = 'כולם';
 $lang['Who can see these photos?'] = 'מי יכול לראות את התמונות?';
 $lang['Who can see this photo?'] = 'מי יכול לראות את התמונה?';
-$lang['... or switch to the old style form'] = '... או לעבור בצורה בסגנון הישן ';
-$lang['... or switch to the multiple files form'] = '... או לעבור בצורת קבצים מרובים ';
 $lang['The websize maximum width must be a number between %d and %d'] = 'רוחב מרבי websize חייב להיות מספר בין% d% d ';
 $lang['The websize maximum height must be a number between %d and %d'] = 'הגובה המרבי של האתר חייב להיות מספר בין %d ו %d';
 $lang['The websize image quality must be a number between %d and %d'] = 'איכות התמונה באתר חייב להיות מספר בין %d ו %d';
@@ -762,4 +758,103 @@ $lang['Type here the title'] = 'כתוב כאן את הכותרת';
 $lang['remove creation date'] = 'הסר את תאריך היצירה';
 $lang['with no album'] = 'ללא אלבום';
 $lang['with no tag'] = 'ללא תיוג';
+$lang['Album photos associated to the following albums: %s'] = 'אלבום תמונות משוייך לאלבום הבא: %s';
+$lang['Delete orphan tags'] = 'מחק תגים יתומים';
+$lang['delete photo'] = 'מחק תמונה';
+$lang['new'] = 'חדש';
+$lang['No results'] = 'אין תוצאות';
+$lang['Orphan tags deleted'] = 'תגים יתומים נמחקו';
+$lang['Remove from caddie'] = 'הוסר מהנושא';
+$lang['Searching...'] = 'מחפש...';
+$lang['Type in a search term'] = 'הקלד את ערך החיפוש';
+$lang['Week starts on'] = 'שבוע מתחיל';
+$lang['You have %d orphan tags: %s.'] = 'יש לך %d תגים יתומים: %s.';
+$lang['Themes which need upgrade'] = 'ערכות נושא שצריכות שידרוג';
+$lang['Languages which need upgrade'] = 'שפות שצריכות שידרוג';
+$lang['All themes are up to date.'] = 'כל ערכות הנושא מעודכנות';
+$lang['All plugins are up to date.'] = 'כל התוספים מעודכנים.';
+$lang['All languages are up to date.'] = 'כל השפות מעודכנות.';
+$lang['Visit theme site'] = 'בקר באתר ערכת הנושא';
+$lang['Visit language site'] = 'בקר באתר השפה';
+$lang['New Version'] = 'גרסה חדשה';
+$lang['Obsolete Plugins'] = 'תוסף מיושן';
+$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'אזהרה! נראה כי תוסף זה לא מתאים ל Piwigo.';
+$lang['Do you want to activate anyway?'] = 'אתה רוצה להפעיל בכל מיקרה?';
+$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'תוסף זה הוא לא חלק מליבת PIWIGO ! הסר אותו מייד!';
+$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'שגיאה: תוסף זה נראה חסר אבל מותקן! הסר אותו מייד.';
+$lang['display'] = 'הצג';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'אתה יכול לעדכן ל Piwigo %s ישירות, מבלי לשדרג ל Piwigo %s (מומלץ).';
+$lang['Save Template Directory'] = 'שמור בספרייה תבנית';
+$lang['Dump Database'] = 'זרוק מסד נתונים';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'כלול נתוני היסטוריה אזהרה:עלולה להיות חריגת זיכרון השרת';
+$lang['Unable to write new local directory.'] = 'אין אפשרות לכתוב ספריה מקומית חדשה.';
+$lang['Unable to send template directory.'] = 'אין אפשרות לשלוח ספריית תבנית.';
+$lang['Unable to dump database.'] = 'אין אפשרות לזרות מסד נתונים.';
+$lang['Some upgrades are available for extensions.'] = 'כמה שידרוגים זמינים להרחבות.';
+$lang['Ignore All'] = 'התעלם מהכל';
+$lang['Crop'] = 'להניב';
+$lang['Width'] = 'רוחב';
+$lang['Height'] = 'גובה';
+$lang['Follow Orientation'] = 'עקוב אחר ההדרכה';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'אם ברצונך לחדש את התמונות הממוזערות נווט בבקשה ל <a href="%s">מנהל אצווה</a>.';
+$lang['Graphics Library'] = 'ספריית גרפיקה';
+$lang['Activate icon "new" next to albums and pictures'] = 'הפעל כפתו "חדש" ליד אלבומים';
+$lang['Deactivate all'] = 'בטל פעולה להכל';
+$lang['Default photos order'] = 'סדר ברירת מחדל לתמונות';
+$lang['Restore'] = 'שחזר';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'שחזר להגדרות ברירת מחדל. הגדרות ההתקן יאבדו!';
+$lang['Show menubar'] = 'הצג תפריט';
+$lang['Regenerate Thumbnails'] = 'חידוש תמונות ממוזערות';
+$lang['Regenerate Websize Photos'] = 'חידוש גודל תמונות באתר';
+$lang['Thumbnails generation in progress...'] = 'חידוש תמונות ממוזערות בתהליך...';
+$lang['Photos generation in progress...'] = 'חידוש תמונות בתהליך...';
+$lang['%s thumbnails have been regenerated'] = '%s תמונות ממוזערות חודשו';
+$lang['%s thumbnails can not be regenerated'] = '%s תמונות ממוזערות לא יכלו להתחדש';
+$lang['%s photos have been regenerated'] = '%s תמונות חודשו';
+$lang['%s photos can not be regenerated'] = '%s תמונות לא יכלו להתחדש';
+$lang['Updates'] = 'עדכונים';
+$lang['Update in progress... Please wait.'] = 'עדכון בתהליך... המתן.';
+$lang['Ignore this update'] = 'התעלם מעידכון זה';
+$lang['Reset ignored updates'] = 'אפס התעלמות מעידכונים';
+$lang['Update All'] = 'עדכן הכל';
+$lang['ERROR'] = 'שגיאה';
+$lang['Update Complete'] = 'עידכון הושלם';
+$lang['Piwigo Update'] = 'Piwigo עדכון';
+$lang['Extensions Update'] = 'עדכון הרחבה';
+$lang['All extensions are up to date.'] = 'כל ההרחבות מעודכנות.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'יכול להיות שההתקן לא תואם לגירסה החדשה של Piwigo:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'יכול להיות שהערכת הנושא לא תואמת לגירסה החדשה של Piwigo:';
+$lang['I decide to update anyway'] = 'החלתי לעדכן בכל מיקרה';
+$lang['Update to Piwigo %s'] = 'עדכן ל Piwigo %s';
+$lang['Two updates are available'] = 'שני עידכונים זמינים';
+$lang['This is a minor update, with only bug corrections.'] = 'זהו עידכון שולי, תיקון באגים שנמצאו.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'עדכון חשוב, עם <a href="%s">מאפיינים חדשים ומלהיבים</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'יכול להיות שחלק מההתקנים וערכות הנושא לא זמינים עדיין .';
+$lang['Learn more'] = 'למד עוד';
+$lang['Rate'] = "דרג";
+$lang['Average rate'] = "דירוג ממוצע";
+$lang['(this tag will be deleted)'] = ')התג הזה ימחק(';
+$lang['... or '] = 'או ...';
+$lang['Add a criteria'] = 'הוסף קריטריון';
+$lang['Allowed file types: %s.'] = 'סוגי קבצים מותרים:%s';
+$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'רזולוציה מקסימלית: %dM פקסלים(שזה %dx%d פקסלים).';
+$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'כברירת מחדל, Piwigo יצור גודל חדש לתמונות ה HD שלך.';
+$lang['Confirm merge'] = 'אשר איחוד';
+$lang['Create'] = 'צור';
+$lang['hide details'] = 'הסתר פרטים';
+$lang['Manage Permissions'] = 'ניהול הרשאות';
+$lang['Maximum file size: %sB.'] = 'גודל קובץ מקסימאלי: %sB.';
+$lang['Merge selected tags'] = 'אחד תגים מסומנים';
+$lang['Merge tags'] = 'איחוד תגים';
+$lang['No destination tag selected'] = 'לא ניבחרו תגי יעד';
+$lang['Photo %s of %s'] = 'תמונה %s מ %s';
+$lang['Select an album'] = 'בחר אלבום';
+$lang['Select at least two tags for merging'] = 'בחר לפחות שני תגים לאיחוד';
+$lang['Select the destination tag'] = 'בחר תגים ביעד';
+$lang['show details'] = 'הצג פרטים';
+$lang['Start Upload'] = 'התחל העלאה';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'התג <em>%s</em> אוחד כעם תג <em>%s</em>';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'אתה משתמש בהעלאה מהדפדפן. נסה <a href="%s">העלאת פלאש</a> במקום.';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'אתה משתמש בהעלאת פלאש. ישנה בעיה? נסה <a href="%s">העלאה מהדפדפן</a> במקום.';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'אין באפשרותך לקבוע סדר תמונות ברירת מחדל מכיוון שאתה משתמש בהגדרות מותאמות אישית';
 ?>
\ No newline at end of file
