@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'E-mail upraviteljima pr
 $lang['Email admins when a comment requires validation'] = 'Email upraviteljima kada komentar treba ovjeru';
 $lang['Environment'] = 'Okruženje';
 $lang['Form'] = 'Oblik';
-$lang['Gallery URL'] = 'URL Galerije';
 $lang['Gallery title'] = 'Naziv galerije';
 $lang['Grant selected groups'] = 'Ovlasti odabrane grupe';
 $lang['Grant selected users'] = 'Ovlasti odabrane korisnike';
@@ -615,11 +614,8 @@ $lang['Privacy level set to "%s"'] = 'Razina privatnosti postavljena na "%s"';
 $lang['Album "%s" now contains %d photos'] = 'Skupina "%s" sada sadržava %d slika';
 $lang['Manage this set of %d photos'] = 'Upravljanje ovim skupom od %d slika';
 $lang['Select files'] = 'Odaberi zapise';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG zapisi ili ZIP arhive sa JPEG zapisima unutra molim.';
 $lang['Everybody'] = 'Svi';
 $lang['Who can see these photos?'] = 'Tko može pregledavati ove slike?';
-$lang['... or switch to the old style form'] = '... ili prebaci na oblik starog stila';
-$lang['... or switch to the multiple files form'] = '... ili prebaci na oblik višestrukih zapisa';
 $lang['The websize maximum width must be a number between %d and %d'] = 'Najveća širina web prozora mora biti broj između %d i %d';
 $lang['The websize maximum height must be a number between %d and %d'] = 'Najveća visina web prozora mora biti broj između %d i %d';
 $lang['The websize image quality must be a number between %d and %d'] = 'Kakvoća slike u web prozoru mora biti broj između %d i %d';
@@ -711,4 +707,88 @@ $lang['Path'] = 'Putanja';
 $lang['Order of menubar items has been updated successfully.'] = 'Redoslijed  stavki izborne trake je uspješno obnovljen.';
 $lang['This theme was not designed to be directly activated'] = 'Ova tema nije zamišljena za neposrednu postavu'; 
 $lang['Menu Management'] = 'Izbornik';
-?>
+$lang['Action'] = 'Akcija';
+$lang['Add a filter'] = 'Dodaj filter';
+$lang['Album photos associated to the following albums: %s'] = 'Fotografije vezane uz sljedeće albume: %s';
+$lang['Albums automatically sorted'] = 'Automatski poredak albuma';
+$lang['All %d photos are selected'] = 'Označeno %d fotografija';
+$lang['Apply action'] = 'Potvrdi akciju';
+$lang['automatic order'] = 'automatski poredak';
+$lang['Batch Manager'] = 'Skupno uređivanje';
+$lang['Choose an action'] = 'Odaberi akciju';
+$lang['Delete orphan tags'] = 'Briši nekorištene oznake';
+$lang['delete photo'] = 'briši fotografiju';
+$lang['duplicates'] = 'duplići';
+$lang['Error on file "%s" : %s'] = 'Greška na datoteci "%s" : %s';
+$lang['Exif extension not available, admin should disable exif use'] = 'Exif ekstenzija nije dostupna, administrator bi trebao onemogućiti korištenje exif-a';
+$lang['Failed to write file to disk'] = 'Nije uspjelo zapisivanje na disk';
+$lang['File upload stopped by extension'] = 'Upload datoteke je zaustavljen od strane ekstenzije';
+$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'Vrijednost upload_max_filesize (%sB) u vašoj php.ini datoteci je veća od post_max_size (%sB), trebali biste podesiti te postavke';
+$lang['include child albums'] = 'uključi podalbume';
+$lang['Keep high definition'] = 'Zadrži visoku kvalitetu';
+$lang['last import'] = 'zadnji import';
+$lang['manual order'] = 'ručni poredak';
+$lang['%d of %d photos selected'] = 'označeno %d od %d fotografija';
+$lang['Missing a temporary folder'] = 'Nedostaje privremena mapa';
+$lang['new'] = 'novo';
+$lang['No file was uploaded'] = 'Datoteka nije poslana';
+$lang['No photo in the current set.'] = 'U trenutnoj grupi nema fotografija.';
+$lang['No photo selected, %d photos in current set'] = 'Fotografije nisu označene, %d fotografija u trenutnoj grupi';
+$lang['No photo selected, no action possible.'] = 'Nijedna fotografija nije označena.';
+$lang['No results'] = 'Nema rezultata';
+$lang['on the %d selected photos'] = 'na %d označenih fotografija';
+$lang['Orphan tags deleted'] = 'Nekorištene oznake su izbrisane';
+$lang['Pending Comments'] = 'Neriješeni komentari';
+$lang['predefined filter'] = 'predefinirani filter';
+$lang['Refresh photo set'] = 'Osvježi grupu fotografija';
+$lang['Remove all filters'] = 'Ukloni sve filtre';
+$lang['remove author'] = 'ukloni autora';
+$lang['remove creation date'] = 'ukloni datum nastanka';
+$lang['Remove from caddie'] = 'Ukloni iz caddie';
+$lang['remove this filter'] = 'ukloni ovaj filter';
+$lang['remove title'] = 'ukloni naslov';
+$lang['Searching...'] = 'Tražim ...';
+$lang['Selection'] = 'Odabir';
+$lang['Set author'] = 'Postavi autora';
+$lang['Set creation date'] = 'Postavi datum nastanka';
+$lang['Set title'] = 'Postavi naslov';
+$lang['The high definition image quality must be a number between %d and %d'] = 'Kvaliteta slike visoke razlučivosti mora biti broj između %d i %d';
+$lang['The high definition maximum height must be a number between %d and %d'] = 'Maksimalna visina slike visoke razlučivosti mora biti broj između %d i %d';
+$lang['The high definition maximum width must be a number between %d and %d'] = 'Maksimalna širina slike visoke razlučivosti mora biti broj između %d i %d';
+$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Veličina poslane datoteke prelazi MAX_FILE_SIZE postavku definiranu unutar HTML obrasca';
+$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Veličina poslane datoteke prelazi uload_max_filesize postavku u php.ini: %sB';
+$lang['The uploaded file was only partially uploaded'] = 'Poslana datoteka je djelomično upload-ana';
+$lang['Rate'] = 'Ocjena';
+$lang['Average rate'] = 'Prosječna ocjena';
+$lang['An error has occured during upgrade.'] = 'Došlo je do greške tijekon postupka nadogradnje.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Greška se dogodila tijekom izlučivanja. Molimo provjerite upisne dozvole vaše piwigo postave.<br><a href="%s">Kliknite za prikaz dnevnika greške</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo ne može dohvatiti zapis nadogradnje sa poslužitelja';
+$lang['Dump Database'] = 'Isprazni bazu podataka';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Uključi povijest posjeta (Pozor: memorijsko ograničenje poslužitelja može biti premašeno)';
+$lang['Unable to write new local directory.'] = 'Nemoguć upis u novu lokalnu mapu.';
+$lang['Unable to send template directory.'] = 'Nemoguće slanje mape predložaka.';
+$lang['Unable to dump database.'] = 'Nemoguće pražnjenje baze podataka.';
+$lang['Save Template Directory'] = 'Sačuvaj mapu predložaka';
+$lang['Some themes and plugins may be not available yet.'] = 'Neke teme i dodaci možda nisu još dostupni.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Možete nadograditi Piwigo na inačicu %s neposredno, bez nadograđivanja na inačicu Piwigo %s (preporučeno).';
+$lang['Update to Piwigo %s'] = 'Nadogradnja na Piwigo inačicu %s';
+$lang['Two updates are available'] = 'Dvije su nadogradnje dostupne';
+$lang['This is a minor update, with only bug corrections.'] = 'Ovo je manja nadogradnja, samo popravke grešeaka.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Ovo je veća nadogradnja, sa <a href="%s">novim uzbudljivim mogućnostima</a>.';
+$lang['Update in progress... Please wait.'] = 'Nadogradnja u tijeku... Molimo sačekajte.';
+$lang['Activate icon "new" next to albums and pictures'] = 'Aktivirajte sličicu "Novo" pored albuma i slika';
+$lang['Add a criteria'] = 'Dodaj uvjet';
+$lang['Deactivate all'] = 'Sve deaktiviraj';
+$lang['Default photos order'] = 'Zadani poredak fotografija';
+$lang['Restore'] = 'Vrati';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Vrati zadane postavke. Postojeće postve dodataka će se izgubiti!';
+$lang['Show menubar'] = 'Prikaži liniju izbornika';
+$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Poslana datoteka prelazi post_max_size direktivu u php.ini: %sB';
+$lang['The whole page'] = 'Cijela stranica';
+$lang['The whole set'] = 'Cijeli set';
+$lang['Type here the author name'] = 'Unesi ime autora';
+$lang['Type here the title'] = 'Unesi naslov';
+$lang['Type in a search term'] = 'Traži ..';
+$lang['Unknown upload error'] = 'Nepoznata greška prilikom slanja datoteke';
+
+?>
\ No newline at end of file
