@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Hrvatski [HR]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=422
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -35,7 +35,6 @@ $lang_info['direction'] = 'ltr';
 $lang_info['code'] = 'hr';
 $lang_info['zero_plural'] = true;
 
-$lang['%.2f (rated %d times)'] = '%.2f (ocijenjeno %d puta)';
 $lang['%d Kb'] = '%d Kb';
 $lang['%d album updated'] = '%d skupina obnovljena';
 $lang['%d albums updated'] = '%d skupine obnovljene';
@@ -57,7 +56,6 @@ $lang['Any tag'] = 'Bilo koji tag';
 $lang['At least one listed rule must be satisfied.'] = 'Najmanje jedno od navedenih pravila mora biti zadovoljeno.';
 $lang['At least one tag must match'] = 'Najmanje jedan tag se mora poklapati';
 $lang['Author'] = 'Autor';
-$lang['Average rate'] = 'Prosječna ocjena';
 $lang['Albums'] = 'Skupine';
 $lang['Album'] = 'Skupina';
 $lang['Close this window'] = 'Zatvori prozor';
@@ -92,9 +90,6 @@ $lang['Links'] = 'Poveznice';
 $lang['N/A'] = 'N/D';
 $lang['New on %s'] = 'Novi na on %s';
 $lang['New password confirmation does not correspond'] = 'Potvrda nove zaporke ne odgovara';
-$lang['New password sent by email'] = 'Nova zaporka poslana e-mail porukom';
-$lang['No email address'] = 'Nema e-mail adrese';
-$lang['No classic user matches this email address'] = 'Nijedan korisnik se ne poklapa s ovom e-mail adresom';
 $lang['Notification'] = 'Obavijest';
 $lang['Number of items'] = 'Broj stavki';
 $lang['Original dimensions'] = 'Izvorne veličine';
@@ -105,7 +100,6 @@ $lang['Posted on'] = 'Objavljeno u';
 $lang['Profile'] = 'Profil';
 $lang['Quick connect'] = 'Brza veza';
 $lang['RSS feed'] = 'RSS izvor';
-$lang['Rate'] = 'Ocjena';
 $lang['Register'] = 'Upišite se';
 $lang['Registration'] = 'Upis';
 $lang['Related tags'] = 'Odnosni tagovi';
@@ -115,7 +109,6 @@ $lang['Search rules'] = 'Pravila pretrage';
 $lang['Search tags'] = 'Tagovi pretrage';
 $lang['Search'] = 'Pretraživanje';
 $lang['display available tags'] = 'Pogledaj dostupne tagove';
-$lang['Send new password'] = 'Pošalji novu zaporku';
 $lang['Since'] = 'Od';
 $lang['Sort by'] = 'Složeno po';
 $lang['Sort order'] = 'Redoslijed slaganja';
@@ -230,10 +223,8 @@ $lang['month'][8] = 'Kolovoz';
 $lang['month'][9] = 'Rujan';
 $lang['Most visited'] = 'Najposjećenije';
 $lang['display most visited photos'] = 'prikaz najposjećenijih slika';
-$lang['The number of photos per row must be a not null scalar'] = 'broj slika po redu mora biti cjelobrojna vrijednost';
-$lang['Number of photos per row'] = 'Broj slika po redu';
-$lang['The number of rows per page must be a not null scalar'] = 'Broj redova po stranici mora biti cjelobrojna vrijednost';
-$lang['Number of rows per page'] = 'Broj redova po stranici';
+$lang['The number of photos per page must be a not null scalar'] = 'broj slika po stranici mora biti cjelobrojna vrijednost';
+$lang['Number of photos per page'] = 'Broj slika po stranici';
 $lang['Unknown identifier'] = 'Nepoznata oznaka';
 $lang['New password'] = 'Nova zaporka';
 $lang['Rate this photo'] = 'Ocjeni ovu sliku';
@@ -313,7 +304,6 @@ $lang['Admin: %s'] = 'Upravitelj: %s';
 $lang['Registration of %s'] = 'Upis od %s';
 $lang['Album: %s'] = 'Skupina: %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Loš status za korisnika "guest", koristi se pretpostavljeni status. Molimo obavjestite webmaster-a.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Upravitelj, webmaster i posebni korisnik ne mogu koristiti ovu metodu';
 $lang['this email address is already in use'] = 'korisnik već koristi ovu e-mail adresu';
 $lang['Album results for'] = 'Ishodi skupine za ';
 $lang['Tag results for'] = 'Ishodi tagova za';
@@ -341,7 +331,6 @@ $lang['show tag cloud'] = 'prikaži tag oblak';
 $lang['cloud'] = 'oblak';
 $lang['Are you sure?'] = 'Sigurni ste?';
 $lang['delete this comment'] = 'izbriši ovaj komentar';
-// piwigo 2.1
 $lang['Reset to default values'] = 'Povratak na pretpostavljene vrijednosti';
 $lang['delete all photos from your favorites'] = 'izbriši sve slike iz omiljenih';
 $lang['Sent by'] = 'Poslano od';
@@ -359,4 +348,30 @@ $lang['Manage this user comment: %s'] = 'Upravljanje ovim korisničkim komentaro
 $lang['This author modified following comment:'] = 'Ovaj autor je promijenio slijedeći komentar:';
 $lang['This author removed the comment with id %d'] = 'Ovaj autor je uklonio komentar sa id %d';
 $lang['validate this comment'] = 'ovjeri ovaj komentar';
+$lang['html tags are not allowed in login'] = 'u korisničkim podacima nisu dozvoljene html oznake';
+$lang['%d rates'] = '%d ocjena';
+$lang['Rating score'] = 'Rezultat ocjenjivanja';
+$lang['Enter a username or email address'] = 'Unesite korisničko ime ili email adresu';
+$lang['Invalid username or email'] = 'Korisničko ime ili email nisu valjani';
+$lang['Password reset is not allowed for this user'] = 'Ovom korisniku nije dozvoljeno ponovno postavljanje lozinke';
+$lang['User "%s" has no email address, password reset is not possible'] = 'Korisnik "%s" nema email adresu, ponovno postavljanje lozinke nije moguće';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Netko je zatražio ponovno postavljanje zaboravljene lozinke za korisnički račun:';
+$lang['Username "%s" on gallery %s'] = 'Korisničko ime "%s" na galeriji %s';
+$lang['To reset your password, visit the following address:'] = 'Za izmjenu zaboravljene lozinke posjetite:';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Ukoliko ste greškom dobili ovu poruku slobodno je zanemarite i ništa se neće desiti.';
+$lang['Password Reset'] = 'Zaboravili ste lozinku?';
+$lang['Check your email for the confirmation link'] = 'Provjerite svoj email, naći ćete link za potvrdu.';
+$lang['Invalid key'] = 'Ključ nije valjan';
+$lang['The passwords do not match'] = 'Lozinke se ne podudaraju';
+$lang['Your password has been reset'] = 'Lozinka vam je izmijenjena';
+$lang['Return to home page'] = 'Povratak na početnu stranicu';
+$lang['Please enter your username or email address.'] = 'Molimo vas da unesete vaše korisničko ime ili email adresu.';
+$lang['You will receive a link to create a new password via email.'] = 'Link za izmjenu lozinke poslan vam je u email poruci.';
+$lang['Username or email'] = 'Korisničko ime ili lozinka';
+$lang['Change my password'] = 'Promjena lozinke';
+$lang['Enter your new password below.'] = 'Unesite vašu novu lozinku.';
+$lang['Reset Password'] = 'Promjeni lozinku.';
+$lang['EXIF Metadata'] = 'EXIF metapodaci';
+$lang['IPTC Metadata'] = 'IPTC metapodaci';
+
 ?>
\ No newline at end of file
