@@ -70,6 +70,7 @@ $lang['Comments for all'] = 'Commenti per tutti';
 $lang['Current name'] = 'Nome attuale';
 $lang['Database'] = 'Database';
 $lang['Deactivate'] = 'Disattivare';
+$lang['Deactivate all'] = 'Disattivare tutto';
 $lang['Delete Representant'] = 'Cancellare la copertina';
 $lang['Delete selected tags'] = 'Cancellare i tags selezionati';
 $lang['Delete selected users'] = 'Cancellare gli utenti selezionati';
@@ -87,7 +88,6 @@ $lang['Email admins when a valid comment is entered'] = 'Notificare gli amminist
 $lang['Email admins when a comment requires validation'] = 'Notificare gli amministratori quando un commento richiede un\'approvazione';
 $lang['Environment'] = 'Ambiente';
 $lang['Form'] = 'Modulo';
-$lang['Gallery URL'] = 'URL della galleria';
 $lang['Gallery title'] = 'Titolo della galleria';
 $lang['Grant selected groups'] = 'Dare l\'accesso ai gruppi selezionati';
 $lang['Grant selected users'] = 'Dare l\'accesso agli utenti selezionati';
@@ -386,7 +386,7 @@ $lang['Errors caption'] = 'Significato degli errori';
 $lang['Detailed informations'] = 'Informazioni dettagliate';
 $lang['File/directory read error'] = 'Errore in letture del file/directory';
 $lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Non è possibile accedere al file o alla directory (probabilmente non esiste o l\'accesso è stato negato)';
-$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'Ogni foto richiede una miniatura. La miniatura deve essere presente nella sottodirectory "thumbnail" della directory. Il nome del file della miniatura deve iniziare con il parametro di configurazione "prefix_thumbnail" e l\'estensione deve essere presente nell\’elenco seguente:';
+$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'Ogni foto richiede una miniatura. La miniatura deve essere presente nella sottodirectory "thumbnail" della directory. Il nome del file della miniatura deve iniziare con il parametro di configurazione "prefix_thumbnail" e l\'estensione deve essere presente nell\'elenco seguente:';
 $lang['missing thumbnail'] = 'miniature mancanti';
 $lang['albums deleted in the database'] = 'album cancellati dal database';
 $lang['photos deleted from the database'] = 'foto cancellate dal database';
@@ -616,16 +616,13 @@ $lang['Album name'] = 'Nome dell\'album';
 $lang['Album "%s" has been added'] = 'L\'Album "%s" è stato aggiunto';
 $lang['Uploaded Photos'] = 'Foto aggiunte ';
 $lang['%d photos uploaded'] = '%d foto aggiunte';
-$lang['Privacy level set to "%s"'] = 'Livello di confidenzialità t "%s"';
+$lang['Privacy level set to "%s"'] = 'Livello di privacy "%s"';
 $lang['Album "%s" now contains %d photos'] = 'L\'Album "%s" contiene adesso %d foto';
 $lang['Manage this set of %d photos'] = 'Gestire questo set di %d foto';
 $lang['Select files'] = 'Scegliere i file';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'File JPEG o archivi ZIP con dentro dei file JPEG per cortesia.';
 $lang['Everybody'] = 'Tutti';
 $lang['Who can see these photos?'] = 'Chi può vedere queste foto?';
 $lang['Who can see this photo?'] = 'Chi può vedere questa foto?';
-$lang['... or switch to the old style form'] = '... o passare sul modulo "vecchio stile"';
-$lang['... or switch to the multiple files form'] = '... o passare sul modulo multi-file';
 
 $lang['The websize maximum width must be a number between %d and %d'] = 'La larghezza massima della foto con dimenzioni per il web deve essere un numero tra %d e %d';
 $lang['The websize maximum height must be a number between %d and %d'] = 'L\'altezza massima della foto con dimenzioni per il web deve essere un numero tra %d e %d';
@@ -635,7 +632,7 @@ $lang['The thumbnail maximum height must be a number between %d and %d'] = 'L\'a
 $lang['The thumbnail image quality must be a number between %d and %d'] = 'La qualità  dell\'immagine per la miniatura deve essere un numero tra %d e %d';
 
 $lang['Settings'] = 'Configurazione';
-$lang['Web size photo'] = 'Dimensione foto';
+$lang['Web size photo'] = 'Dimensione foto web';
 $lang['Resize'] = 'Ridimensionare';
 $lang['Maximum Width'] = 'Larghezza massima';
 $lang['pixels'] = 'pixels';
@@ -653,7 +650,7 @@ $lang['Delete this theme'] = 'Cancellare questo tema';
 $lang['Directory does not exist'] = 'La directory non esiste';
 $lang['Download,'] = 'Scaricare,';
 $lang['FTP + Synchronization'] = 'FTP + Sincronizzazione';
-$lang['Get Support on Piwigo Forum'] = 'Ottenere supporto sul forum di Piwigo';
+$lang['Get Support on Piwigo Forum'] = 'Ottenere assistenza sul forum di Piwigo';
 $lang['Help Me'] = 'Aiuto';
 $lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Non è stato possibile attivare questo tema, manca il tema principale (superiore): %s';
 $lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Impossibile cancellare questo tema. Altri temi dipendono da esso: %s';
@@ -662,7 +659,6 @@ $lang['Install on your computer,'] = 'Installare sul vostro computer,';
 $lang['Make this theme available to users'] = 'Rendere questo tema disponibile agli utenti';
 $lang['Page end'] = 'Fine pagina';
 $lang['Piwigo Uploader'] = 'Piwigo Uploader';
-$lang['Please wait...'] = 'Attendere prego ...';
 $lang['Read Piwigo Documentation'] = 'Leggere la documentazione di Piwigo';
 $lang['Start pLoader and add your photos.'] = 'Avviare pLoader e aggiungere le vostre foto.';
 $lang['Switch to clear or dark colors for administration'] = 'Scegliere il colore chiaro o scuro per l\'amministrazione';
@@ -794,8 +790,88 @@ $lang['Do you want to activate anyway?'] = 'Volete attivarlo comunque?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'QUESTO PLUGIN FA ORMAI PARTIE DEL CORE DI PIWIGO! CANCELLATELO.';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERRORE: QUESTO PLUGIN È MANCANTE MA TUTTORA INSTALLATO! CANCELLATELO.';
 $lang['display'] = 'Visualizzare';
+$lang['Restore'] = 'Restaurare';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Reimpostare la configurazione di defaut? Perderete tutte le vostre impostazioni!';
+$lang['Regenerate Thumbnails'] = 'Rigenerare le miniature';
+$lang['Regenerate Websize Photos'] = 'Rigenerare le foto dimensioni web';
+$lang['Thumbnails generation in progress...'] = 'Rigenerazione delle miniature in corso ...';
+$lang['Photos generation in progress...'] = 'Rigenerazione delle foto in corso ...';
+$lang['%s thumbnails have been regenerated'] = '%s miniature sono state rigenerate';
+$lang['%s thumbnails can not be regenerated'] = '%s miniature non possono essere rigenerate';
+$lang['%s photos have been regenerated'] = '%s foto sono state rigenerate';
+$lang['%s photos can not be regenerated'] = '%s foto non possono essere rigenerate';
+
+$lang['Updates'] = 'Aggiornamento';
+$lang['Update in progress... Please wait.'] = 'Aggiornamento in corso ... Attendere prego';
+$lang['Ignore this update'] = 'Igniorare questo aggiornamento';
+$lang['Reset ignored updates'] = 'Ripristinare gli aggiornamenti igniorati';
+$lang['Update All'] = 'Applicare tutti gli aggiornamenti';
+$lang['ERROR'] = 'ERRORE';
+$lang['Update Complete'] = 'Aggiornamento completao';
+$lang['Piwigo Update'] = 'Aggiornamento di Piwigo';
+$lang['Extensions Update'] = 'Aggiornamento delle estenzioni';
+$lang['All extensions are up to date.'] = 'Tutte le estensioni sono aggiorno';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'I plugin seguenti potrebbero non essere compatibili con la nuova versione di Piwigo :';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'I temi seguenti potrebbero non essere compatibili con la nuova versione di Piwigo :';
+$lang['I decide to update anyway'] = 'Decido comunque di aggiornare';
+$lang['Update to Piwigo %s'] = 'Aggiornare a Piwigo %s';
+$lang['Two updates are available'] = 'Due aggiornamenti sono disponibili';
+$lang['This is a minor update, with only bug corrections.'] = 'Questo è un aggiornamento minore, con solo correzioni di bug';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Questo è un aggiornamento importante, con <a href="%s">nuove e interessanti funzionalità</a>';
+$lang['Some themes and plugins may be not available yet.'] = 'Alcuni temi e plugin possono non essere ancora disponibili';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'È possibile aggiornare direttamente a Piwigo %s, senza passare per Piwigo %s (consigliato)';
+$lang['Save Template Directory'] = 'Salvare la template directory';
+$lang['Dump Database'] = 'Salvare il database';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Includere la cronologia (Attenzione: può essere superato il limite di memoria del server)';
+$lang['Unable to write new local directory.'] = 'Impossibile creare nuove directory locali';
+$lang['Unable to send template directory.'] = 'Impossibile inviare la directory template';
+$lang['Unable to dump database.'] = 'Impossibile eseguire il salvataggio del database';
+$lang['Some upgrades are available for extensions.'] = 'Degli aggiornamenti sono disponibili per le estenzioni';
+$lang['Please wait...'] = 'Attendere prego ...';
+$lang['Ignore All'] = 'Igniorare tutti gli aggiornamenti';
+$lang['Crop'] = 'Ridimenzionare';
+$lang['Width'] = 'Larghezza';
+$lang['Height'] = 'Altezza';
+$lang['Follow Orientation'] = 'Rispettare l\'orientamento';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Se volete rigenerare le miniature, rendetevi su <a href="%s">Gestione per lotti</a>.';
+$lang['Graphics Library'] = 'Biblioteca grafica';
+$lang['Show menubar'] = 'Visualizzare il menu';
 $lang['No results'] = 'Nessun risultato';
 $lang['Type in a search term'] = 'Inserire un Entrez un termine di ricerca';
 $lang['Searching...'] = 'Ricerca ...';
 $lang['new'] = 'nuovo';
+$lang['Default photos order'] = 'Ordinamento di default delle foto';
+$lang['Activate icon "new" next to albums and pictures'] = 'Visualizzare l\'icona "nuovo" a fianco degli album e delle foto';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Non potete impostare l\'ordine predefinito delle foto perché avete un\'impostazione personalizzata nella configurazione locale';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Avete specificato <i>$conf[\'order_by\']</i> nel vostro file di configurazione, questo parametro è obsoleto, si prega di eliminarlo o rinominarlo in <i>$conf[\'order_by_custom\']</i> !';
+$lang['Add a criteria'] = 'Aggiungere un criterio';
+$lang['... or '] = '... oppure ';
+$lang['Create'] = 'Creare';
+$lang['Start Upload'] = 'Avviare il trasferimento';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Uzate il modulo Flash. Dei problemi? Provate allora con il <a href="%s">modulo HTML</a>';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Uzate il modulo HTML. Provate con il <a href="%s">modulo Flash</a>';
+$lang['Maximum file size: %sB.'] = 'Grandezza massima dei file : %sB.';
+$lang['Allowed file types: %s.'] = 'Tipi di file autorizzati : %s.';
+$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Risoluzione massima approssimativa : %dM pixels (sia %dx%d pixels)';
+$lang['Manage Permissions'] = 'Gestire i permessi';
+$lang['Photo %s of %s'] = 'Foto %s su %s';
+$lang['show details'] = 'mostrare i dettagli';
+$lang['hide details'] = 'nascondere i dettagli';
+$lang['Merge tags'] = 'Fusionare i tags';
+$lang['Select the destination tag'] = 'Selezionare il tag di destinazione';
+$lang['(this tag will be deleted)'] = '(questo tag sara cancellato)';
+$lang['Confirm merge'] = 'Confermare la fusione';
+$lang['Merge selected tags'] = 'Fusionare i tags selezionati';
+$lang['No destination tag selected'] = 'Non avete selezionato il tag di destinazione';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'i tags <em>%s</em> sono stati fuzionati nel tag <em>%s</em>';
+$lang['Select at least two tags for merging'] = 'Selezionare almeno due tag da fuzionare';
+$lang['Average rate'] = 'Voto medio';
+$lang['Rate'] = 'Voto';
+$lang['Learn more'] = 'Per saperne di più';
+$lang['Select an album'] = 'Selezionare un album';
+$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Di default, Piwigo creera la nuova foto dimensioni web a partire della foto HD (alta definizione)';
+$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Se la foto HD non è disponibile e la foto dimensioni web è più grande delle dimensioni qui di seguito, allora Piwigo la considererà come una foto HD e creera la nuova foto dimensioni web';
+$lang['An error has occured during upgrade.'] = 'Si è verificato un\'errore durante l\'aggiornamento';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Non è stato possibile estrarre i file. Verificare i permessi dei file della vostra installazione.<br><a href="%s">Cliccare qui per visualizzare il rapporto d\'errore</a>';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo non può recuperare i file d\'aggiornamento dal server';
 ?>
\ No newline at end of file
