@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Italiano [IT]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=424
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -35,7 +35,6 @@ $lang_info['direction'] = 'ltr';
 $lang_info['code'] = 'it';
 $lang_info['zero_plural'] = false;
 
-$lang['%.2f (rated %d times)'] = '%.2f (votata %d volte)';
 $lang['%d Kb'] = '%d Ko';
 $lang['%d album updated'] = '%d album aggiornato';
 $lang['%d albums updated'] = '%d album aggiornati';
@@ -56,8 +55,6 @@ $lang['All tags'] = 'Tutti i tags';
 $lang['Any tag'] = 'Qualsiasi tag';
 $lang['At least one listed rule must be satisfied.'] = 'Almeno una delle regole elencate deve essere soddisfatta.';
 $lang['At least one tag must match'] = 'Almeno un tag deve corrispondere';
-$lang['Author'] = 'Autore';
-$lang['Average rate'] = 'Voto medio';
 $lang['Albums'] = 'Album';
 $lang['Album'] = 'Album';
 $lang['Close this window'] = 'Chiudi questa finestra';
@@ -91,9 +88,6 @@ $lang['Links'] = 'Links';
 $lang['N/A'] = 'Non disponibile';
 $lang['New on %s'] = 'Nuovo il %s';
 $lang['New password confirmation does not correspond'] = 'La conferma della nuova password non corrisponde';
-$lang['New password sent by email'] = 'La nuova password ti è stata inviata via email';
-$lang['No email address'] = 'Nessun indirizzo email';
-$lang['No classic user matches this email address'] = 'Non esiste nessun utente con questo indirizzo email';
 $lang['Notification'] = 'Notifiche RSS';
 $lang['Number of items'] = 'Numero di elementi';
 $lang['Original dimensions'] = 'Dimensioni originali';
@@ -104,7 +98,6 @@ $lang['Posted on'] = 'Inviato il';
 $lang['Profile'] = 'Profilo';
 $lang['Quick connect'] = 'Connessione veloce';
 $lang['RSS feed'] = 'Feed RSS';
-$lang['Rate'] = 'Voto';
 $lang['Register'] = 'Registrati';
 $lang['Registration'] = 'Registrazione';
 $lang['Related tags'] = 'Tags correlati';
@@ -114,10 +107,9 @@ $lang['Search rules'] = 'Criteri di ricerca';
 $lang['Search tags'] = 'Ricercare i tags';
 $lang['Search'] = 'Cerca';
 $lang['display available tags'] = 'Mostra i tags disponibili';
-$lang['Send new password'] = 'Inviare una nuova password';
 $lang['Since'] = 'Dal';
 $lang['Sort by'] = 'Ordina per';
-$lang['Sort order'] = 'Tipo di ordinamento';
+$lang['Sort order'] = 'Ordinamento';
 $lang['Tag'] = 'Tag';
 $lang['Tags'] = 'Tags';
 $lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'L\'RSS Feed notifica delle novità della galleria: nuove foto, nuovi album, nuovi commenti. Da usare con un lettore RSS Feed.';
@@ -229,10 +221,8 @@ $lang['month'][8] = 'Agosto';
 $lang['month'][9] = 'Settembre';
 $lang['Most visited'] = 'Le più viste';
 $lang['display most visited photos'] = 'Mostra le foto le più viste';
-$lang['The number of photos per row must be a not null scalar'] = 'Il numero di foto per riga deve essere un intero non nullo';
-$lang['Number of photos per row'] = 'Numero di miniature per riga';
-$lang['The number of rows per page must be a not null scalar'] = 'Il numero di righe per pagina deve essere un intero non nullo';
-$lang['Number of rows per page'] = 'Numero di righe per pagina';
+$lang['The number of photos per page must be a not null scalar'] = 'Il numero di foto per pagina deve essere un intero non nullo';
+$lang['Number of photos per page'] = 'Numero di miniature per pagina';
 $lang['Unknown identifier'] = 'Identificante sconosciuto';
 $lang['New password'] = 'Nuova password';
 $lang['Rate this photo'] = 'Vota questa foto';
@@ -312,7 +302,6 @@ $lang['Admin: %s'] = 'Amministrazione: %s';
 $lang['Registration of %s'] = 'Registrazione di %s';
 $lang['Album: %s'] = 'Album: %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Lo status dell\'utente "guest" non è conforme, viene usato lo status di default. Per favore avvisa il webmaster.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Amministratore, webmaster e utente speciale non possono utilizzare questo metodo';
 $lang['this email address is already in use'] = 'un utente usa già questo indirizzo mail';
 $lang['Album results for'] = 'Risultati degli album per';
 $lang['Tag results for'] = 'Risultato dei tag per';
@@ -324,7 +313,7 @@ $lang['Not repeat the slideshow'] = 'Non ricominciare proiezione';
 $lang['Reduce diaporama speed'] = 'Ralentare la velocità proiezione';
 $lang['Accelerate diaporama speed'] = 'Accelerare la velocità proiezione';
 $lang['Submit'] = 'Confermare';
-$lang['Yes'] = 'Si';
+$lang['Yes'] = 'Sì';
 $lang['No'] = 'No';
 $lang['%d photo']='%d foto';
 $lang['%d photos']='%d foto';
@@ -359,4 +348,30 @@ $lang['This author removed the comment with id %d'] = 'Questo autore ha cancella
 $lang['delete this comment'] = 'Cancellare questo commento';
 $lang['validate this comment'] = 'Approvare questo commento';
 $lang['html tags are not allowed in login'] = 'I tag HTML non sono ammessi nel login';
+$lang['Enter a username or email address'] = 'Inserisci il tuo nome utente o indirizzo email';
+$lang['Invalid username or email'] = 'Nome utente o indirizzo email non valido';
+$lang['Password reset is not allowed for this user'] = 'Il rinnovo della password non è consentito per questo utente';
+$lang['User "%s" has no email address, password reset is not possible'] = 'L\'utente "%s" non ha nessun indirizzo email, il rinnovo della password è impossibile';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Qualcuno ha chiesto di rinnovare la propria password per l\'utente seguente :';
+$lang['Username "%s" on gallery %s'] = 'Utente "%s" sur la galerie %s';
+$lang['To reset your password, visit the following address:'] = 'Per rinnovare la vostra password, cliccare sul link qui sotto :';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Se si tratta di un\'errore, ignorare questo messaggio e la richiesta non sarà presa in considerazione';
+$lang['Password Reset'] = 'Rinnovare la vostra password';
+$lang['Check your email for the confirmation link'] = 'Controllare la posta elettronica per trovare il link di conferma';
+$lang['Invalid key'] = 'Chiave non valida';
+$lang['The passwords do not match'] = 'Le password non coincidono';
+$lang['Your password has been reset'] = 'La password è stata reimpostata';
+$lang['Return to home page'] = 'Ritornare alla home page';
+$lang['Please enter your username or email address.'] = 'Grazie d\'inserire il nome utente o l\'indirizzo email';
+$lang['You will receive a link to create a new password via email.'] = 'Via email, riceverete un link da cliccare per rinnovare la vostra password';
+$lang['Username or email'] = 'Nome utente o indirizzo email';
+$lang['Change my password'] = 'Cambiare la mia password';
+$lang['Enter your new password below.'] = 'Immettere la nuova password qui sotto';
+$lang['Author'] = 'Autore';
+$lang['%d rates'] = '%d voti';
+$lang['Rating score'] = 'Punteggio';
+$lang['Reset Password'] = 'Reinizzializzare la password';
+$lang['EXIF Metadata'] = 'Dati EXIF';
+$lang['IPTC Metadata'] = 'Dati IPTC';
+
 ?>
\ No newline at end of file
