@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'შევატყო
 $lang['Email admins when a comment requires validation'] = 'შევატყობინოთ ადმინისტრატორს შესამოწმებელი კომანტარის შესახებ';
 $lang['Environment'] = 'გარემოცვა';
 $lang['Form'] = 'მოქმედებები';
-$lang['Gallery URL'] = 'გალერეის მისამართი';
 $lang['Gallery title'] = 'გალერეის სახელი';
 $lang['Grant selected groups'] = 'ნება დავრთოთ რჩეულ ჯგუფებს';
 $lang['Grant selected users'] = 'ნება დავრთოთ რჩეულ მომხმარებლებს';
@@ -625,11 +624,8 @@ $lang['Privacy level set to "%s"'] = 'დავაყენოთ დაშვ
 $lang['Album "%s" now contains %d photos'] = 'კატეგორია "%s" შეიცავს ამჟამად %d ფოტოს';
 $lang['Manage this set of %d photos'] = 'ამ კრებულის რედაქტირება, შემცველობით %d Fოტო';
 $lang['Select files'] = 'ავირჩიოთ ფაილები';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG ფაილები ან ZIP არქივი JPEG ფაილებით შიგნით.';
 $lang['Everybody'] = 'ყველა';
 $lang['Who can see these photos?'] = 'ვის შეუძლია ნახოს ეს ფოტოები?';
-$lang['... or switch to the old style form'] = '... ან გადართეთ ფორმის ძველ სახეზე';
-$lang['... or switch to the multiple files form'] = '... ან გადართეთ მულტი ატვირთვის ფორმაზე';
 $lang['The websize maximum width must be a number between %d and %d'] = 'ფოტოს მაქსიმალური სიგანე უნდა იყოს რიცხვი %d და %d შორის';
 $lang['The websize maximum height must be a number between %d and %d'] = 'ფოტოს მაქსიმალური სიმაღლე უნდა იყოს რიცხვი %d და %d შორის';
 $lang['The websize image quality must be a number between %d and %d'] = 'ფოტოს ხარისხი უნდა იყოს რიცხვით %d და %d შორის';
@@ -798,5 +794,26 @@ $lang['new'] = 'ახალი';
 $lang['No results'] = 'შედეგი არ არის';
 $lang['Searching...'] = 'ძიება...';
 $lang['Type in a search term'] = 'ჩაწერეთ მოსაძებნი სიტყვა';
+$lang['Learn more'] = 'გავიგოთ მეტი';
+$lang['Rate'] = 'შეფასება';
+$lang['Average rate'] = 'საშუალო ქულა';
+$lang['An error has occured during upgrade.'] = 'განახლების დროს მოხდა შეცდომა.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'ამოარქივების დროს მოხდა შეცდომა. გთხოვთ, შეამოწმეთ დაშვების უფლება piwigo–ს ფოლდერთან.<br><a href="%s">დაკლიკეთ, რათა ნახოთ ინფორმაცია შეცდომაზე</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo ვერ იღებს განახლების ფაილებს სერვერიდან';
+$lang['Save Template Directory'] = 'შევინახოთ დირექტორიის შაბლონი';
+$lang['Dump Database'] = 'მონაცემთა ბაზის წაშლა';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'ჩავრთოთ ისტორიის მონაცემები (გაფრთხილება: შესაძლებელია სერვერზე მეხსიერების ლიმიტის  გადაჭარბება)';
+$lang['Unable to write new local directory.'] = 'შეუძლებელია ახალი ლოკალური დირექტორიის ჩაწერა.';
+$lang['Unable to send template directory.'] = 'შეუძლებელია შაბლონის დირექტორიის გაგზავნა.';
+$lang['Unable to dump database.'] = 'შეუძლებელია მონაცემთა ბაზის წაშლა.';
+$lang['Update in progress... Please wait.'] = 'მიმდინარეობს განახლების პროცესი... გთხოვთ დაიცადოთ.';
+$lang['Update to Piwigo %s'] = 'განაახლეთ Piwigo %s';
+$lang['Two updates are available'] = 'ორი განახლებაა ხელმისაწვდომი';
+$lang['This is a minor update, with only bug corrections.'] = 'ეს მცირე განახლებაა, მხოლოდ შეცდომების შესწორება.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'ეს ძალიან დიდი განახლებაა <a href="%s">საინტერესო სიახლეებით</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'თემების და პლაგინების ნაწილი ჯერჯერობით არ არის ხელმისაწვდომი.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'თქვენ პირდაპირ შეგიძლიათ  Piwigo %s გადახვიდეთ,  Piwigo %s განახლების გარეშე(რეკომენდირებულია).';
+
+
 
 ?>
\ No newline at end of file
