@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'Stuur email naar beheer
 $lang['Email admins when a comment requires validation'] = 'Stuur email naar beheerders wanneer een commantaar validatie nodig heeft';
 $lang['Environment'] = 'Omgeving';
 $lang['Form'] = 'Formulier';
-$lang['Gallery URL'] = 'Galerie URL';
 $lang['Gallery title'] = 'Galerie-titel';
 $lang['Grant selected groups'] = 'Toegang geselecteerde groepen';
 $lang['Grant selected users'] = 'Toegang geselecteerde gebruikers';
@@ -615,11 +614,8 @@ $lang['Privacy level set to "%s"'] = 'Privacy-niveau staat nu op "%s"';
 $lang['Album "%s" now contains %d photos'] = 'Categorie "%s" bevat nu %d foto\'s';
 $lang['Manage this set of %d photos'] = 'Beheer deze reeks van %d foto\'s';
 $lang['Select files'] = 'Selecteer bestanden';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG bestanden of ZIP bestanden die JPEG bestanden bevatten aub.';
 $lang['Everybody'] = 'Iedereen';
 $lang['Who can see these photos?'] = 'Wie mag deze foto\'s zien?';
-$lang['... or switch to the old style form'] = '... of schakel om naar het oude-stijl formulier';
-$lang['... or switch to the multiple files form'] = '... of schakel om naar het meervoudige bestanden formulier';
 $lang['The websize maximum width must be a number between %d and %d'] = 'De webgrootte maximum breedte moet liggen tussen %d en %d';
 $lang['The websize maximum height must be a number between %d and %d'] = 'De webgrootte maximum hoogte moet liggen tussen %d en %d';
 $lang['The websize image quality must be a number between %d and %d'] = 'De webgrootte afbeeldingskwaliteit moet liggen tussen %d en %d';
@@ -785,6 +781,88 @@ $lang['WARNING! This plugin does not seem to be compatible with this version of
 $lang['Do you want to activate anyway?'] = 'Wilt u desondanks activeren?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'DEZE PLUGIN IS NU ONDERDEEL VAN PIWIGO CORE! VERWIJDER DE PLUGIN NU.';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'FOUT: DEZE PLUGIN MIST MAAR IS GEINSTALEERD! DEINSTALLEER DE PLUGIN NU.';
+$lang['Regenerate Thumbnails'] = 'Hergenereer Thumbnails';
+$lang['Thumbnails generation in progress...'] = 'Bezig met genereren van thumbnails...';
+$lang['%s thumbnails have been regenerated'] = '%s thumbnails zijn opnieuw gegenereerd.';
+$lang['%s thumbnails can not be regenerated'] = '%s thumbnails kunnen niet opnieuw worden gegenereerd.';
+$lang['Regenerate Websize Photos'] = 'Hergenereer webformaat foto\'s.';
+$lang['Photos generation in progress...'] = 'Bezig met hergenereren foto\'s...';
+$lang['%s photos have been regenerated'] = '%s foto\'s zijn hergegenereerd.';
+$lang['%s photos can not be regenerated'] = '%s foto\'s konden niet opnieuw gegenereerd worden.';
 $lang['display'] = 'toon';
-
+$lang['new'] = 'nieuw';
+$lang['No results'] = 'Geen resultaten';
+$lang['Searching...'] = 'Bezig met zoeken...';
+$lang['Type in a search term'] = 'Type een zoekterm in';
+$lang['Activate icon "new" next to albums and pictures'] = 'Activeer "nieuw" pictogram naast albums en afbeeldingen';
+$lang['Deactivate all'] = 'Deactiveer alles';
+$lang['Default photos order'] = 'Standaard foto volgorde';
+$lang['Restore'] = 'Herstel';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Herstel de standaard instellingen. Je zal alle plugin instellingen kwijtraken!';
+$lang['Show menubar'] = 'Toon menubalk';
+$lang['Updates'] = 'Updates';
+$lang['Update in progress... Please wait.'] = 'Bezig met updaten... Even geduld aub';
+$lang['Ignore this update'] = 'Negeer deze update';
+$lang['Reset ignored updates'] = 'Reset genegeerde updates';
+$lang['Update All'] = 'Update Alles';
+$lang['ERROR'] = 'ERROR';
+$lang['Update Complete'] = 'Update klaar';
+$lang['Piwigo Update'] = 'Piwigo Update';
+$lang['Extensions Update'] = 'Uitbreidingen Update';
+$lang['All extensions are up to date.'] = 'Alle uitbreidingen zijn bijgewerkt.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'De volgende plugins zouden niet compatibel kunnen zijn met de nieuwe versie van Piwigo:';
+$lang['Add a criteria'] = 'Voeg een criterium toe';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'U kan geen standaard foto volgorde aanmaken, omdat u een aangepaste instelling in uw locale configuratie heeft.';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'U heeft <i>$conf[\'order_by\']</i> in uw lokale configuratie bestand gespecificeerd. Deze parameter is verouderd, verwijder het of hernoem het naar <i>$conf[\'order_by_custom\']</i> !';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'De volgende thema\'s zijn mogelijk niet compatibel met de nieuwe versie van Piwigo:';
+$lang['I decide to update anyway'] = 'Ik besluit om alsnog te updaten';
+$lang['Update to Piwigo %s'] = 'Update naar Piwigo %s';
+$lang['Two updates are available'] = 'Twee updates zijn beschikbaar';
+$lang['This is a minor update, with only bug corrections.'] = 'Dit is een kleine update, met alleen wat gerepareerde foutjes.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Dit is een grote update, met <a href="%s">allerlei nieuwe mogelijkheden</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'Sommige thema\'s en plugins zijn mogelijk nog niet beschikbaar.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'U kunt gelijk naar Piwigo %s updaten, zonder eerst up te daten naar Piwigo %s (aanbevolen).';
+$lang['Save Template Directory'] = 'Sla sjabloon direcotry op';
+$lang['Dump Database'] = 'Dump Database';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Gebruik geschiedenis data (Waarschuwing: het geheugen limiet van de server kan overschreden worden).';
+$lang['Unable to write new local directory.'] = 'Kan niet naar de lokale map schrijven.';
+$lang['Unable to send template directory.'] = 'Kan geen sjabloon map sturen.';
+$lang['Unable to dump database.'] = 'Kan de database niet dumpen.';
+$lang['Some upgrades are available for extensions.'] = 'Er zijn sommige updates beschikbaar voor de plugins.';
+$lang['Ignore All'] = 'Negeer alles';
+$lang['Crop'] = 'Inkorten';
+$lang['Width'] = 'Breedte';
+$lang['Height'] = 'Hoogte';
+$lang['Follow Orientation'] = 'Volg orientatie';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Als je thumbnails wilt hergenereren, ga dan naar de <a href="%s">Batch Manager</a>.';
+$lang['Graphics Library'] = 'Afbeeldings bibliotheek';
+$lang['Average rate'] = 'Gemiddelde waardering';
+$lang['Rate'] = 'Waardering';
+$lang['Learn more'] = 'Leer meer';
+$lang['An error has occured during upgrade.'] = 'Er is iets foutgegaan bij het bijwerken van Piwigo naar de nieuwste versie.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Er is iets foutgegaan bij het uitpakken. Controleer de bestandstoegangen van uw Piwigo-installatie.<br><a href="%s">Klik kier om de fout-logging weer te geven</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo kan het upgrade-bestand niet van de server verkrijgen';
+$lang['... or '] = '... of ';
+$lang['Create'] = 'Aanmaken';
+$lang['Start Upload'] = 'Start Upload';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Je gebruikt de Flash uploader. Problemen? Probeer de <a href="%s">Browser uploader</a> inplaats.';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Je gebruikt de Browser uploader. Problemen? Probeer de  <a href="%s">Flash uploader</a> inplaats.';
+$lang['Maximum file size: %sB.'] = 'Maximum bestands omvang: %sB.';
+$lang['Allowed file types: %s.'] = 'Toegestane bestands typen: %s.';
+$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Geschatte maximale resolutie: %dM pixels (dat is %dx%d pixels).';
+$lang['Manage Permissions'] = 'Beheer Permissies';
+$lang['Photo %s of %s'] = 'Foto %s of %s';
+$lang['show details'] = 'Toon details';
+$lang['hide details'] = 'Verberg details';
+$lang['Merge tags'] = 'Voeg tags samen';
+$lang['Select the destination tag'] = 'Kies de bestemmings tag';
+$lang['(this tag will be deleted)'] = '(Deze tag wordt verwijderd)';
+$lang['Confirm merge'] = 'Bevestig samenvoegen';
+$lang['Merge selected tags'] = 'Voeg geselecteerde tags samen';
+$lang['No destination tag selected'] = 'Geen bestemmings tag geselecteerd';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Tags <em>%s</em> samengevoegd in tag <em>%s</em>';
+$lang['Select at least two tags for merging'] = 'Selecteer ten minste twee tags om samen te voegen';
+$lang['Select an album'] = 'Kies een album';
+$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Standaard zal Piwigo een nieuwe web formaat foto aanmaken van de HD (high definition) versie van je foto.';
+$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Als geen HD beschikbaar is en de huidige web formaat foto is groter dan de nieuwe afmetingen, dan zal Piwigo het als HD gebruiken en daar een web formaat foto van maken.';
 ?>
\ No newline at end of file
