@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Nederlands [NL]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=429
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -35,7 +35,6 @@ $lang_info['direction'] = 'ltr';
 $lang_info['code'] = 'nl';
 $lang_info['zero_plural'] = true;
 
-$lang['%.2f (rated %d times)'] = '%.2f (waardering %d aantal x)';
 $lang['%d Kb'] = '%d Kb';
 $lang['%d album updated'] = '%d categorie bijgewerkt';
 $lang['%d albums updated'] = '%d categorieën bijgewerkt';
@@ -57,7 +56,6 @@ $lang['Any tag'] = 'Elke tag';
 $lang['At least one listed rule must be satisfied.'] = 'Op zijn minst moet aan één regel worden voldaan.';
 $lang['At least one tag must match'] = 'Op zijn minst moet een tag kloppen';
 $lang['Author'] = 'Maker';
-$lang['Average rate'] = 'Gemiddelde waardering';
 $lang['Albums'] = 'Categorieën';
 $lang['Album'] = 'Categorie';
 $lang['Close this window'] = 'Sluit dit venster';
@@ -92,9 +90,6 @@ $lang['Links'] = 'Links';
 $lang['N/A'] = 'Niet bekend';
 $lang['New on %s'] = 'Nieuw op %s';
 $lang['New password confirmation does not correspond'] = 'Nieuw wachtwoord bevestiging komt niet overeen';
-$lang['New password sent by email'] = 'Nieuw wachtwoord is verzonden per email';
-$lang['No email address'] = 'Geen email-adres';
-$lang['No classic user matches this email address'] = 'Geen gebruiker gevonden met dit email-adres';
 $lang['Notification'] = 'Meldingen';
 $lang['Number of items'] = 'Aantal items';
 $lang['Original dimensions'] = 'Originele dimensies';
@@ -105,7 +100,6 @@ $lang['Posted on'] = 'Geplaatst op';
 $lang['Profile'] = 'Profiel';
 $lang['Quick connect'] = 'Snel inloggen';
 $lang['RSS feed'] = 'RSS feed';
-$lang['Rate'] = 'Waardering';
 $lang['Register'] = 'Registreren';
 $lang['Registration'] = 'Registratie';
 $lang['Related tags'] = 'Aanverwante tags';
@@ -115,7 +109,6 @@ $lang['Search rules'] = 'Zoekregels';
 $lang['Search tags'] = 'Zoek tags';
 $lang['Search'] = 'Zoeken';
 $lang['display available tags'] = 'Toon beschikbare tags';
-$lang['Send new password'] = 'Stuur nieuw wachtwoord';
 $lang['Since'] = 'Sinds';
 $lang['Sort by'] = 'Sorteren op';
 $lang['Sort order'] = 'Sorteervolgorde';
@@ -231,10 +224,8 @@ $lang['month'][8] = 'Augustus';
 $lang['month'][9] = 'September';
 $lang['Most visited'] = 'Meest bekeken';
 $lang['display most visited photos'] = 'Toon de meest bekeken afbeelding';
-$lang['The number of photos per row must be a not null scalar'] = 'Het aantal afbeeldingen per rij mag geen ongeldige deling zijn';
-$lang['Number of photos per row'] = 'Aantal afbeeldingen per rij';
-$lang['The number of rows per page must be a not null scalar'] = 'Het aantal rijen per pagina mag geen ongeldige deling zijn';
-$lang['Number of rows per page'] = 'Aantal rijen per pagina';
+$lang['The number of photos per page must be a not null scalar'] = 'Het aantal afbeeldingen per pagina mag geen ongeldige deling zijn';
+$lang['Number of photos per page'] = 'Aantal afbeeldingen per pagina';
 $lang['Unknown identifier'] = 'Onbekend herkenningsteken';
 $lang['New password'] = 'Nieuw wachtwoord';
 $lang['Rate this photo'] = 'Waardeer deze afbeelding';
@@ -314,7 +305,6 @@ $lang['Admin: %s'] = 'Beheerder: %s';
 $lang['Registration of %s'] = 'Registratie van %s';
 $lang['Album: %s'] = 'Categorie: %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Foutieve status voor gebruiker "guest", gebruik standaard status. Waarschuw de webbeheerder.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Administrator, webbeheerder en speciale gebruiker kunnen deze methode niet gebruiken';
 $lang['this email address is already in use'] = 'Een andere gebruiker maakt al gebruik van dit email-adres';
 $lang['Album results for'] = 'Categorie resultaten voor';
 $lang['Tag results for'] = 'Tag resultaten voor';
@@ -360,5 +350,29 @@ $lang['This author modified following comment:'] = 'Deze bewerker wijzigde het v
 $lang['This author removed the comment with id %d'] = 'This author removed the comment with id %d';
 $lang['validate this comment'] = 'Valideer dit commentaar';
 $lang['html tags are not allowed in login'] = 'html tags zijn niet toegestaan in login';
+$lang['%d rates'] = '%d stemmen';
+$lang['Rating score'] = 'Waarderings score';
+$lang['Enter a username or email address'] = 'Voer je gebruikersnaam en e-mailadres in';
+$lang['Invalid username or email'] = 'Gebruikersnaam of e-mailadres is ongeldig';
+$lang['Password reset is not allowed for this user'] = 'Deze gebruiker heeft geen toestemming om het paswoord te vernieuwen';
+$lang['User "%s" has no email address, password reset is not possible'] = 'Gebruiker "%s" heeft geen e-mailadres daarom kan het paswoord niet vernieuwd worden';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Iemand heeft verzocht om het paswoord te vernieuwen voor het volgende account:';
+$lang['Username "%s" on gallery %s'] = 'Gebruikersnaam "%s" voor gallery %s';
+$lang['To reset your password, visit the following address:'] = 'Om je paswoord te vernieuwen kun je het volgende adres bezoeken:';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Als dit een vergissing was kun je deze e-mail negeren, er zal dan niets gewijzigd worden.';
+$lang['Password Reset'] = 'Vernieuw paswoord';
+$lang['Check your email for the confirmation link'] = 'Kijk in je mail box voor de bevestigings link';
+$lang['Invalid key'] = 'Onjuiste sleutel';
+$lang['The passwords do not match'] = 'De paswoorden zijn niet gelijk';
+$lang['Your password has been reset'] = 'Je paswoord is vernieuwd';
+$lang['Return to home page'] = 'Keer terug naar de home page';
+$lang['Please enter your username or email address.'] = 'Voer je gebruikersnaam en e-mailadres in.';
+$lang['You will receive a link to create a new password via email.'] = 'Via e-mail krijg je een link om je paswoord te vernieuwen.';
+$lang['Username or email'] = 'Gebruikersnaam of e-mail';
+$lang['Change my password'] = 'Vernieuw mijn paswoord';
+$lang['Enter your new password below.'] = 'Voer hieronder je nieuwe paswoord in.';
+$lang['Reset Password'] = 'Vernieuw Paswoord';
+$lang['EXIF Metadata'] = 'EXIF Metagegevens';
+$lang['IPTC Metadata'] = 'IPTC Metagegevens';
 
 ?>
\ No newline at end of file
