@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Norwegian [NO]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=483
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -47,7 +47,6 @@ $lang['Email: %s'] = "Email: %s";
 $lang['Admin: %s'] = "Admin: %s";
 $lang['Registration of %s'] = "Registrering av %s";
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = "Feil status for bruker \"gjest\", default status vil bli brukt. Vennligst kontakt webmaster.";
-$lang['Administrator, webmaster and special user cannot use this method'] = "Administrator, webmaster og spesial bruker kan ikke bruke denne metoden";
 $lang['this email address is already in use'] = "En annen bruker har allerede denne mail addressen";
 $lang['Tag results for'] = "Tag resultat for";
 $lang['from %s to %s'] = "fra %s til %s";
@@ -147,11 +146,7 @@ $lang['Any tag'] = 'Valgte ord';
 $lang['At least one listed rule must be satisfied.'] = 'Minst en listet regel må være med.';
 $lang['At least one tag must match'] = 'Minst et ord må stemme';
 $lang['Author'] = 'Forfatter';
-$lang['Average rate'] = 'Gjennomsnittlig rate';
 $lang['New password confirmation does not correspond'] = 'Nytt passord bekreftelse er ikke lik';
-$lang['New password sent by email'] = 'Nytt passord sendt via email';
-$lang['No email address'] = 'Ingen email addresse';
-$lang['No classic user matches this email address'] = 'Ingen kjent bruker har denne email addressen';
 $lang['Notification'] = 'Til informasjon';
 $lang['Number of items'] = 'Antall poster';
 $lang['Original dimensions'] = 'Orginal dimensjoner';
@@ -162,7 +157,6 @@ $lang['Posted on'] = 'Postet den';
 $lang['Profile'] = 'Profil';
 $lang['Quick connect'] = 'Hurtig tilkobling';
 $lang['RSS feed'] = 'RSS mating';
-$lang['Rate'] = 'Rangere';
 $lang['Register'] = 'Registrere';
 $lang['Registration'] = 'Registrering';
 $lang['Related tags'] = 'Relaterte ord';
@@ -172,7 +166,6 @@ $lang['Search rules'] = 'Søke kriterie';
 $lang['Search tags'] = 'Søke ord';
 $lang['Search'] = 'Søk';
 $lang['display available tags'] = 'Se tilgjengelige tags';
-$lang['Send new password'] = 'Send nytt passord';
 $lang['Since'] = 'Siden';
 $lang['Sort by'] = 'Sorter etter';
 $lang['Sort order'] = 'Sorter alfabetisk';
@@ -267,10 +260,8 @@ $lang['return to normal view mode'] = 'tilbake til normalvisning';
 $lang['display a calendar by posted date'] = 'vis en kalender etter dato postet';
 $lang['Most visited'] = 'Mest besøkte';
 $lang['display most visited photos'] = 'vis mest besøkte bilder';
-$lang['The number of photos per row must be a not null scalar'] = 'Antall bilder per rad må være større en null';
-$lang['Number of photos per row'] = 'Antall bilder per rad';
-$lang['The number of rows per page must be a not null scalar'] = 'Antall rader per side må være større en null';
-$lang['Number of rows per page'] = 'Antall rader per side';
+$lang['The number of photos per page must be a not null scalar'] = 'Antall bilder per side må være større en null';
+$lang['Number of photos per page'] = 'Antall bilder per side';
 $lang['Unknown identifier'] = 'Ukjent identifier';
 $lang['New password'] = 'Nytt passord';
 $lang['Rate this photo'] = 'Gi karakter på dette bildet';
@@ -301,7 +292,6 @@ $lang['this login is already used'] = 'denne innloggingen er allerede i bruk';
 $lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'mail addresse må være tilsvarende xxx@yyy.eee (eksempel : jack@altern.org)';
 $lang['please enter your password again'] = 'vennligst skriv ditt passord på ny';
 $lang['Auto login'] = 'Auto innlogging';
-$lang['%.2f (rated %d times)'] = '%.2f (gradert % ganger)';
 $lang['%d Kb'] = '%d Kb';
 $lang['Week %d'] = 'Uke %d';
 $lang['remove this tag from the list'] = 'fjern tag fra denne listen';
