@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'Notificar os administra
 $lang['Email admins when a comment requires validation'] = 'Notificar os administradores quando um comentário necessitar de aprovação';
 $lang['Environment'] = 'Ambiente';
 $lang['Form'] = 'Formulário';
-$lang['Gallery URL'] = 'Endereço (URL) da galeria';
 $lang['Gallery title'] = 'Título da galeria';
 $lang['Grant selected groups'] = 'Permitir os grupos selecionados';
 $lang['Grant selected users'] = 'Permitir os utilizadores selecionados';
@@ -234,7 +233,7 @@ $lang['Prepared time for list of users to send mail is limited. Others users are
 $lang['Time to send mail is limited. Others mails are skipped.'] = 'O tempo para enviar email é limitado. Outros emails serão desconsiderados.';
 $lang['To send ?'] = 'Enviar ?';
 $lang['Last send'] = 'Enviado pela última vez';
-$lang['email'] = 'E-mail';
+$lang['email'] = 'Email';
 $lang['User'] = 'Utilizador';
 $lang['Complementary mail content'] = 'Conteúdo complementar da correspondência';
 $lang['See you soon,'] = 'Até breve,';
@@ -586,8 +585,6 @@ $lang['Menu Management'] = 'Menú';
 $lang['%d of %d photos selected'] = '%d de %d fotos seleccionadas';
 $lang['%d photos uploaded'] = '%d fotos enviadas';
 $lang['+ Add an upload box'] = '+ Adicionar uma caixa de envio';
-$lang['... or switch to the multiple files form'] = '... ou mudar para o formulário de ficheiros múltiplos';
-$lang['... or switch to the old style form'] = '... ou mudar para o formulário antigo';
 $lang['Action'] = 'Acção';
 $lang['Activate field "%s"'] = 'Activar campo "%s"';
 $lang['Activate icon "%s"'] = 'Activar ícone "%s"';
@@ -665,7 +662,6 @@ $lang['Installed Languages'] = 'Linguagens Instaladas';
 $lang['Installed Themes'] = 'Temas Instalados';
 $lang['Instructions to use Piwigo'] = 'Instruções para usar Piwigo';
 $lang['Invert'] = 'Inverter';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'Ficheiros JPEG ou ficheiros ZIP com ficheiros JPEG dentro, por favor.';
 $lang['Keep high definition'] = 'Manter Alta Definição';
 $lang['Language has been successfully installed'] = 'Linguagem instalada com sucesso';
 $lang['Languages'] = 'Linguagens';
@@ -782,5 +778,46 @@ $lang['Do you want to activate anyway?'] = 'Deseja mesmo activar a extensão?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'ESTA EXTENSÃO AGORA É PARTE DO NÚCLEO DE PIWIGO! DESINSTALE-A IMEDIATAMENTE!';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERRO: ESTA EXTENSÃO NÃO EXISTE MAS ESTÁ INSTALADA! DESINSTALE-A AGORA.';
 $lang['Simulation'] = 'Simulação';
+$lang['new'] = 'novo';
+$lang['No results'] = 'Sem resultados';
+$lang['Searching...'] = 'Procurando...';
+$lang['Type in a search term'] = 'Escreva um termo de busca';
+$lang['Learn more'] = 'Saber mais';
+$lang['Rate'] = 'Classificação';
+$lang['Average rate'] = 'Nota média';
+$lang['Activate icon "new" next to albums and pictures'] = 'Mostrar o icon "novo" ao lado dos Álbums e das fotos';
+$lang['Add a criteria'] = 'Adicionar um critério';
+$lang['Deactivate all'] = 'Desactivar tudo';
+$lang['Default photos order'] = 'Ordem padrão das fotos';
+$lang['Restore'] = 'Restaurar';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Restaurar a configuração padrão ? Perderá as configurações pesoiais !';
+$lang['Show menubar'] = 'Mostrar o menú';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Não pode definir uma ordem padrão para as fotos porque tem uma definição na sua configuração local.';																																					
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Especificou <i>$conf[\'order_by\']</i> no seu ficheiro de configuração, este pâremetro esta obsoleto, apaguar ou renomear em <i>$conf[\'order_by_custom\']</i> !';
 $lang['display'] = 'Mostrar';
+$lang['An error has occured during upgrade.'] = 'Ocorreu um erro durante a actualização automática.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Ocorreu um erro durante a extração dos ficheiros. Por favior verifique as permissões de escrita da sua instalação Piwigo.<br><a href="%s">Clique aqui para mostrar o relatório de erros</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo não consegue recuperar o ficheiro de actualização do servidor remoto.';
+$lang['Update in progress... Please wait.'] = 'Actualização em curso... Aguarde, por favor.';
+$lang['Update to Piwigo %s'] = 'Actualizar para Piwigo %s';
+$lang['Two updates are available'] = 'Duas actualizações disponíveis';
+$lang['This is a minor update, with only bug corrections.'] = 'Esta é uma actualização menor, apenas alguns pequenos erros foram corrigidos.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Esta é uma actualização maior, com <a href="%s">novas funcionalidades excitantes</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'Alguns temas e plugins poderão não estar ainda disponíveis.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Pode actualizar para Piwigo %s directamente, sem actualizar primeiro para Piwigo %s (recomendado).';
+$lang['Save Template Directory'] = 'Salvar a pasta de Modelos';
+$lang['Dump Database'] = 'Descarregar Base de Dados';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Incluir dados históricos (Aviso: pode exceder o limite de memória do servidor)';
+$lang['Unable to write new local directory.'] = 'Impossível criar nova pasta local.';
+$lang['Unable to send template directory.'] = 'Impossível enviar pasta de modelos.';
+$lang['Unable to dump database.'] = 'Impossível descarregar base de dados.';
+$lang['ERROR'] = 'ERRO';
+$lang['Update Complete'] = 'Actualização Completa';
+$lang['Piwigo Update'] = 'Actualizar Piwigo';
+$lang['Extensions Update'] = 'Actualizar Extensões';
+$lang['All extensions are up to date.'] = 'Todas as extensões estão actualizadas.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'As seguintes estensões poderão não ser compatíveis com a nova versão de Piwigo:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Os seguintes temas poderão não ser compatíveis com a nova versão de Piwigo:';
+
+
 ?>
\ No newline at end of file
