@@ -1,13 +1,10 @@
 <?php
 // +-----------------------------------------------------------------------+
-// | PhpWebGallery - a PHP based picture gallery                           |
-// | Copyright (C) 2002-2003 Pierrick LE GALL - pierrick@phpwebgallery.net |
-// | Copyright (C) 2003-2007 PhpWebGallery Team - http://phpwebgallery.net |
+// | Piwigo - a PHP based photo gallery                                    |
 // +-----------------------------------------------------------------------+
-// | file          : $Id: common.lang.php 10350 2011-04-13 10:41:49Z patdenice $
-// | last update   : $Date: 2011-04-13 12:41:49 +0200 (Wed, 13 Apr 2011) $
-// | last modifier : $Author: patdenice $
-// | revision      : $Revision: 10350 $
+// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
+// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
 // | This program is free software; you can redistribute it and/or modify  |
 // | it under the terms of the GNU General Public License as published by  |
@@ -25,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Română [RO]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=433
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -60,7 +57,6 @@ $lang['Any tag'] = 'Orice eticheta';
 $lang['At least one listed rule must be satisfied.'] = 'Cel puţin o singură regulă trebuie să fie îndeplinită';
 $lang['At least one tag must match'] = 'Cel puţin o etichetă trebuie să se potriveasca';
 $lang['Author'] = 'Autor';
-$lang['Average rate'] = 'Notă medie';
 $lang['Albums'] = 'Categorii';
 $lang['Album'] = 'Categorie';
 $lang['Close this window'] = 'Inchide această fereastră';
@@ -94,9 +90,6 @@ $lang['Links'] = 'Link-uri';
 $lang['N/A'] = 'N/A';
 $lang['New on %s'] = 'Nou pe %s';
 $lang['New password confirmation does not correspond'] = 'Noua confirmare a parolei nu se potriveşte';
-$lang['New password sent by email'] = 'Noua parolă a fost trimisă prin email';
-$lang['No email address'] = 'Nici o adresă de email';
-$lang['No classic user matches this email address'] = 'Nici un utilizator clasic nu corespunde acestei adrese de e-mail';
 $lang['Notification'] = 'Notificare';
 $lang['Number of items'] = 'Numărul de articole';
 $lang['Original dimensions'] = 'Dimensiuni originale';
@@ -107,7 +100,6 @@ $lang['Posted on'] = 'Postat pe';
 $lang['Profile'] = 'Profil';
 $lang['Quick connect'] = 'Conectare rapidă';
 $lang['RSS feed'] = 'RSS feed';
-$lang['Rate'] = 'Evaluare';
 $lang['Register'] = 'Înscrie';
 $lang['Registration'] = 'Înscriere';
 $lang['Related tags'] = 'Etichete asociate';
@@ -117,7 +109,6 @@ $lang['Search rules'] = 'Criterii de căutare';
 $lang['Search tags'] = 'Caută etichete';
 $lang['Search'] = 'Caută';
 $lang['display available tags'] = 'Vezi etichetele disponibile';
-$lang['Send new password'] = 'Trimite parola nouă';
 $lang['Since'] = 'De la';
 $lang['Sort by'] = 'Sortare după';
 $lang['Sort order'] = 'Ordine de sortare';
@@ -184,7 +175,6 @@ $lang['day'][3] = 'Miercuri';
 $lang['day'][4] = 'Joi';
 $lang['day'][5] = 'Vineri';
 $lang['day'][6] = 'Sâmbătă';
-$lang['%.2f (rated %d times)'] = '%.2f (evaluat de %d ori)';
 $lang['excluded'] = 'exclus';
 $lang['Your favorites'] = 'Preferatele mele';
 $lang['display your favorites photos'] = 'Afişează imaginile mele preferate';
@@ -221,10 +211,8 @@ $lang['return to normal view mode'] = 'Înapoi la vizualizarea normală';
 $lang['display a calendar by posted date'] = 'afişează un calendar în funcţie de data adăugării';
 $lang['Most visited'] = 'Cele mai vizionate';
 $lang['display most visited photos'] = 'afişează imaginile cele mai vizionate';
-$lang['The number of photos per row must be a not null scalar'] = 'Numărul de imagini pe linie trebuie să fie un număr întreg nenul';
-$lang['Number of photos per row'] = 'Numărul de miniaturi pe linie';
-$lang['The number of rows per page must be a not null scalar'] = 'Numărul de linii pe pagină trebuie să fie un număr întreg nenul';
-$lang['Number of rows per page'] = 'Numărul de linii pe pagină';
+$lang['The number of photos per page must be a not null scalar'] = 'Numărul de imagini pe pagină trebuie să fie un număr întreg nenul';
+$lang['Number of photos per page'] = 'Numărul de miniaturi pe pagină';
 $lang['Unknown identifier'] = 'Identificator necunoscut ';
 $lang['New password'] = 'Parolă nouă';
 $lang['Rate this photo'] = 'Evaluează aceasta imagine';
@@ -305,7 +293,6 @@ $lang['Admin: %s'] = 'Administraţie : %s';
 $lang['Registration of %s'] = 'Înregistrare de %s';
 $lang['Album: %s'] = 'Categorie : %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Statutul utilizatorului "invitat" este eronat, se vor folosi  parametrii impliciţi. Va rugăm sa informaţi webmasterul.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Administratorul, webmasterul şi utilizatorul special nu pot folosi aceasta metodă';
 $lang['this email address is already in use'] = 'un alt utilizator foloseşte deja acest e-mail';
 $lang['Album results for'] = 'Rezultatele categoriilor pentru';
 $lang['Tag results for'] = 'Rezultatele  etichetelor pentru';
@@ -364,4 +351,5 @@ $lang['month'][7] = 'Iulie';
 $lang['month'][8] = 'August';
 $lang['month'][9] = 'Septembrie';
 $lang['html tags are not allowed in login'] = 'tag-urile HTML nu sunt permise în login';
+
 ?>
\ No newline at end of file
