@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'Сообщать адм
 $lang['Email admins when a comment requires validation'] = 'Сообщать администратору когда появился комментарий для проверки';
 $lang['Environment'] = 'Окружение';
 $lang['Form'] = 'Действия';
-$lang['Gallery URL'] = 'Адрес галереи';
 $lang['Gallery title'] = 'Название галереи';
 $lang['Grant selected groups'] = 'Разрешить доступ выбранным группам';
 $lang['Grant selected users'] = 'Разрешить доступ выбранным пользователям';
@@ -136,7 +135,6 @@ $lang['Position'] = 'Номер';
 $lang['Preferences'] = 'Настройки';
 $lang['Properties'] = 'Свойства';
 $lang['Random photo'] = 'Случайная фотография';
-$lang['Rate date'] = 'Rate date';
 $lang['Rating by guests'] = 'Оценки от гостей';
 $lang['Rating'] = 'Оценки';
 $lang['Reject'] = 'Отклонить';
@@ -615,11 +613,8 @@ $lang['Privacy level set to "%s"'] = 'Установить уровень дос
 $lang['Album "%s" now contains %d photos'] = 'Категория "%s" содержит сейчас %d фотографий';
 $lang['Manage this set of %d photos'] = 'Редактировать этот набор из %d фотографий';
 $lang['Select files'] = 'Выбрать файлы';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG файлы или ZIP архивы с JPEG файлами внутри, пожалуйста.';
 $lang['Everybody'] = 'Все';
 $lang['Who can see these photos?'] = 'Кто может смотреть эти фотографии?';
-$lang['... or switch to the old style form'] = '... или переключитесь на старый вид формы';
-$lang['... or switch to the multiple files form'] = '... или переключитесь на форму мультизагрузки';
 $lang['The websize maximum width must be a number between %d and %d'] = 'Максимальная ширина изображения должна быть числом между %d и %d';
 $lang['The websize maximum height must be a number between %d and %d'] = 'Максимальная высота изображения должна быть числом между %d и %d';
 $lang['The websize image quality must be a number between %d and %d'] = 'Качество изображения должно быть числом между %d и%d';
@@ -783,5 +778,87 @@ $lang['WARNING! This plugin does not seem to be compatible with this version of
 $lang['Do you want to activate anyway?'] = 'Всё равно хотите активировать?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'ЭТОТ ПЛАГИН СЕЙЧАС УЖЕ ЯВЛЯЕТСЯ ЧАСТЬЮ ЯДРА PIWIGO! УДАЛИТЕ ЕГО СЕЙЧАС!';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ОШИБКА: НЕСМОТРЯ НА ТО, ЧТО ЭТОТ ПЛАГИН УСТАНОВЛЕН, ОН ПОТЕРЯЛСЯ! УДАЛИТЕ ЕГО СЕЙЧАС.';
-
+$lang['new'] = 'новый';
+$lang['No results'] = 'Ничего не найдено';
+$lang['Searching...'] = 'Выполняется поиск...';
+$lang['Type in a search term'] = 'Определите критерий поиска';
+$lang['display'] = 'показать';
+$lang['Activate icon "new" next to albums and pictures'] = 'Активировать иконку "new" рядом с альбомами и фотографиями';
+$lang['Deactivate all'] = 'Деактивировать все';
+$lang['Default photos order'] = 'Порядок фотографий по умолчанию';
+$lang['Restore'] = 'Восстановить';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Восстановление конфигурации по умолчанию. Ваши настройки плагинов будут потеряны!';
+$lang['Show menubar'] = 'Показать меню';
+$lang['Regenerate Thumbnails'] = 'Сгенерить миниатюры заново';
+$lang['Regenerate Websize Photos'] = 'Сгенерить фотографии web размера заново';
+$lang['Thumbnails generation in progress...'] = 'Идет генерация миниатюр ...';
+$lang['Photos generation in progress...'] = 'Идет генерация фотографий ...';
+$lang['%s thumbnails have been regenerated'] = '%s миниатюр было создано заново';
+$lang['%s thumbnails can not be regenerated'] = '%s миниатюр не было создано заново';
+$lang['%s photos have been regenerated'] = '%s фотографий было создано заново';
+$lang['%s photos can not be regenerated'] = '%s фотографий не было создано заново';
+$lang['Updates'] = 'Обновление';
+$lang['Update in progress... Please wait.'] = 'Процесс обновления... Пожалуйста, подождите.';
+$lang['Ignore this update'] = 'Пропустить это обновление';
+$lang['Reset ignored updates'] = 'Сбросить проигнорированные обновления';
+$lang['Update All'] = 'Обновить все';
+$lang['ERROR'] = 'ОШИБКА';
+$lang['Update Complete'] = 'Обновление завершено';
+$lang['Piwigo Update'] = 'Обновление Piwigo';
+$lang['Extensions Update'] = 'обновление плагинов';
+$lang['All extensions are up to date.'] = 'Все плагины обновлены.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Следующие плагины, возможно, не являются совместимыми с новой версией Piwigo:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Следующие темы, возможно, не являются совместимыми с новой версией Piwigo:';
+$lang['I decide to update anyway'] = 'Ну и ладно, всё равно обновить!)';
+$lang['Update to Piwigo %s'] = 'Обновление до версии Piwigo %s';
+$lang['Two updates are available'] = 'Два апдейта доступны';
+$lang['This is a minor update, with only bug corrections.'] = 'Это незначительный апдейт, исправлены небольшие ошибки.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Это основной апдейт, с <a href="%s">новыми восхитительными возможностями</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'Некоторые темы и плагины  все же могут быть не доступны.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Вы можете обновиться до версии  Piwigo %s, минуя апдейт до версии Piwigo %s (рекомендуется).';
+$lang['Save Template Directory'] = 'Сохранить каталог шаблонов';
+$lang['Dump Database'] = 'Дамп базы данных';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Включить данные истории (Предупреждение: память сервера может быть превышена)';
+$lang['Unable to write new local directory.'] = 'Не удалось записать новый локальный каталог.';
+$lang['Unable to send template directory.'] = 'Не удается отправить каталог шаблонов.';
+$lang['Unable to dump database.'] = 'Невозможно сделать дамп базы данных.';
+$lang['Some upgrades are available for extensions.'] = 'Для плагинов доступны некоторые обновления.';
+$lang['Ignore All'] = 'Пропустить все';
+$lang['Crop'] = 'Обрезать';
+$lang['Width'] = 'Ширина';
+$lang['Height'] = 'Высота';
+$lang['Follow Orientation'] = 'Изменить ориентацию';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Если в хотите перегенерить миниатюры, используйте, пожалуйста, <a href="%s">Бач менеджер (Batch Manager)</a>.'; 
+$lang['Graphics Library'] = 'Библиотека изображений';
+$lang['Add a criteria'] = 'Добавить критерий';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Вы не можете определить порядок сортировки фотографий по умолчанию, так как он переопределен в локальных настройках.';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Вы использовали <i>$conf[\'order_by\']</i> в качестве порядка сортировки в локальном файле конфигурации. Этот параметр не рекомендуется для использования. Пожалуйста, удалите его или переименуйте в <i>$conf[\'order_by_custom\']</i> !';
+$lang['Learn more'] = 'Узнать больше';
+$lang['Rate'] = 'Оценка';
+$lang['Average rate'] = 'Средний балл';
+$lang['Rate date'] = 'Дата оценки';
+$lang['... or '] = '... или ';
+$lang['Create'] = 'Создать';
+$lang['Start Upload'] = 'Начать загрузку';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Вы используете Flash-загрузчик. Возникли проблемы? Попробуйте <a href="%s">браузерный загрузчик</a>.';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Вы используете браузерный загрузчик. Попробуйте <a href="%s">Flash-загрузчик</a>.';
+$lang['Maximum file size: %sB.'] = 'Максимальный размер файла: %sB.';
+$lang['Allowed file types: %s.'] = 'Допустимые типы файлов: %s.';
+$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Максимальное разрешение: %dM пикселей (то есть %dx%d пикселей).';
+$lang['Manage Permissions'] = 'Настройка прав доступа';
+$lang['Photo %s of %s'] = 'Фотография %s из %s';
+$lang['show details'] = 'показать подробности';
+$lang['hide details'] = 'скрыть подробности';
+$lang['Merge tags'] = 'Объединить тэги';
+$lang['Select the destination tag'] = 'Выбрать тэг-получатель';
+$lang['(this tag will be deleted)'] = '(этот тэг будет удален)';
+$lang['Confirm merge'] = 'Подтвердите объединение';
+$lang['Merge selected tags'] = 'Объединить выбранные тэги';
+$lang['No destination tag selected'] = 'Тэг-получатель не выбран';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Тэги <em>%s</em> объединены в тэг <em>%s</em>';
+$lang['Select at least two tags for merging'] = 'Выберите по крайней мере два тэга для объединения';
+$lang['Select an album'] = 'Выберите альбом';
+$lang['An error has occured during upgrade.'] = 'Во время обновления произошла ошибка.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Во время распаковки произошла ошибка. Пожалуйста, проверьте права доступа к папке установки piwigo.<br><a href="%s">Нажмите, чтобы посмотреть лог ошибки</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo не может получить файлы обновления с сервера';
 ?>
\ No newline at end of file
