@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Srpski [SR]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=435
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -92,9 +92,6 @@ $lang['Links'] = 'Linkovi';
 $lang['N/A'] = 'N/D';
 $lang['New on %s'] = 'Novi na on %s';
 $lang['New password confirmation does not correspond'] = 'Potvrda nove lozinke ne odgovara';
-$lang['New password sent by email'] = 'Nova lozinka poslana e-mail porukom';
-$lang['No email address'] = 'Nema e-mail adrese';
-$lang['No classic user matches this email address'] = 'Nijedan korisnik se ne poklapa s ovom e-mail adresom';
 $lang['Notification'] = 'Obaveštenje';
 $lang['Number of items'] = 'Broj stavki';
 $lang['Original dimensions'] = 'Izvorne veličine';
@@ -115,7 +112,6 @@ $lang['Search rules'] = 'Pravila pretrage';
 $lang['Search tags'] = 'Tagovi pretrage';
 $lang['Search'] = 'Pretraživanje';
 $lang['display available tags'] = 'Pogledaj dostupne tagove';
-$lang['Send new password'] = 'Pošalji novu lozinku';
 $lang['Since'] = 'Od';
 $lang['Sort by'] = 'Složeno po';
 $lang['Sort order'] = 'Redosled slaganja';
@@ -230,10 +226,8 @@ $lang['month'][8] = 'Avgust';
 $lang['month'][9] = 'Septembar';
 $lang['Most visited'] = 'Najposjećenije';
 $lang['display most visited photos'] = 'prikaz najposjećenijih slika';
-$lang['The number of photos per row must be a not null scalar'] = 'broj slika po redu mora biti celobrojna vrednost';
-$lang['Number of photos per row'] = 'Broj slika po redu';
-$lang['The number of rows per page must be a not null scalar'] = 'Broj redova po stranici mora biti celobrojna vrednost';
-$lang['Number of rows per page'] = 'Broj redova po stranici';
+$lang['The number of photos per page must be a not null scalar'] = 'broj slika po stranici mora biti celobrojna vrednost';
+$lang['Number of photos per page'] = 'Broj slika po stranici';
 $lang['Unknown identifier'] = 'Nepoznata oznaka';
 $lang['New password'] = 'Nova lozinka';
 $lang['Rate this photo'] = 'Oceni ovu sliku';
@@ -313,7 +307,6 @@ $lang['Admin: %s'] = 'Administrator: %s';
 $lang['Registration of %s'] = 'Prijava od %s';
 $lang['Album: %s'] = 'Kategorija: %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Loš status za korisnika "guest", koristi se podrazumevani status. Molimo obavestite webmaster-a.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Administrator, webmaster i posebni korisnik ne mogu koristiti ovu metodu';
 $lang['this email address is already in use'] = 'korisnik već koristi ovu e-mail adresu';
 $lang['Album results for'] = 'Rezultati kategorije za ';
 $lang['Tag results for'] = 'Rezultati tagova za';
