@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Slovenšcina [SL]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=453
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -34,7 +34,6 @@ $lang_info['direction'] = 'ltr';
 $lang_info['code'] = 'sl';
 $lang_info['zero_plural'] = true;
 
-$lang['%.2f (rated %d times)'] = '%.2f (rated %d times, standardno odstopanje = %.2f)';
 $lang['%d Kb'] = '%d Kb';
 $lang['%d album updated'] = '%d kategorija popravljena';
 $lang['%d albums updated'] = '%d kategorij popravljenih';
@@ -54,7 +53,6 @@ $lang['Any tag'] = 'Katerakoli označba';
 $lang['At least one listed rule must be satisfied.'] = 'Vsaj eno pravilo mora biti izpolnjeno.';
 $lang['At least one tag must match'] = 'Vsaj ena označba se mora ujemati';
 $lang['Author'] = 'Avtor';
-$lang['Average rate'] = 'Povprečje';
 $lang['Albums'] = 'Kategorije';
 $lang['Album'] = 'Kategorija';
 $lang['Close this window'] = 'Zapri okno';
@@ -90,9 +88,6 @@ $lang['Links'] = 'Povezave';
 $lang['N/A'] = 'N/A';
 $lang['New on %s'] = 'Nov na %s';
 $lang['New password confirmation does not correspond'] = 'Potrditveno geslo se ne ujema';
-$lang['New password sent by email'] = 'Novo geslo je poslano po e-pošti';
-$lang['No email address'] = 'Brez e-pošte';
-$lang['No classic user matches this email address'] = 'Noben uporabnik ne pripada e-pošti';
 $lang['Notification'] = 'Obvestilo';
 $lang['Number of items'] = 'Število ';
 $lang['Original dimensions'] = 'Originalna velikost';
@@ -103,7 +98,6 @@ $lang['Posted on'] = 'Objavljeno';
 $lang['Profile'] = 'Profil';
 $lang['Quick connect'] = 'Hitra povezava';
 $lang['RSS feed'] = 'RSS vir';
-$lang['Rate'] = 'Glasuj';
 $lang['Register'] = 'Registracija';
 $lang['Registration'] = 'Registracija';
 $lang['Unknown feed identifier'] = 'Neznan identifikator vira';
@@ -158,7 +152,6 @@ $lang['Search rules'] = 'Iskalni kriteriji';
 $lang['Search tags'] = 'Iskalne označbe';
 $lang['Search'] = 'Išci';
 $lang['display available tags'] = 'Prikaži možne označbe';
-$lang['Send new password'] = 'Pošlji novo geslo';
 $lang['Since'] = 'Odkar';
 $lang['Sort by'] = 'Uredi po';
 $lang['Sort order'] = 'Urejeno po';
@@ -204,10 +197,8 @@ $lang['Maximum height must be a number superior to 50'] = 'Maksimalna velikost m
 $lang['Maximum photo width'] = 'Maksimalna dolžina slik';
 $lang['Most visited'] = 'Najbolj obiskana';
 $lang['display most visited photos'] = 'prikaži najbolj obiskane slike';
-$lang['The number of photos per row must be a not null scalar'] = 'Število slik v vrstici, mora biti ne prazno celo število.';
-$lang['Number of photos per row'] = 'Število slik v vrstici';
-$lang['The number of rows per page must be a not null scalar'] = 'Število vrstic na strani, mora biti ne prazno celo število.';
-$lang['Number of rows per page'] = 'Število vrstic na stran';
+$lang['The number of photos per page must be a not null scalar'] = 'Število slik na stran, mora biti ne prazno celo število.';
+$lang['Number of photos per page'] = 'Število slik na stran';
 $lang['Unknown identifier'] = 'Neznan';
 $lang['New password'] = 'Novo geslo';
 $lang['Rate this photo'] = 'Glasuj';
@@ -292,7 +283,6 @@ $lang['Admin: %s'] = 'Administrator: %s';
 $lang['Registration of %s'] = 'Prijavljenih %s';
 $lang['Album: %s'] = 'Kategorija: %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Nepravilen status uporabnika "guest", uporabljen bo privzeti status. Prosim obvestite skrbnika.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Administrator, skrbnik in posebni uporabnik ne morejo uporabljati te metode';
 $lang['this email address is already in use'] = 'email uporablja že drug uporabnik';
 $lang['Album results for'] = 'Category results for';
 $lang['Tag results for'] = 'Rezultat za značke';
@@ -358,5 +348,29 @@ $lang['This author removed the comment with id %d'] = 'Ta uporabnik je odstranil
 $lang['delete this comment'] = 'odstrani komentar';
 $lang['validate this comment'] = 'preveri komentar';
 $lang['html tags are not allowed in login'] = 'pri prijavi niso dovoljene html značke';
+$lang['%d rates'] = '%d točk';
+$lang['Rating score'] = 'Ocena';
+$lang['Enter a username or email address'] = 'Vnesite uporabniško ime ali e-pošto';
+$lang['Invalid username or email'] = 'Nepravilno uporabniško ime ali e-pošta';
+$lang['Password reset is not allowed for this user'] = 'Poenostavite gesla ni možna za tega uporabnika';
+$lang['User "%s" has no email address, password reset is not possible'] = 'Uporabnik "%s" nima e-pošte, zato poenostavitev gesla ni možna';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Nekdo je zahteval poenostavite gesla za uporabniški račun:';
+$lang['Username "%s" on gallery %s'] = 'Uporabnik "%s" za album %s';
+$lang['To reset your password, visit the following address:'] = 'Za poenostavitev gesla, obiščite naslednji spletni naslov:';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Če je bila to napaka, preprosto prezrite to sporočilo in nič se ne bo zgodilo.';
+$lang['Password Reset'] = 'Poenostavitev gesla';
+$lang['Check your email for the confirmation link'] = 'Preverite e-pošto za potrditev';
+$lang['Invalid key'] = 'Nepravilen ključ';
+$lang['The passwords do not match'] = 'Gesli se ne ujemata';
+$lang['Your password has been reset'] = 'Vaše geslo je bilo poenostavljeno';
+$lang['Return to home page'] = 'Vrnite se na domačo stran';
+$lang['Please enter your username or email address.'] = 'Prosim vnesite svoje uporabniško ime ali e-pošto.';
+$lang['You will receive a link to create a new password via email.'] = 'Po e-pošti boste prejeli povezavo za kreiranje novega gesla.';
+$lang['Username or email'] = 'Uporabniško ime ali e-pošta';
+$lang['Change my password'] = 'Spremeni geslo';
+$lang['Enter your new password below.'] = 'Vnesite novo geslo.';
+$lang['Reset Password'] = 'Poenostavi geslo';
+$lang['EXIF Metadata'] = 'EXIF metapodatki';
+$lang['IPTC Metadata'] = 'IPTC metapodatki';
 
 ?>
\ No newline at end of file
