@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Српски [SR]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=458
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -35,7 +35,6 @@ $lang_info['direction'] = 'ltr';
 $lang_info['code'] = 'sr';
 $lang_info['zero_plural'] = true;
 
-$lang['%.2f (rated %d times)'] = '%.2f (оцењено %d пута)';
 $lang['%d Kb'] = '%d Kb';
 $lang['%d album updated'] = '%d категорија обновљена';
 $lang['%d albums updated'] = '%d категорије обновљене';
@@ -57,7 +56,6 @@ $lang['Any tag'] = 'Било која ознака';
 $lang['At least one listed rule must be satisfied.'] = 'Најмање једно од наведених правила мора бити задовољено.';
 $lang['At least one tag must match'] = 'Најмање једна ознака се мора поклапати';
 $lang['Author'] = 'Аутор';
-$lang['Average rate'] = 'Просечна оцена';
 $lang['Albums'] = 'Категорије';
 $lang['Album'] = 'Категорија';
 $lang['Close this window'] = 'Затвори прозор';
@@ -92,9 +90,6 @@ $lang['Links'] = 'Интернет везе';
 $lang['N/A'] = 'Н/Д';
 $lang['New on %s'] = 'Нови на %s';
 $lang['New password confirmation does not correspond'] = 'Потврда нове лозинке не одговара';
-$lang['New password sent by email'] = 'Нова лозинка послана електронском поруком';
-$lang['No email address'] = 'Нема електронске адресе';
-$lang['No classic user matches this email address'] = 'Ниједан корисник се не поклапа с овом електронском адресом';
 $lang['Notification'] = 'Обавештење';
 $lang['Number of items'] = 'Број ставки';
 $lang['Original dimensions'] = 'Изворне величине';
@@ -105,7 +100,6 @@ $lang['Posted on'] = 'Датум објављивања';
 $lang['Profile'] = 'Профил';
 $lang['Quick connect'] = 'Брза веза';
 $lang['RSS feed'] = 'RSS извор';
-$lang['Rate'] = 'Оцена';
 $lang['Register'] = 'Упишите се';
 $lang['Registration'] = 'Регистрација';
 $lang['Related tags'] = 'Повезане ознаке';
@@ -115,7 +109,6 @@ $lang['Search rules'] = 'Правила претраге';
 $lang['Search tags'] = 'Ознаке претраге';
 $lang['Search'] = 'Претраживање';
 $lang['display available tags'] = 'Погледај доступне ознаке';
-$lang['Send new password'] = 'Пошаљи нову лозинку';
 $lang['Since'] = 'Од';
 $lang['Sort by'] = 'Сложено по';
 $lang['Sort order'] = 'Редослед слагања';
@@ -230,10 +223,6 @@ $lang['month'][8] = 'Август';
 $lang['month'][9] = 'Септембар';
 $lang['Most visited'] = 'Најпосјећеније';
 $lang['display most visited photos'] = 'приказ најпосјећенијих слика';
-$lang['The number of photos per row must be a not null scalar'] = 'број слика по реду мора бити целобројна вредност';
-$lang['Number of photos per row'] = 'Број слика по реду';
-$lang['The number of rows per page must be a not null scalar'] = 'Број редова по страници мора бити целобројна вредност';
-$lang['Number of rows per page'] = 'Број редова по страници';
 $lang['Unknown identifier'] = 'Непозната ознака';
 $lang['New password'] = 'Нова лозинка';
 $lang['Rate this photo'] = 'Оцени ову слику';
@@ -313,7 +302,6 @@ $lang['Admin: %s'] = 'Администратор: %s';
 $lang['Registration of %s'] = 'Пријава од %s';
 $lang['Album: %s'] = 'Категорија: %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Лош статус за корисника "гост", користи се подразумевани статус. Молимо обавестите мајстора интернет страница.';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Administrator, webmaster и посебни корисник не могу користити ову методу';
 $lang['this email address is already in use'] = 'корисник већ користи ову адресу електронске поште';
 $lang['Album results for'] = 'Резултати категорије за ';
 $lang['Tag results for'] = 'Резултати ознака за';
@@ -359,4 +347,30 @@ $lang['This author removed the comment with id %d'] = 'Овај аутор је
 $lang['delete this comment'] = 'обриши овај коментар';
 $lang['validate this comment'] = 'овери овај коментар';
 $lang['html tags are not allowed in login'] = 'html ознаке нису дозвољене овде';
+$lang['The number of photos per page must be a not null scalar'] = 'Број фотографија по страни мора бити већи од нуле';
+$lang['Number of photos per page'] = 'Број фотографија по страници';
+$lang['%d rates'] = '%d оцена';
+$lang['Rating score'] = 'Оцена резултата';
+$lang['Enter a username or email address'] = 'Унеси корисничко име или е-адресу';
+$lang['Invalid username or email'] = 'Неправилно корисничко име или адреса е-поште';
+$lang['Password reset is not allowed for this user'] = 'Поништавање лозинке није дозвољено за овог корисника';
+$lang['User "%s" has no email address, password reset is not possible'] = 'Корисник "%s" нема адресу е-поште, поништавање лозинке није могуће';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Неко је захтевао да се лозинка поништи за корисничко налог:';
+$lang['Username "%s" on gallery %s'] = 'Корисничко име "%s" у галерији %s';
+$lang['To reset your password, visit the following address:'] = 'Да бисте поништили Вашу лозинку прочитајте пошту са следеће е-адресе:';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Ако је ово грешка, занемарите ову поруку и ништа се неће десити.';
+$lang['Password Reset'] = 'Поништавање лозинке';
+$lang['Check your email for the confirmation link'] = 'Проверите вашу е-пошту за везу за потврду';
+$lang['Invalid key'] = 'Лош кључ';
+$lang['The passwords do not match'] = 'Лозинке нису једнаке';
+$lang['Your password has been reset'] = 'Ваша лозинка је поништена';
+$lang['Return to home page'] = 'Повратак на почетну страницу';
+$lang['Please enter your username or email address.'] = 'Молимо Вас да унесете корисничко име или е-адресу.';
+$lang['You will receive a link to create a new password via email.'] = 'Добићете везу  преко е-поште да бисте променили лозинку.';
+$lang['Username or email'] = 'Корисничко име или е-адреса';
+$lang['Change my password'] = 'Промени моју лозинку';
+$lang['Enter your new password below.'] = 'Унесите Вашу нову лозинку испод.';
+$lang['Reset Password'] = 'Поништи лозинку';
+
+
 ?>
\ No newline at end of file
