@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'Sänd mail till admin n
 $lang['Email admins when a comment requires validation'] = 'Sänd mail till admin när en kommentar väntar på godkännande';
 $lang['Environment'] = 'Miljö';
 $lang['Form'] = 'Formulär';
-$lang['Gallery URL'] = 'Galleri URL';
 $lang['Gallery title'] = 'Galleri titel';
 $lang['Grant selected groups'] = 'Tillåt markerade grupper';
 $lang['Grant selected users'] = 'Tillåt markerade användare';
@@ -271,7 +270,6 @@ $lang['Subscribe to notification by mail'] = 'Anmäl till notifikation via e-mai
 $lang['Unsubscribe from notification by mail'] = 'Avanmäl notifikation via e-mail';
 $lang['Parameter'] = 'Inställningar';
 $lang['Operation in progress'] = 'Bearbetnings behandling.';
-$lang['Please wait...'] = 'Vänligen vänta...';
 $lang['Continue processing treatment'] = 'Fortsätt med pågående behandling';
 $lang['Add detailed content'] = 'Lägg till detaljerad information';
 $lang['Send mail as'] = 'Skicka e-mail som';
@@ -613,13 +611,10 @@ $lang['Privacy level set to "%s"'] = 'Sekretessnivå inställd på "%s"';
 $lang['Album "%s" now contains %d photos'] = 'Kategir "%s" innehåller nu %d foton';
 $lang['Manage this set of %d photos'] = 'Hantera settet om %d foton';
 $lang['Select files'] = 'Markerade filer';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG filer eller ZIP arkiv med JPEG filer innuti tack.';
 $lang['Everybody'] = 'Alla';
 $lang['Who can see these photos?'] = 'Vem kan se dessa foton?';
 $lang['Who can see this photo?'] = 'Vem kan se detta foto?';
 
-$lang['... or switch to the old style form'] = '... eller byt till gamla versionen av formuläret';
-$lang['... or switch to the multiple files form'] = '... eller byt till formuläret för att ladda upp många bilder';
 
 $lang['The websize maximum width must be a number between %d and %d'] = 'Webstorlekens maximala bredd måste vara ett nummer mellan %d och %d';
 $lang['The websize maximum height must be a number between %d and %d'] = 'Webstorlekens maximala höjd måste vara ett nummer mellan %d och %d';
@@ -784,8 +779,87 @@ $lang['Do you want to activate anyway?'] = 'Vill du aktivera ändå?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'Detta plugin är nu del av PIWIGO CORE! Avinstallera det NU!';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'FEL:. Detta plugin saknas men den är installerad! Avinstallera det NU'; 
 $lang['display'] = 'Visa';
+$lang['Regenerate Thumbnails'] = 'Generera miniatyrer bilder';
+$lang['Thumbnails generation in progress...'] = 'generering av miniatyr bilder pågår ......';
+$lang['%s thumbnails have been regenerated'] = '%s miniatyrbilder har skapats';
+$lang['%s thumbnails can not be regenerated'] = '%s miniatyrbilder inte kan skapas ';
+$lang['Regenerate Websize Photos'] = 'Skapa Web storleks bilder';
+$lang['Photos generation in progress...'] = 'Bild generering pågår..';
+$lang['%s photos have been regenerated'] = '%s foton har skapats';
+$lang['%s photos can not be regenerated'] = '%s foton har inte skapats';
 $lang['new'] = 'ny';
 $lang['No results'] = 'Inga poster hittades';
 $lang['Searching...'] = 'Söker...';
-$lang['Type in a search term'] = 'Ange nytt sökord'; 
+$lang['Type in a search term'] = 'Ange nytt sökord';
+$lang['Activate icon "new" next to albums and pictures'] = 'Aktivera ikonen "ny" intill album och bilder';
+$lang['Deactivate all'] = 'Avaktivera allt';
+$lang['Default photos order'] = 'Standardordning för bilder';
+$lang['Restore'] = 'Återställ';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Återställ standardkonfiguration. Du kommer att förlora inställingarna för din plugins!';
+$lang['Show menubar'] = 'Visa verktygsfält';
+$lang['Updates'] = 'Uppdateringar';
+$lang['Update in progress... Please wait.'] = 'Uppdatering körs... Var vänlig vänta.';
+$lang['Ignore this update'] = 'Ignorera denna uppdatering';
+$lang['Reset ignored updates'] = 'Nollställ ignorerade uppdateringar';
+$lang['Update All'] = 'Uppdatera allt';
+$lang['ERROR'] = 'FEL';
+$lang['Update Complete'] = 'Uppdatering avslutad';
+$lang['Piwigo Update'] = 'Piwigo Uppdatering';
+$lang['Extensions Update'] = 'Uppdatering av tillägg';
+$lang['Rate'] = 'Betygsätt';
+$lang['Average rate'] = 'Genomsnittligt betyg';
+$lang['Learn more'] = 'Läs mer';
+$lang['Some upgrades are available for extensions.'] = 'Det finns uppdateringar till några insticksmoduler.';
+$lang['Ignore All'] = 'Ignorera alla';
+$lang['Crop'] = 'Klipp';
+$lang['Width'] = 'Bredd';
+$lang['Height'] = 'Höjd';
+$lang['Follow Orientation'] = 'Följ bildformat';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Om du vill regenerera miniatyrerna, på till <a href="%s">Batch Manager</a>.';
+$lang['Graphics Library'] = 'Grafikbibliotek';
+$lang['... or '] = '... eller ';
+$lang['Create'] = 'Skapa';
+$lang['Start Upload'] = 'Börja uppladdning';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Du använder Flash-uppladaren. Har du problem, försök med <a href="%s">webbläsaruppladdaren</a> istället.';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Du använder webbläsaruppladdaren, prova gärna <a href="%s">Flash-uppladdaren</a> istället.';
+$lang['Maximum file size: %sB.'] = 'Maximal filstorlek: %sB.';
+$lang['Allowed file types: %s.'] = 'Tillåtna filtyper: %s.';
+$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Ungefärlig maximal upplösning: %dM pixlar (motsvarande %dx%d pixlar).';
+$lang['Manage Permissions'] = 'Hantera rättigheter';
+$lang['Photo %s of %s'] = 'Bild %s av %s';
+$lang['show details'] = 'visa detaljer';
+$lang['hide details'] = 'dölj detaljer';
+$lang['Merge tags'] = 'Sammanfoga taggar';
+$lang['Select the destination tag'] = 'Välj mål-tagg';
+$lang['(this tag will be deleted)'] = '(den här taggen kommer raderas)';
+$lang['Confirm merge'] = 'Bekräfta sammanfogning';
+$lang['Merge selected tags'] = 'Sammanfoga valda taggar';
+$lang['No destination tag selected'] = 'Ingen mål-tagg har valts';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Taggar <em>%s</em> sammanfogade som <em>%s</em>';
+$lang['Select at least two tags for merging'] = 'Välj minst två taggar för sammanfogning';
+$lang['Select an album'] = 'Välj ett album';
+$lang['Add a criteria'] = 'Lägg till ett kriterium';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Du kan inte ange en standardsortering för foton på grund av en vald inställning i din lokala konfiguration.';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Du har specifierat <i>$conf[\'order_by\']</i> i din lokala konfigurationsfil, den här parametern är ersatt. Ta bort den eller döpom till <i>$conf[\'order_by_custom\']</i> !';
+$lang['All extensions are up to date.'] = 'Alla insticksmoduler är de senaste.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Följande insticksmoduler kan vara inkompatibla med senaste Piwigo:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Följande teman kan vara inkompatibla med senaste Piwigo:';
+$lang['I decide to update anyway'] = 'Jag uppdaterar ändå';
+$lang['Update to Piwigo %s'] = 'Uppdatera till Piwigo %s';
+$lang['Two updates are available'] = 'Två uppdateringar är tillgängliga';
+$lang['This is a minor update, with only bug corrections.'] = 'Det här är en mindre uppdatering med bug-fixar.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Det här är en stor uppdatering med <a href="%s">nya spännande funktioner</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'Några teman och insticksmoduler kan vara otillgängliga ännu.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Du kan uppdatera till to Piwigo %s direkt, utan att uppgradera till Piwigo %s (rekommenderat).';
+$lang['Save Template Directory'] = 'Spara mallkatalogen';
+$lang['Dump Database'] = 'Dumpa databasen';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Inkludera historiska data (Varning: serverns minnesgräns kan överskridas)';
+$lang['Unable to write new local directory.'] = 'Kan inte skriva till ny lokal katalog.';
+$lang['Unable to send template directory.'] = 'Kan inte skicka mallkatalogen.';
+$lang['Unable to dump database.'] = 'Kan inte dumpa databasen.';
+$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Som standard kommer Piwigo skapa en ny webbstorlek från HD (high definition) versionen av din bild.';
+$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Om ingen HD-bild är tillgänglig och den nuvarande webbstorleken är större än skalningsdimensionerna så kommer Piwigo flytta bilden till HD och skapa en nedskalad version av den.';
+$lang['An error has occured during upgrade.'] = 'Det uppstod ett fel under uppgraderingen.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Ett fel uppstod vid dekomprimeringen. Kontrollera rättigheterna på din Piwigo-installation och försök igen.<br><a href="%s">Klicka här för att visa felloggen</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo kan inte hämta uppgraderingen från servern';
 ?>
\ No newline at end of file
