@@ -82,7 +82,6 @@ $lang['Email admins when a valid comment is entered'] = 'Yeni yorum eklendiginde
 $lang['Email admins when a comment requires validation'] = 'Yorum onayı oldugunda yöneticiye e-posta gönder';
 $lang['Environment'] = 'Ortam / Çevre';
 $lang['Form'] = 'Biçim';
-$lang['Gallery URL'] = 'Galleri URL';
 $lang['Gallery title'] = 'Galleri Başlığı';
 $lang['Grant selected groups'] = 'Seçilen grupların kabulu';
 $lang['Grant selected users'] = 'Seçilen kullanıcıların kabulu';
@@ -596,7 +595,7 @@ $lang['Add New Theme'] = 'Yeni bir tema ekle';
 $lang['Forbid this theme to users'] = 'Bu temayı kullanıcılara yasakla';
 $lang['Set as default theme for unregistered and new users'] = 'Kayıtsız ve yeni kullanıcılar için varsayılan tema olarak ayarla';
 $lang['unknown'] = 'bilinmeyen';
-$lang['Upload Photos'] = 'Resimler Yükle';
+$lang['Upload Photos'] = 'Resim Yükle';
 $lang['Drop into album'] = 'albüm içine bırak';
 $lang['+ Add an upload box'] = '+ Bir yükleme kutusu ekleyin';
 $lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Bir "%s" dizini açınız Piwigo kurduğunuz yerde.';
@@ -611,12 +610,9 @@ $lang['Privacy level set to "%s"'] = 'Gizlilik seviyesi "%s" için';
 $lang['Album "%s" now contains %d photos'] = 'kategori "%s" şimdi %d resimlerini içeriyor';
 $lang['Manage this set of %d photos'] = 'Düzenle bu dizi %d resimleri';
 $lang['Select files'] = 'Dosyaları seçin';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG dosyaları ya da ZIP arşivleri içinde JPEG dosyaları olan.';
 $lang['Everybody'] = 'Herkes';
 $lang['Who can see these photos?'] = 'Kim bu resimleri görebilir?';
 $lang['Who can see this photo?'] = 'Kim bu resimi görebilir?';
-$lang['... or switch to the old style form'] = '... veya eski stil form geç';
-$lang['... or switch to the multiple files form'] = '... veya birden fazla dosya geçiş formu';
 $lang['The websize maximum width must be a number between %d and %d'] = 'En fazla genişlik %d ve %d sayıları arasında olmalı';
 $lang['The websize maximum height must be a number between %d and %d'] = 'En fazla yükseklik %d be %d sayıları arasında olmalı';
 $lang['The websize image quality must be a number between %d and %d'] = 'Resim kalitesi  %d ve %d sayıları arasında olmalı';
@@ -776,9 +772,65 @@ $lang['WARNING! This plugin does not seem to be compatible with this version of
 $lang['Do you want to activate anyway?'] = 'Yine de etkinleştirmek istiyor musunuz?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'Bu eklenti şimdi Piwigo\'nun kendi parçasıdır lütfen siliniz.!';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'Hata: Bu eklenti eksik, ama yüklenmiş. Lütfen siliniz.';
+$lang['Restore'] = 'Onarım';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Varsayılan yapılandırmalarınızı onarın. Eklenti ayarlrınız kaybolacaktır!';
 $lang['display'] = 'göster';
+$lang['Regenerate Thumbnails'] = 'Küçük Resimleri Tekrar Oluştur';
+$lang['Thumbnails generation in progress...'] = 'Küçük resimler oluşturuluyor...';
+$lang['%s thumbnails have been regenerated'] = '%s küçük resimler oluşturuldu';
+$lang['%s thumbnails can not be regenerated'] = '%s küçük resimler oluşturulamadı';
+$lang['Regenerate Websize Photos'] = 'Yeniden web boyutu oluştur';
+$lang['Photos generation in progress...'] = 'Resimler oluşturulmaya devam ediyor...';
+$lang['%s photos have been regenerated'] = '%s resimler oluşturuldu';
+$lang['%s photos can not be regenerated'] = '%s resimler oluşturulamadı';
 $lang['new'] = 'yeni';
 $lang['No results'] = 'Sonuç yok';
 $lang['Searching...'] = 'Arıyor...';
 $lang['Type in a search term'] = 'Aramak için bir kelime yazınız';
+$lang['Deactivate all'] = 'Hepsini etkisizleştir';
+$lang['Show menubar'] = 'menü çubuğunu göster';
+$lang['Updates'] = 'Güncellemeler';
+$lang['Update in progress... Please wait.'] = 'Güncelleniyor.. Lütfen bekleyiniz.';
+$lang['Ignore this update'] = 'Bu güncellemeyi görmezden gel';
+$lang['Reset ignored updates'] = 'Görmezden gelinen güncellemeleri tekrar ayarla';
+$lang['Update All'] = 'Hepsini Güncelle';
+$lang['ERROR'] = 'HATA';
+$lang['Update Complete'] = 'Güncelleme Tamamlandı';
+$lang['Piwigo Update'] = 'Piwigo Güncellemesi';
+$lang['Extensions Update'] = 'Eklentiler Güncellemesi';
+$lang['All extensions are up to date.'] = 'Tüm eklentiler günceldir.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Aşağıdaki eklentiler Piwigo yeni sürümü ile uyumlu olmayabilir:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Aşağıdaki temalar Piwigo yeni sürümü ile uyumlu olmayabilir:';
+$lang['I decide to update anyway'] = 'Güncellemeye karar verdim';
+$lang['Update to Piwigo %s'] = 'Piwigoyu %s\'e güncelle';
+$lang['Two updates are available'] = 'İki güncelleştirme mevcut';
+$lang['This is a minor update, with only bug corrections.'] = 'Bu sadece hata düzeltmeleri ile, küçük bir güncelleştirme.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Bu yeni büyük bir güncelleme <a href="%s">yeni heyecan verici özellikler</a> içerir.';
+$lang['Some themes and plugins may be not available yet.'] = 'Bazı tema ve eklentiler henüz hazır olamayabilir.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Piwigoyu direkt olarak %s\'e güncelleyebilirsiniz, Piwigo %s\'e güncellemeden (önerilir).';
+$lang['Save Template Directory'] = 'Tema dizinini kaydet';
+$lang['Dump Database'] = 'Vertitabanını sil';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Geçmiş verileri dahil et (UYARI: sunucu belleği sınırı aşılabilir)';
+$lang['Unable to write new local directory.'] = 'Yeni bir yerel dizine yazılamıyor.';
+$lang['Unable to send template directory.'] = 'Tema dizinine gönderilemiyor.';
+$lang['Unable to dump database.'] = 'Veritabanı silinemiyor.';
+$lang['Some upgrades are available for extensions.'] = 'Eklentiler için bazı güncellemeler mevcut.';
+$lang['Ignore All'] = 'Tümünü Yoksay';
+$lang['Crop'] = 'Kes';
+$lang['Width'] = 'Genişlik';
+$lang['Height'] = 'Yükseklik';
+$lang['Follow Orientation'] = 'Oryantasyonu takip edin';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Eğer küçük resimleri yenilemek istiyorsanız, <a href="%s">Küçük Resimleri Tekrar Oluştur</a> gidin.';
+$lang['Graphics Library'] = 'Grafik Arşivi';
+$lang['Activate icon "new" next to albums and pictures'] = 'Resimlerin yanındaki "yeni" simgesini etkinleştir';
+$lang['Default photos order'] = 'Varsayılan resim düzeni';
+$lang['Learn more'] = 'Daha fazla bilgi edinin';
+$lang['Average rate'] = 'Ortalama derecelendirme';
+$lang['Rate'] = 'Oyla';
+$lang['... or '] = '... yada';
+$lang['Create'] = 'Oluştur';
+$lang['hide details'] = 'ayrıntıları gizle';
+$lang['Select an album'] = 'Albüm seçiniz';
+$lang['show details'] = 'ayrıntıları göster';
+$lang['Start Upload'] = 'Yüklemeye başla';
 ?>
\ No newline at end of file
