@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Українська [UA]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=523
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -55,7 +55,6 @@ $lang['Any tag'] = 'Будь-який тег';
 $lang['At least one listed rule must be satisfied.'] = 'Хоча б одне правило повинне виконуватись.';
 $lang['At least one tag must match'] = 'Хоча б один тег повинен бути присутнім';
 $lang['Author'] = 'Автор';
-$lang['Average rate'] = 'Середній бал';
 $lang['Albums'] = 'Альбоми';
 $lang['Album'] = 'Альбом';
 $lang['Close this window'] = 'Закрити це вікно';
@@ -105,9 +104,6 @@ $lang['month'][7] = "Липень";
 $lang['month'][8] = "Серпень";
 $lang['month'][9] = "Вересень";
 $lang['New password confirmation does not correspond'] = 'Підтвердження нового пароля не співпадає';
-$lang['New password sent by email'] = 'Новий пароль висланий електронною поштою';
-$lang['No email address'] = 'Немає адреси електронної пошти';
-$lang['No classic user matches this email address'] = 'Немає користувачів з такою адресою електронної пошти';
 $lang['Notification'] = 'Повідомлення';
 $lang['Number of items'] = 'Кількість елементів';
 $lang['Original dimensions'] = 'Оригінальні розміри';
@@ -118,7 +114,6 @@ $lang['Posted on'] = 'Опубліковано';
 $lang['Profile'] = 'Профіль';
 $lang['Quick connect'] = "Швидке з'єднання";
 $lang['RSS feed'] = 'RSS канал';
-$lang['Rate'] = 'Оцінити';
 $lang['Register'] = 'Реєстрація';
 $lang['Registration'] = 'Реєстрація';
 $lang['Related tags'] = "Пов'язані теги";
@@ -128,7 +123,6 @@ $lang['Search rules'] = 'Критерії пошуку';
 $lang['Search tags'] = 'Теги пошуку';
 $lang['Search'] = 'Пошук';
 $lang['display available tags'] = 'відображати доступні теги';
-$lang['Send new password'] = 'Відправити новий пароль';
 $lang['Since'] = 'З';
 $lang['Sort by'] = 'Сортувати за';
 $lang['Sort order'] = 'Порядок сортування';
@@ -257,10 +251,8 @@ $lang['return to normal view mode'] = 'повернутися до звичай
 $lang['display a calendar by posted date'] = 'показувати календар за датою відправлення';
 $lang['Most visited'] = 'Найбільш відвідувані';
 $lang['display most visited photos'] = 'показувати найбільш відвідувані фотографії';
-$lang['The number of photos per row must be a not null scalar'] = 'Кількість фотографій у рядку повинно бути цілим ненульовим числом';
-$lang['Number of photos per row'] = 'Кількість фотографій в рядку';
-$lang['The number of rows per page must be a not null scalar'] = 'Кількість рядків на сторінці повинно бути цілим ненульовим числом';
-$lang['Number of rows per page'] = 'Кількість рядків на сторінці';
+$lang['The number of photos per page must be a not null scalar'] = 'Кількість фотографій на сторінці повинно бути цілим ненульовим числом';
+$lang['Number of photos per page'] = 'Кількість фотографій на сторінці';
 $lang['Unknown identifier'] = 'Невідомий ідентифікатор';
 $lang['New password'] = 'Новий пароль';
 $lang['Rate this photo'] = 'Оцінити це фото';
@@ -304,7 +296,6 @@ $lang['Search for all terms'] = 'Пошук по всім словам';
 $lang['Search for any terms'] = 'Пошук по будь-якому слову';
 $lang['Empty query. No criteria has been entered.'] = 'Порожній запит. Не був введений жоден критерій.';
 $lang['Search Options'] = 'Опції пошуку';
-$lang['%.2f (rated %d times)'] = '%.2f (оцінено %d разів)';
 $lang['%d Kb'] = '%d Кб';
 $lang['Search results'] = 'Результати пошуку';
 $lang['Search in sub-albums'] = 'Пошук в під-альбомах';
@@ -355,9 +346,32 @@ $lang['This author removed the comment with id %d'] = 'Цей автор вид
 $lang['delete this comment'] = 'видалити цей коментар';
 $lang['validate this comment'] = 'перевірити цей коментар';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = "Невірний статус для користувача \"гість\", буде використовуватись статус за замовчуванням. Будь ласка, повідомте вебмайстра.";
-$lang['Administrator, webmaster and special user cannot use this method'] = "Адміністратор, вебмайстер та спеціальний користувач не можуть використовувати цей метод";
 $lang['N/A'] = 'невідомий';
 $lang['IP: %s'] = "IP: %s";
 $lang['html tags are not allowed in login'] = 'логін не повинен містити html тегів';
+$lang['%d rates'] = '%d голосів';
+$lang['Rating score'] = 'Рейтинговий бал';
+$lang['Enter a username or email address'] = 'Введіть ім\'я користувача або адресу електронної пошти';
+$lang['Invalid username or email'] = 'Невірне ім\'я користувача або адреса електронної пошти';
+$lang['Password reset is not allowed for this user'] = 'Оновлення паролю не дозволено для цього користувача';
+$lang['User "%s" has no email address, password reset is not possible'] = 'Користувач "%s" не має адреси електронної пошти, оновлення паролю неможливе';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Хтось запросив оновлення паролю для наступного облікового запису користувача:';
+$lang['Username "%s" on gallery %s'] = 'Ім\'я "%s" в галереї %s';
+$lang['To reset your password, visit the following address:'] = 'Щоб оновити пароль, відвідайте наступну адресу:';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Якщо це було помилкою, просто проігноруйте це повідомлення і нічого не трапиться.';
+$lang['Password Reset'] = 'Оновлення паролю';
+$lang['Check your email for the confirmation link'] = 'Перевірте вашу пошту на наявність лінку підтвердження';
+$lang['Invalid key'] = 'Невірний ключ';
+$lang['The passwords do not match'] = 'Паролі не співпадають';
+$lang['Your password has been reset'] = 'Ваш пароль був оновлений';
+$lang['Return to home page'] = 'Повернутися на домашню сторінку';
+$lang['Please enter your username or email address.'] = 'Будь ласка введіть ваше ім\'я користувача або адресу електронної пошти.';
+$lang['You will receive a link to create a new password via email.'] = 'Ви отримаєте посилання, щоб створити новий пароль по електронній пошті.';
+$lang['Username or email'] = 'Ім\'я користувача або адреса електронної пошти';
+$lang['Change my password'] = 'Змінити мій пароль';
+$lang['Enter your new password below.'] = 'Введіть ваш новий пароль нижче.';
+$lang['Reset Password'] = 'Оновити пароль';
+$lang['EXIF Metadata'] = 'EXIF метадані';
+$lang['IPTC Metadata'] = 'IPTC метадані';
 
 ?>
\ No newline at end of file
