@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = 'Gởi email cho quản
 $lang['Email admins when a comment requires validation'] = 'Gởi email cho quản trị khi có một mời bình cần được xác nhận';
 $lang['Environment'] = 'Môi trường';
 $lang['Form'] = 'Form';
-$lang['Gallery URL'] = 'Địa chỉ website của gallery';
 $lang['Gallery title'] = 'Tiêu đề của gallery';
 $lang['Grant selected groups'] = 'Cấp cho các nhóm đã chọn';
 $lang['Grant selected users'] = 'Cấp cho các thành viên đã chọn';
@@ -620,12 +619,9 @@ $lang['Privacy level set to "%s"'] = 'Mức độ riêng tư đã được thi
 $lang['Album "%s" now contains %d photos'] = 'Đề mục "%s" hiện tại chứa %d bức ảnh';
 $lang['Manage this set of %d photos'] = 'Quản lý bộ gồm %d ảnh';
 $lang['Select files'] = 'Chọn tệp tin';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'Chỉ chấp nhận tệp tin JPEG hoặc định dạng lưu trữ ZIP chứa tệp JPEG bên trong.';
 $lang['Everybody'] = 'Mọi người';
 $lang['Who can see these photos?'] = 'Ai có thể xem được những bức ảnh này?';
 $lang['Who can see this photo?'] = 'Ai có thể xem được bức ảnh này?';
-$lang['... or switch to the old style form'] = '... hoặc chuyển sang fomr kiểu cũ';
-$lang['... or switch to the multiple files form'] = '... hoặc chuyển sang fomr kiểu đa tệp tin';
 $lang['The websize maximum width must be a number between %d and %d'] = 'Chiều rộng lớn nhất của trang web phải là số nằm giữa %d và %d';
 $lang['The websize maximum height must be a number between %d and %d'] = 'Chiều cao lớn nhất của trang web phải là số nằm giữa %d và %d';
 $lang['The websize image quality must be a number between %d and %d'] = 'Chất lượng hình của trang web phải là số nằm giữa %d và %d';
@@ -783,5 +779,89 @@ $lang['WARNING! This plugin does not seem to be compatible with this version of
 $lang['Do you want to activate anyway?'] = 'Bạn vẫn muốn kích hoạt?';
 $lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'PLUGIN NÀY GIỜ LÀ MỘT PHẦN CỦA NHÂN PIWIGO! GỠ BỎ NGAY!';
 $lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'LỖI: PLUGIN NÀY BỊ THIẾU NHƯNG NÓ ĐÃ ĐƯỢC CÀI ĐẶT! GỠ BỎ NGAY.';
+$lang['Regenerate Thumbnails'] = 'Khởi tạo lại Hình thu nhỏ';
+$lang['Thumbnails generation in progress...'] = 'Quá trình khởi tạo hình thu nhỏ đang được thực hiện...';
+$lang['%s thumbnails have been regenerated'] = 'Có %s hình thu nhỏ đã được tạo ra';
+$lang['%s thumbnails can not be regenerated'] = 'Có %s hình thu nhỏ không thể tạo ra được';
+$lang['Regenerate Websize Photos'] = 'Khởi tạo Ảnh Web';
+$lang['Photos generation in progress...'] = 'Quá trình khởi tạo ảnh web đang được thực hiện...';
+$lang['%s photos have been regenerated'] = 'có %s ảnh đã được tạo ra';
+$lang['%s photos can not be regenerated'] = 'Có %s ảnh không thể tạo ra được';
+$lang['new'] = 'mới';
+$lang['No results'] = 'Không có kết quả nào';
+$lang['Searching...'] = 'Đang tìm kiếm...';
+$lang['Type in a search term'] = 'Nhập vào trong mục tìm kiếm';
+$lang['display'] = 'hiển thị';
+$lang['Deactivate all'] = 'Bỏ kích hoạt tất cả';
+$lang['Restore'] = 'Phục hồi';
+$lang['Restore default configuration. You will lose your plugin settings!'] = 'Khôi phục lại cấu hình mặc định. Các thiết lập cho plugin sẽ bị mất!';
+$lang['Show menubar'] = 'Hiển thị thanh trình đơn';
+$lang['Updates'] = 'Bản cập nhật';
+$lang['Update in progress... Please wait.'] = 'Đang tiến hành cập nhật... Vui lòng đợi.';
+$lang['Ignore this update'] = 'Bỏ qua bản cập nhật này';
+$lang['Reset ignored updates'] = 'Cài đặt lại những bản cập nhật đã bỏ qua';
+$lang['Update All'] = 'Cập nhật Tất cả';
+$lang['ERROR'] = 'CÓ LỖI';
+$lang['Update Complete'] = 'Cập nhật Hoàn thành';
+$lang['Piwigo Update'] = 'Cập nhật Piwigo';
+$lang['Extensions Update'] = 'Cập nhật thành phần mở rộng';
+$lang['All extensions are up to date.'] = 'Tất cả thành phần mở rộng đều được cập nhật.';
+$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Plugins sau đây có thể không tương thích với phiên bản mới của Piwigo:';
+$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Giao diện sau đây có thể không tương thích với phiên bản mới của Piwigo:';
+$lang['I decide to update anyway'] = 'Dù gì tôi cũng quyết định cập nhật';
+$lang['Update to Piwigo %s'] = 'Cập nhật Piwigo lên phiên bản %s';
+$lang['Two updates are available'] = 'Có hai bản cập nhật';
+$lang['This is a minor update, with only bug corrections.'] = 'Đây là bản nâng cấp phụ, với các bản sửa lỗi.';
+$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Đây là bản cập nhật chính, với nhiều <a href="%s">tính năng mới thú vị</a>.';
+$lang['Some themes and plugins may be not available yet.'] = 'Một số giao diện và plugins có thể chưa sử dụng được.';
+$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Bạn có thể cập nhật trực tiếp Piwigo lên phiên bản %s, mà không cần phải nâng cấp lên phiên bản %s (khuyến cáo).';
+$lang['Save Template Directory'] = 'Lưu thư mục khuôn mẫu';
+$lang['Dump Database'] = 'Kết xuất Cơ sở dữ liệu';
+$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Bao gồm dữ liệu lược sử (Cảnh báo: giới hạn bộ nhớ máy chủ có thể bị vượt quá)';
+$lang['Unable to write new local directory.'] = 'Không thể ghi vào thư mục cục bộ mới.';
+$lang['Unable to send template directory.'] = 'Không thể gửi đi thư mục khuôn mẫu.';
+$lang['Unable to dump database.'] = 'Không thể kết xuất cơ sở dữ liệu.';
+$lang['Some upgrades are available for extensions.'] = 'Một số bản nâng cấp có thể áp dụng được cho các thành phần mở rộng.';
+$lang['Ignore All'] = 'Bỏ qua Tất cả';
+$lang['Crop'] = 'Xén';
+$lang['Width'] = 'Chiều rộng';
+$lang['Height'] = 'Chiều cao';
+$lang['Follow Orientation'] = 'Định hướng Dõi theo';
+$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Nếu bạn muốn tái tạo lại các hình thu nhỏ, hãy trỏ đến mục <a href="%s">Quản lý Khối</a>.';
+$lang['Graphics Library'] = 'Thư viện Đồ họa';
+$lang['Activate icon "new" next to albums and pictures'] = 'Kích hoạt biểu tượng "ảnh mới" kế bên albums ảnh và hình';
+$lang['Add a criteria'] = 'Thêm một tiêu chí';
+$lang['Default photos order'] = 'Thứ tự ảnh mặc định';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Bạn không thể định ra một thứ tự ảnh mặc định vì đã có một thiết lập tùy chọn trong cấu hình cục bộ.';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Bạn đã định ra <i>$conf[\'order_by\']</i> trong tệp tin cấu hình cục bộ của bạn, tham số này không được chấp nhận, hãy xóa bỏ hoặc đổi tên trong mục <i>$conf[\'order_by_custom\']</i> !';
+$lang['Average rate'] = 'Xếp hạng trung bình';
+$lang['Rate'] = 'Xếp hạng';
+$lang['... or '] = '... hoặc ';
+$lang['Create'] = 'Khởi tạo';
+$lang['Start Upload'] = 'Bắt đầu Tải lên';
+$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Bạn hiện đang dùng Flash Uploader. Nếu có trục trặc? Thì dùng <a href="%s">Web Uploader</a> thay thế.';
+$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Bạn hiện đang dùng Browser uploader. Hãy dùng <a href="%s">Flash uploader</a> thay thế.';
+$lang['Maximum file size: %sB.'] = 'Kích thước file lớn nhất: %sB.';
+$lang['Allowed file types: %s.'] = 'Loại file cho phép dùng: %s.';
+$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Độ phân giải lớn nhất ước chừng: %dM pixels (đó là %dx%d pixels).';
+$lang['Manage Permissions'] = 'Quản lý Quyền Hạn';
+$lang['Learn more'] = 'Tìm hiểu thêm';
+$lang['Photo %s of %s'] = 'Ảnh %s của %s';
+$lang['show details'] = 'hiện chi tiết';
+$lang['hide details'] = 'ẩn chi tiết';
+$lang['Merge tags'] = 'Sáp nhập nhãn';
+$lang['Select the destination tag'] = 'Chọn nhãn đích';
+$lang['(this tag will be deleted)'] = '(nhãn này sẽ bị xóa)';
+$lang['Confirm merge'] = 'Xác nhận sáp nhập';
+$lang['Merge selected tags'] = 'Sáp nhập những thẻ được chọn';
+$lang['No destination tag selected'] = 'Không có nhãn đích nào được chọn';
+$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Nhãn <em>%s</em> được sáp nhập vào nhãn <em>%s</em>';
+$lang['Select at least two tags for merging'] = 'Chọn ít nhất hai nhãn để sáp nhập';
+$lang['Select an album'] = 'Chọn một album ảnh';
+$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Theo mặc định, Piwigo sẽ tạo ra một kích thước web từ ảnh định dạng cao của bản.';
+$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Nếu không có định dạng cao nào và nếu kích thước web hiện tại lớn hơn kích thước đã điều chỉnh, Piwigo sẽ chuyển nó thành định dạng cao và tạo ra một ảnh có kích thước web đã thu nhỏ từ ảnh gốc.';
+$lang['An error has occured during upgrade.'] = 'Có một lỗi xuất hiện trong quá trình nâng cấp.';
+$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Có một lỗi xuất hiện trong quá trình trích xuất tệp tin. Vui lòng kiểm tra quyền hiệu chỉnh tệp tin gói cài đặt Piwigo của bạn.<br><a href="%s">Click vào đây để xem lỗi.</a>.';
+$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo không thể nhận được tệp tin nâng cấp từ  máy chủ';
 
 ?>
\ No newline at end of file
