@@ -22,7 +22,7 @@
 // +-----------------------------------------------------------------------+
 /*
 Language Name: Tiếng Việt [VN]
-Version: 2.2.1
+Version: 2.3.0
 Language URI: http://piwigo.org/ext/extension_view.php?eid=437
 Author: Piwigo team
 Author URI: http://piwigo.org
@@ -35,7 +35,6 @@ $lang_info['direction'] = 'ltr';
 $lang_info['code'] = 'vn';
 $lang_info['zero_plural'] = true;
 
-$lang['%.2f (rated %d times)'] = '%.2f (được đánh giá trên %d lần)';
 $lang['%d Kb'] = '%d Kb';
 $lang['%d album updated'] = '%d đề mục đã được cập nhật';
 $lang['%d albums updated'] = '%d đề mục đã được cập nhật';
@@ -57,7 +56,6 @@ $lang['Any tag'] = 'Tất cả các tag';
 $lang['At least one listed rule must be satisfied.'] = 'Ít nhất một điều khoản nêu trên phải được đáp ứng.';
 $lang['At least one tag must match'] = 'Ít nhất phải có một tag trùng nhau';
 $lang['Author'] = 'Tác giả';
-$lang['Average rate'] = 'Xếp hạng trung bình';
 $lang['Albums'] = 'Đề mục';
 $lang['Album'] = 'Đề mục';
 $lang['Close this window'] = 'Đóng';
@@ -91,9 +89,6 @@ $lang['Links'] = 'Liên kết';
 $lang['N/A'] = 'Không có';
 $lang['New on %s'] = 'hình mới ở %s';
 $lang['New password confirmation does not correspond'] = 'Xác nhận mật khẩu mới không được phản hồi';
-$lang['New password sent by email'] = 'Mật khẩu mới đã được gởi qua email của bạn';
-$lang['No email address'] = 'Không có địa chỉ email';
-$lang['No classic user matches this email address'] = 'Không có thành viên nào có địa chỉ email trùng với email này.';
 $lang['Notification'] = 'Thông báo';
 $lang['Number of items'] = 'Số lượng hình';
 $lang['Original dimensions'] = 'Độ phân giải gốc';
@@ -104,7 +99,6 @@ $lang['Posted on'] = 'Gởi vào';
 $lang['Profile'] = 'Hồ sơ';
 $lang['Quick connect'] = 'Kết nối nhanh';
 $lang['RSS feed'] = 'Bản tin RSS';
-$lang['Rate'] = 'Xếp hạng';
 $lang['Register'] = 'Đăng ký';
 $lang['Registration'] = 'Mục đăng ký';
 $lang['Related tags'] = 'Tag liên quan';
@@ -114,7 +108,6 @@ $lang['Search rules'] = 'Điều khoản tìm kiếm';
 $lang['Search tags'] = 'Tag tìm kiếm';
 $lang['Search'] = 'Tìm kiếm';
 $lang['display available tags'] = 'Xem các tag được dùng';
-$lang['Send new password'] = 'Gởi mật khẩu mới';
 $lang['Since'] = 'Từ';
 $lang['Sort by'] = 'Sắp xếp theo';
 $lang['Sort order'] = 'Vị trí sắp xếp';
@@ -229,10 +222,6 @@ $lang['month'][8] = 'Tháng Tám';
 $lang['month'][9] = 'Tháng Chín';
 $lang['Most visited'] = 'Hình được xem nhiều nhất';
 $lang['display most visited photos'] = 'hiển thị những hình được xem nhiều nhất';
-$lang['The number of photos per row must be a not null scalar'] = 'Số hình mỗi hàng phải là đại lượng vô hướng không rỗng';
-$lang['Number of photos per row'] = 'Số hình trên mỗi hàng';
-$lang['The number of rows per page must be a not null scalar'] = 'Số hàng mỗi trang phải là đại lượng vô hướng không rỗng';
-$lang['Number of rows per page'] = 'Số hàng trên mỗi trang';
 $lang['Unknown identifier'] = 'Định danh không xác định';
 $lang['New password'] = 'Mật khẩu mới';
 $lang['Rate this photo'] = 'Đánh giá hình này';
@@ -312,7 +301,6 @@ $lang['Admin: %s'] = 'Quản trị: %s';
 $lang['Registration of %s'] = 'Mục đăng ký của %s';
 $lang['Album: %s'] = 'Đề mục: %s';
 $lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Status xấu đối với thành viên đăng thuộc nhóm "khách", sử dụng status mặc định. Thông báo ngay cho Quản trị';
-$lang['Administrator, webmaster and special user cannot use this method'] = 'Quản trị viên và thành viên đặc biệt không thể sử dụng cách này';
 $lang['this email address is already in use'] = 'đã có thành viên sử dụng địa chỉ email này';
 $lang['Album results for'] = 'Kết quả đề mục cho';
 $lang['Tag results for'] = 'Kết quả tag cho';
@@ -359,4 +347,31 @@ $lang['This author removed the comment with id %d'] = 'Tác giả này đã xóa
 $lang['validate this comment'] = 'xác nhận lời bình này';
 $lang['show tag cloud'] = 'hiển thị thẻ mây';
 $lang['html tags are not allowed in login'] = 'thẻ html không được phép dùng để đăng nhập';
+$lang['The number of photos per page must be a not null scalar'] = 'Số hình trên mỗi trang phải là số nguyên khác 0';
+$lang['Number of photos per page'] = 'Số hình trên mỗi trang';
+$lang['%d rates'] = '%d hạng';
+$lang['Rating score'] = 'Bảng xếp hạng';
+$lang['Enter a username or email address'] = 'Nhập tên người dùng hoặc địa chỉ email';
+$lang['Invalid username or email'] = 'Tên người dùng hoặc địa chỉ email không hợp lệ';
+$lang['Password reset is not allowed for this user'] = 'Không được phép đặt lại mật khẩu cho người dùng này';
+$lang['User "%s" has no email address, password reset is not possible'] = 'Người dùng "%s" không có địa chỉ email, nên việc đặt lại mật khẩu là không thể được';
+$lang['Someone requested that the password be reset for the following user account:'] = 'Có người yêu cầu đặt lại mật khẩu cho những người dùng sau:';
+$lang['Username "%s" on gallery %s'] = 'Người dùng "%s" trên thư viện hình %s';
+$lang['To reset your password, visit the following address:'] = 'Để đặt lại mật khẩu, hãy vào những địa chỉ sau:';
+$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Nếu đây là do nhầm lẫn, thì chỉ việc bỏ qua bỏ qua email này và không có việc gì sẽ xảy ra.';
+$lang['Password Reset'] = 'Cài đặt lại mật khẩu';
+$lang['Check your email for the confirmation link'] = 'Kiểm tra email để nhận liên kết xác nhận';
+$lang['Invalid key'] = 'Key không hợp lệ';
+$lang['The passwords do not match'] = 'Mật khẩu không trùng';
+$lang['Your password has been reset'] = 'Mật khẩu của bạn đã được đặt lại';
+$lang['Return to home page'] = 'Trở lại trang chủ';
+$lang['Please enter your username or email address.'] = 'Vui lòng nhập tên người dùng và địa chỉ email.';
+$lang['You will receive a link to create a new password via email.'] = 'Bạn sẽ nhận được một liên kết để tạo mật khẩu mới qua email.';
+$lang['Username or email'] = 'Người dùng hoặc email';
+$lang['Change my password'] = 'Đổi mật khẩu của tôi';
+$lang['Enter your new password below.'] = 'Nhập mật khẩu mới của bạn ở dưới.';
+$lang['Reset Password'] = 'Đặt lại mật khẩu';
+$lang['EXIF Metadata'] = 'Lý lịch dữ liệu EXIF';
+$lang['IPTC Metadata'] = 'Lý lịch dữ liệu IPTC';
+
 ?>
\ No newline at end of file
