@@ -84,7 +84,6 @@ $lang['Email admins when a valid comment is entered'] = '當用戶發表評論
 $lang['Email admins when a comment requires validation'] = '當用戶要求確認他的評論時通知管理員';
 $lang['Environment'] = '環境';
 $lang['Form'] = '表單';
-$lang['Gallery URL'] = '圖庫URL';
 $lang['Gallery title'] = '圖庫標題';
 $lang['Grant selected groups'] = '對所選組授權';
 $lang['Grant selected users'] = '對所選用戶授權';
@@ -610,11 +609,8 @@ $lang['Privacy level set to "%s"'] = '私有級別設置為 "%s"';
 $lang['Album "%s" now contains %d photos'] = '類別 "%s" 現已包含了 %d 相片';
 $lang['Manage this set of %d photos'] = '管理此設置的 %d 張照片 ';
 $lang['Select files'] = '選擇文件';
-$lang['JPEG files or ZIP archives with JPEG files inside please.'] = 'JPEG 文件或者將 JPEG 文件放到一個 ZIP 檔案裡';
 $lang['Everybody'] = '每個人';
 $lang['Who can see these photos?'] = '哪些人可以看到這些相片?';
-$lang['... or switch to the old style form'] = '... 或者使用舊式的表單';
-$lang['... or switch to the multiple files form'] = '... 或者使用多文件上傳表單';
 $lang['The websize maximum width must be a number between %d and %d'] = '最大寬度的網頁尺寸必須在 %d 和 %d 之間';
 $lang['The websize maximum height must be a number between %d and %d'] = '最大高度的網頁尺寸必須在 %d 和 %d 之間';
 $lang['The websize image quality must be a number between %d and %d'] = '圖片質量的網頁尺寸必須在 %d 和 %d 之間';
@@ -776,5 +772,34 @@ $lang['All languages are up to date.'] = '所有語言都是最新的';
 $lang['Visit theme site'] = '瀏覽主題頁面';
 $lang['Visit language site'] = '瀏覽語言頁面';
 $lang['New Version'] = '新版本';
-
+$lang['new'] = '新增';
+$lang['No results'] = '沒有結果';
+$lang['Searching...'] = '搜尋中...';
+$lang['Type in a search term'] = '輸入搜索字詞';
+$lang['Obsolete Plugins'] = '過時(廢棄)的插件';
+$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = '警告! 這個插件與此Piwigo版本不相容!';
+$lang['Do you want to activate anyway?'] = '你無論如何都要啟動嗎?';
+$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = '這個插件目前是Piwigo核心一部份! 請立即移除它!';
+$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = '錯誤：這個插件雖已安裝但並不存在! 請立即移除它!';
+$lang['display'] = '顯示'; 
+$lang['Learn more'] = '瞭解更多';
+$lang['Rate'] = '評分';
+$lang['Average rate'] = '評分';
+$lang['Activate icon "new" next to albums and pictures'] = '在相簿及相片旁邊加上"新"的圖示';
+$lang['Add a criteria'] = '新增標準';
+$lang['Deactivate all'] = '取消全部';
+$lang['Default photos order'] = '預設的相片順序';
+$lang['Restore'] = '復原';
+$lang['Restore default configuration. You will lose your plugin settings!'] = '復原至預設設定。你將失去你在套件上的設定！';
+$lang['Show menubar'] = '顯示選單列';
+$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = '無法使用預設相片順序，因你在本地端已另有設定。';
+$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = '你已在本地設定檔選用 <i>$conf[\'order_by\']</i>，造成參數矛盾，請將它移除或重新命名為 <i>$conf[\'order_by_custom\']</i>！';
+$lang['Regenerate Thumbnails'] = '重新製作小圖';
+$lang['Regenerate Websize Photos'] = '重新製作適用於網頁瀏覽的圖片';
+$lang['Thumbnails generation in progress...'] = '小圖製作中...';
+$lang['Photos generation in progress...'] = '圖片製作中...';
+$lang['%s thumbnails have been regenerated'] = '小圖製作完成';
+$lang['%s thumbnails can not be regenerated'] = '無法製作小圖';
+$lang['%s photos have been regenerated'] = '%s圖片製作完成';
+$lang['%s photos can not be regenerated'] = '無法製作%s圖片';
 ?>
\ No newline at end of file
