@@ -313,22 +313,15 @@ UPDATE '.USER_CACHE_CATEGORIES_TABLE.'
     case 'rate' :
     {
       include_once(PHPWG_ROOT_PATH.'include/functions_rate.inc.php');
-      rate_picture(
-        $page['image_id'],
-        isset($_POST['rate']) ? $_POST['rate'] : $_GET['rate']
-        );
+      rate_picture($page['image_id'], $_POST['rate']);
       redirect($url_self);
     }
     case 'edit_comment' :
     {
       check_pwg_token();
-
       include_once(PHPWG_ROOT_PATH.'include/functions_comment.inc.php');
-
       check_input_parameter('comment_to_edit', $_GET, false, PATTERN_ID);
-
       $author_id = get_comment_author_id($_GET['comment_to_edit']);
-
       if (can_manage_comment('edit', $author_id))
       {
         if (!empty($_POST['content']))
@@ -441,7 +434,7 @@ $result = pwg_query($query);
 $related_categories = array();
 while ($row = pwg_db_fetch_assoc($result))
 {
-  $row['commentable'] = boolean_to_string($row['commentable']);
+  $row['commentable'] = get_boolean($row['commentable']);
   array_push($related_categories, $row);
 }
 usort($related_categories, 'global_rank_compare');
@@ -903,7 +896,26 @@ $url = make_index_url(
 $infos['INFO_POSTED_DATE'] = '<a href="'.$url.'" rel="nofollow">'.$val.'</a>';
 
 // size in pixels
-if ($picture['current']['is_picture'] and isset($picture['current']['width']) )
+if ($picture['current']['is_picture'] AND $picture['current']['has_high'])
+{
+  if (!empty($picture['current']['high_width']))
+  {
+    $infos['INFO_DIMENSIONS'] = $picture['current']['high_width'].'*'.$picture['current']['high_height'];
+  }
+  else if ($hi_size = @getimagesize($hi_url))
+  {
+    pwg_query('
+      UPDATE ' . IMAGES_TABLE . '
+      SET 
+        high_width = \'' . $hi_size[0].'\',
+        high_height = \''.$hi_size[1] .'\'
+      WHERE id = ' . $picture['current']['id'] . ';
+    ');
+    
+    $infos['INFO_DIMENSIONS'] = $hi_size[0].'*'.$hi_size[1];
+  }
+}
+else if ($picture['current']['is_picture'] and isset($picture['current']['width']) )
 {
   if ($picture['current']['scaled_width'] !== $picture['current']['width'] )
   {
@@ -920,7 +932,12 @@ if ($picture['current']['is_picture'] and isset($picture['current']['width']) )
 }
 
 // filesize
-if (!empty($picture['current']['filesize']))
+if ($picture['current']['has_high'] and !empty($picture['current']['high_filesize']))
+{
+  $infos['INFO_FILESIZE'] =
+    sprintf(l10n('%d Kb'), $picture['current']['high_filesize']);
+}
+else if (!empty($picture['current']['filesize']))
 {
   $infos['INFO_FILESIZE'] =
     sprintf(l10n('%d Kb'), $picture['current']['filesize']);
@@ -1016,6 +1033,15 @@ if ($metadata_showable and pwg_get_session_var('show_metadata') <> null )
   include(PHPWG_ROOT_PATH.'include/picture_metadata.inc.php');
 }
 
+// include menubar
+$themeconf = $template->get_template_vars('themeconf');
+if ($conf['picture_menu'] AND (!isset($themeconf['hide_menu_on']) OR !in_array('thePicturePage', $themeconf['hide_menu_on'])))
+{
+  if (!isset($page['start'])) $page['start'] = 0;
+  include( PHPWG_ROOT_PATH.'include/menubar.inc.php');
+  if (is_admin()) $template->assign('U_ADMIN', $url_admin); // overwrited by the menu
+}
+
 include(PHPWG_ROOT_PATH.'include/page_header.php');
 trigger_action('loc_end_picture');
 if ($page['slideshow'] and $conf['light_slideshow'])
