@@ -73,7 +73,7 @@ function ws_addDefaultMethods( $arr )
       ),
       'Returns elements for the corresponding categories.
 <br><b>cat_id</b> can be empty if <b>recursive</b> is true. Can be sent as an array.
-<br><b>order</b> comma separated fields for sorting (file,id, average_rate,...)'
+<br><b>order</b> comma separated fields for sorting (file,id, rating_score,...)'
     );
 
   $service->addMethod('pwg.categories.getList', 'ws_categories_getList',
@@ -82,6 +82,7 @@ function ws_addDefaultMethods( $arr )
         'recursive' => array('default'=>false),
         'public' => array('default'=>false),
         'tree_output' => array('default'=>false),
+        'fullname' => array('default'=>false),
       ),
       'retrieves a list of categories (tree_output option only compatible with json/php output format' );
 
@@ -143,6 +144,17 @@ function ws_addDefaultMethods( $arr )
     'sets the privacy levels for the images (POST method only)'
     );
 
+  $service->addMethod(
+    'pwg.images.setRank',
+    'ws_images_setRank',
+    array(
+      'image_id' => array(),
+      'category_id' => array(),
+      'rank' => array(),
+      ),
+    'sets the rank of a photo for a given album (POST method only, for admins)'
+    );
+  
   $service->addMethod('pwg.session.getStatus', 'ws_session_getStatus', null, '' );
   $service->addMethod('pwg.session.login', 'ws_session_login',
     array('username', 'password'),
@@ -247,7 +259,7 @@ function ws_addDefaultMethods( $arr )
     'ws_images_delete',
     array(
       'image_id'=>array('default'=>0),
-      'pwg_token' => array('default' => null),
+      'pwg_token' => array(),
       ),
     'Delete photos. You can give several image_ids, comma separated'
     );
@@ -274,7 +286,7 @@ function ws_addDefaultMethods( $arr )
     'ws_categories_delete',
     array(
       'category_id'=>array('default'=>0),
-      'pwg_token' => array('default' => null),
+      'pwg_token' => array(),
       'photo_deletion_mode' => array('default' => 'delete_orphans'),
       ),
     'Delete categories. You can give several category_ids, comma separated.
@@ -287,11 +299,21 @@ function ws_addDefaultMethods( $arr )
     array(
       'category_id'=>array('default'=>0),
       'parent'=>array('default'=>0),
-      'pwg_token' => array('default' => null),
+      'pwg_token' => array(),
       ),
     'Move categories. You can give several category_ids, comma separated. Set parent as 0 to move to gallery root. Only virtual categories can be moved.'
     );
-  
+
+  $service->addMethod(
+    'pwg.categories.setRepresentative',
+    'ws_categories_setRepresentative',
+    array(
+      'category_id'=>array('default'=>0),
+      'image_id'=>array('default'=>0),
+      ),
+    'Set the representative photo for an album. The photo doesn\'t have to belong to the album. POST method only. Administration method only.'
+    );
+
   $service->addMethod(
     'pwg.tags.getAdminList',
     'ws_tags_getAdminList',
@@ -350,7 +372,7 @@ function ws_addDefaultMethods( $arr )
       'categories' => array('default' => null),
       'tag_ids' => array('default' => null),
       'level' => array(
-        'default' => 0,
+        'default' => null,
         'maxValue' => $conf['available_permission_levels']
         ),
       'single_value_mode' => array('default' => 'fill_if_empty'),
@@ -386,9 +408,9 @@ function ws_addDefaultMethods( $arr )
     'pwg.plugins.performAction',
     'ws_plugins_performAction',
     array(
-      'action' => array('default' => null),
-      'plugin' => array('default' => null),
-      'pwg_token' => array('default' => null),
+      'action' => array(),
+      'plugin' => array(),
+      'pwg_token' => array(),
       ),
     'install/activate/deactivate/uninstall/delete a plugin
 <br>administration status required'
@@ -398,12 +420,77 @@ function ws_addDefaultMethods( $arr )
     'pwg.themes.performAction',
     'ws_themes_performAction',
     array(
-      'action' => array('default' => null),
-      'themes' => array('default' => null),
-      'pwg_token' => array('default' => null),
+      'action' => array(),
+      'theme' => array(),
+      'pwg_token' => array(),
       ),
     'activate/deactivate/delete/set_default a theme<br>administration status required'
     );
+
+  $service->addMethod(
+    'pwg.images.resizeThumbnail',
+    'ws_images_resizethumbnail',
+    array(
+      'image_id' => array('default' => null),
+      'image_path' => array('default' => null),
+      'maxwidth' => array('default' => $conf['upload_form_thumb_maxwidth']),
+      'maxheight' => array('default' => $conf['upload_form_thumb_maxheight']),
+      'quality' => array('default' => $conf['upload_form_thumb_quality']),
+      'crop' => array('default' => $conf['upload_form_thumb_crop']),
+      'follow_orientation' => array('default' => $conf['upload_form_thumb_follow_orientation']),
+      'library' => array('default' => $conf['graphics_library']),
+    ),
+    'Create/Regenerate thumbnails photo with given arguments.
+<br>One of arguments "image_id" or "image_path" must be sent.'
+  );
+
+  $service->addMethod(
+    'pwg.images.resizeWebsize',
+    'ws_images_resizewebsize',
+    array(
+      'image_id' => array(),
+      'maxwidth' => array('default' => $conf['upload_form_websize_maxwidth']),
+      'maxheight' => array('default' => $conf['upload_form_websize_maxheight']),
+      'quality' => array('default' => $conf['upload_form_websize_quality']),
+      'automatic_rotation' => array('default' => $conf['upload_form_automatic_rotation']),
+      'library' => array('default' => $conf['graphics_library']),
+    ),
+    'Regenerate websize photo with given arguments.'
+  );
+
+  $service->addMethod(
+    'pwg.extensions.update',
+    'ws_extensions_update',
+    array(
+      'type' => array(),
+      'id' => array(),
+      'revision'=> array(),
+      'pwg_token' => array(),
+    ),
+    'Update an extension. Webmaster only.
+<br>Parameter type must be "plugins", "languages" or "themes".'
+  );
+
+  $service->addMethod(
+    'pwg.extensions.ignoreUpdate',
+    'ws_extensions_ignoreupdate',
+    array(
+      'type' => array('default'=>null),
+      'id' => array('default'=>null),
+      'reset' => array('default'=>null),
+      'pwg_token' => array(),
+    ),
+    'Ignore an extension if it need update.
+<br>Parameter type must be "plugins", "languages" or "themes".
+<br>If reset parameter is true, all ignored extensions will be reinitilized.'
+  );
+
+  $service->addMethod(
+    'pwg.extensions.checkUpdates',
+    'ws_extensions_checkupdates',
+    array(),
+    'Check if piwigo or extensions are up to date.'
+  );
 }
 
 add_event_handler('ws_add_methods', 'ws_addDefaultMethods');
